/**
 * Swiper Slider Component
 */
jQuery(function ($) {

    if (typeof Swiper !== 'undefined') {

        // Swiper Slider
        $(".c-swiper-slider .swiper-container").each(function (i) {

            // Data
            const randomId = $(this).data("id") ? '-' + $(this).data("id") : '';
            const slides = $(this).data("slides") ? $(this).data("slides") : '4';
            const slides_lg = $(this).data("slides-lg") ? $(this).data("slides-lg") : '4';
            const slides_md = $(this).data("slides-md") ? $(this).data("slides-md") : '2';
            const slides_sm = $(this).data("slides-sm") ? $(this).data("slides-sm") : '1';
            const slides_xs = $(this).data("slides-xs") ? $(this).data("slides-xs") : '1';
            const speed = $(this).data("speed") ? $(this).data("speed") : 5000;
            const loop = $(this).data("loop") === true ? true : false;
            const space = $(this).data("space") ? $(this).data("space") : 16;
            const effect = $(this).data("effect") ? $(this).data("effect") : 'slide';
            const paginationType = $(this).data("pagination-type") ? $(this).data("pagination-type") : 'bullets';

            // Autoplay
            let autoplay = $(this).data("autoplay") === true ? true : false;
            if (autoplay == true && speed > 0) {
                autoplay = {
                    delay: speed,
                }
            }

            // Effect
            let effectParam = effect;
            let effectArray = '';
            switch (effectParam) {
                case 'fade':
                    effectParam = 'fade';
                    effectArray = {
                        fadeEffect: {
                            crossFade: true
                        }
                    };
                    break;
                case 'flip':
                    effectParam = 'flip';
                    effectArray = {
                        flipEffect: {
                            slideShadows: false
                        }
                    };
                    break;
                case 'coverflow':
                    effectParam = 'coverflow';
                    effectArray = {
                        coverflowEffect: {
                            rotate: 50,
                            slideShadows: false,
                        }
                    };
                    break;
                case 'cube':
                    effectParam = 'cube';
                    effectArray = {
                        cubeEffect: {
                            slideShadows: false,
                        }
                    };
                    break;
                default:
                    effectParam = 'slide';
            }

            // Carousel slider
            new Swiper($(this), {

                // Optional parameters
                watchSlidesVisibility: true,
                autoplay: autoplay,
                loop: loop,
                spaceBetween: space,
                slidesPerView: slides_xs,
                breakpoints: {
                    576: {
                        slidesPerView: slides_sm
                    },
                    768: {
                        slidesPerView: slides_md
                    },
                    992: {
                        slidesPerView: slides_lg
                    },
                    1200: {
                        slidesPerView: slides,
                        autoplayDisableOnInteraction: false,
                        disableOnInteraction: false,
                    }
                },
                setWrapperSize: true,
                effect: effectParam,
                effectArray,
                pagination: {
                    el: ".swiper-pagination" + randomId,
                    type: paginationType,
                    clickable: true
                },
                navigation: {
                    nextEl: '.swiper-button-next' + randomId,
                    prevEl: '.swiper-button-prev' + randomId,
                },
                // Events
                on: {
                    init: function () {
                        togglePlayVideo()
                    },
                    slideChangeTransitionStart: function () {
                        togglePlayVideo()
                    }
                }

            });

            function togglePlayVideo() {

                var player;
                const videoID = $('.swiper-slide-active').find('.ysp-swiper-ytube-video').data('video-bg-id');
                const checkEmpty = $('.swiper-slide-active .ysp-swiper-ytube-video').empty();

                if (videoID != '' && checkEmpty) {
                    if (typeof YTPlayer !== 'undefined') {
                        player = $('.swiper-slide-active .ysp-swiper-ytube-video').YTPlayer({
                            fitToBackground: true,
                            videoId: videoID,
                            pauseOnScroll: true,
                            repeat: true,
                            playerVars: {
                                autoplay: 1,
                                modestbranding: 1,
                                autoplay: 1,
                                controls: 0,
                                showinfo: 0,
                                wmode: 'transparent',
                                rel: 0,
                                origin: window.location.origin
                            }
                        });
                    }
                }

            }

        });

    }

});