<?php
/**
 * yourstyle+ functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package yourstyle+
 */

global $ysp_theme_setup;

/* Start Theme Setup */
if ( ! class_exists( 'YSP_Theme_Setup' ) ) {

    class YSP_Theme_Setup {

        /* Template Directory */
        private $template_directory;

        /**
         * Theme Class Constructor.
         *
         * Loads All Necessary Actions, Classes, Configuration Files, Functions and Hooks for the Theme.
         *
         * @since 0.3.0
         */
        public function __construct()
        {
            $this->template_directory = get_template_directory();

            /* Theme Constants */
            add_action('after_setup_theme', array( $this, 'ysp_theme_constants' ), 1 );
            
            /* Theme Basics */
            add_action('after_setup_theme', array( $this, 'ysp_theme_basics' ), 1 );

            /* Theme Typography */
            add_action('after_setup_theme', array( $this, 'ysp_theme_typography_generator' ), 2 );

            /* Theme Constants */
            $this->ysp_theme_constants();

            /* Theme Options */
            $this->ysp_theme_options();
            
            /* Theme Functions */
            add_action('after_setup_theme', array( $this, 'ysp_theme_functions' ), 4 );

            /* Theme Add-ons */
            add_action('after_setup_theme', array( $this, 'ysp_theme_addons' ), 4 );
            
            /* Theme Setup Defaults */
            add_action('widgets_init', array( $this, 'ysp_theme_setup_defaults' ), 1 );

            /* Theme Main Nav */
            add_action('after_setup_theme', array( $this, 'ysp_theme_main_nav' ) );

            /* Theme Mobile Nav */
            add_action('after_setup_theme', array( $this, 'ysp_theme_mobile_nav' ) );
            
            /* Theme Meta Boxes */
            add_action('after_setup_theme', array( $this, 'ysp_theme_meta_boxes' ), 5 );
            
            /* Theme Third Party Integrations */
            add_action('after_setup_theme', array( $this, 'ysp_theme_third_party_integrations' ) );
        
            /* Theme Set Default Hidden Columns */
            add_action('admin_init', array( $this, 'ysp_set_default_hidden_columns' ) );
        }

        /**
         * Theme Constants.
         *
         * @since 0.3.0
         */
        public function ysp_theme_constants()
        {

            /* Theme Text Domain */
            if ( !defined('YSP_TEXT_DOMAIN') ) {
                define( 'YSP_TEXT_DOMAIN', 'yourstyle-plus' );
            }

            /* Theme Directory DIR */
            if ( !defined('YSP_THEME_DIR') ) {
                define( 'YSP_THEME_DIR', get_template_directory() );
            }

            /* Theme Directory URI */
            if ( !defined('YSP_THEME_URI') ) {
                define( 'YSP_THEME_URI', get_template_directory_uri() );
            }

            /* Theme Stylesheet DIR */
            if ( !defined('YSP_THEME_STYLE_DIR') ) {
                define( 'YSP_THEME_STYLE_DIR', get_stylesheet_directory() );
            }

            /* Theme Stylesheet URI */
            if ( !defined('YSP_THEME_STYLE_URI') ) {
                define( 'YSP_THEME_STYLE_URI', get_stylesheet_directory_uri() );
            }

            /* Theme "Engine" Directory */
            if ( !defined('YSP_ENGINE_DIR') ) {
                define( 'YSP_ENGINE_DIR', YSP_THEME_DIR . '/inc' );
            }

        }

        /**
         * Theme Basics.
         *
         * @since 0.3.0
         */
        public function ysp_theme_basics()
        {

            /* Utility functions */
            include YSP_ENGINE_DIR . '/utility.php';
            
            /* Plugin compatability */
            include YSP_ENGINE_DIR . '/compatibility.php';

            /* Register navigation menus and custom menu functionality */
            include YSP_ENGINE_DIR . '/navigation.php';

            /* Register Options and Admin Pages */
            include YSP_ENGINE_DIR . '/options.php';

            /* Register front-end and back-end scripts */
            include YSP_ENGINE_DIR . '/scripts.php';

            /* Functions which enhance the theme by hooking into WordPress */
            include YSP_ENGINE_DIR . '/template-functions.php';

            /* Custom template tags for this theme */
            include YSP_ENGINE_DIR . '/template-tags.php';

            /* Register widget areas and custom widget functionality */
            include YSP_ENGINE_DIR . '/widgets.php';
        }

        /**
         * Theme Typography Generator.
         *
         * @since 0.3.0
         */
        public function ysp_theme_typography_generator()
        {
            /* Typography Generator */
            include YSP_ENGINE_DIR  . '/functions/typography-generator.php';
        }
        
        /**
         * Theme Options.
         *
         * @since 0.3.0
         */
        public function ysp_theme_options()
        {
            /* Customizer additions */
            include YSP_ENGINE_DIR . '/customizer.php';

        }

        /**
         * Theme Functions.
         *
         * @since 0.3.0
         */
        public function ysp_theme_functions()
        {
            /* Theme Hooks */
            include YSP_ENGINE_DIR . '/hooks.php';

            /* Shortcodes Admin Buttons */
            include YSP_ENGINE_DIR . '/admin/tinymce/tinymce-buttons.php';

            /* WP Editor YSP Extension */
            include YSP_ENGINE_DIR . '/admin/tinymce/tinymce-extension.php';

            /* Typography Generator */
            include YSP_ENGINE_DIR . '/admin/admin-typography.php';
            
            /* WP Fine Tune */
            include YSP_ENGINE_DIR . '/admin/admin-theme-fine-tune.php';

            /* Shortcode Helpers */
            include YSP_ENGINE_DIR . '/components/shortcodes/shortcode-helpers.php';

            /* Shortcodes */
            include YSP_ENGINE_DIR . '/components/shortcodes/shortcodes.php';

            /* Admin Settings Page */
            include YSP_ENGINE_DIR . '/functions/theme-helpers.php';

            /* Run Theme Fonts */
            include YSP_ENGINE_DIR . '/functions/theme-run-fonts.php';

            /* Icon Render Wrapper */
            include YSP_ENGINE_DIR . '/functions/theme-run-icon.php';

            /* CSS Classes */
            include YSP_ENGINE_DIR . '/functions/css-layout-classes.php';
            
            /* Add Classes and Wrappers */
            include YSP_ENGINE_DIR . '/functions/front-layout-setup.php';

            /* Social Media */
            include YSP_ENGINE_DIR . '/functions/social-media.php';

            /* Search Engine Warning */
            include YSP_ENGINE_DIR . '/functions/search-engine-warning.php';
        }

        /**
         * Theme Add-ons.
         *
         * @since 0.3.0
         */
        public function ysp_theme_addons()
        {

            /* Addon: Color Scheme */
            include YSP_ENGINE_DIR . '/addons/admin-color-scheme/custom-admin-color-schemes.php';

            /* Addon: WooCommerce */
            include YSP_ENGINE_DIR . '/addons/woo/woo-enabler.php';
            if ( woo_switch() ) :
                include YSP_ENGINE_DIR . '/addons/woo/woo-setup.php';
            endif;
        }
        
        /**
         * Sets up theme defaults and registers support for various WordPress features.
         *
         * Note that this function is hooked into the after_setup_theme hook, which
         * runs before the init hook. The init hook is too late for some features, such
         * as indicating support for post thumbnails.
         *
         * @since 0.3.0
         */
        public function ysp_theme_setup_defaults()
        {
            /*
            * Make your Theme available for translation. Translations can be filed in the /languages/ directory.
            */
            load_theme_textdomain( YSP_TEXT_DOMAIN, get_template_directory() . '/languages' );

            /*
            * Let WordPress manage the document title.
            * By adding theme support, we declare that this theme does not use a hard-coded
            * <title> tag in the document head, and expect WordPress to provide it for us.
            */
            add_theme_support( 'title-tag' );
        
            /**
             * Add default posts and comments RSS feed links to head.
             */
            add_theme_support( 'automatic-feed-links' );

            /*
            * Enable support for Post Thumbnails on posts and pages.
            * 
            * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
            */
            add_theme_support( 'post-thumbnails' );

            /**
             * Switch default core markup for search form, comment form, and comments to output valid HTML5.
             */
            add_theme_support( 'html5', array(
                'search-form',
                'comment-form',
                'comment-list',
                'gallery',
                'caption',
            ));

            /**
             * Add theme support for selective refresh for widgets.
             */
            add_theme_support( 'customize-selective-refresh-widgets' );

            /**
             * 3rd Party plugins support.
             */
            add_theme_support('woocommerce');
            add_theme_support('yoast-seo-breadcrumbs');
            
            /**
             * Add support for core custom logo.
             *
             * @link https://codex.wordpress.org/Theme_Logo
             */
            add_theme_support( 'custom-logo', array(
                'height'      => 250,
                'width'       => 250,
                'flex-width'  => true,
                'flex-height' => true,
            ));

            /**
             * Remove default image sizes that are unnessary
             */
            remove_image_size( '1536x1536' ); // 2 x Medium Large (1536 x 1536)
            remove_image_size( '2048x2048' ); // 2 x Large (2048 x 2048)
        }

        /**
         * Theme Main Nav
         *
         * @since 0.3.0
         */
        public function ysp_theme_main_nav()
        {
            /* Site Main Navigation */
            add_action( 'ysp_site_navigation', 'ysp_site_main_navigation', 10 );
            function ysp_site_main_navigation() {
                $menu = '';
                if (is_page_template('template-landingpage.php') ) {
                    $menu = 'site-header-landingpage';
                } else {
                    $menu = 'site-header';
                }
                echo '<nav id="site-navigation" class="main-navigation" role="navigation">';
                    echo ysp_navigation( $menu );
                echo '</nav><!-- #site-navigation -->';
            }

            /* Custom Nav Walker */
            include YSP_ENGINE_DIR . '/navigation/custom-nav-walker.php';
            
            /* Admin Menu Meta */
            include YSP_ENGINE_DIR . '/navigation/admin-menu-meta.php';
        }

        /**
         * Theme Mobile Nav
         *
         * @since 0.3.0
         */
        public function ysp_theme_mobile_nav()
        {
            /* Mobile Nav */
            include YSP_ENGINE_DIR . '/navigation/mobile-nav.php';

            /* Mobile Nav Walker */
            include YSP_ENGINE_DIR . '/navigation/mobile-nav-walker.php';
            
            /* Mobile Nav Hook */
            add_action( 'ysp_after_footer', 'ysp_mobile_nav' );
            
            /* Mobile Nav Mask */
            add_action( 'wp_footer', 'ysp_mobile_nav_mask' );

        }

        /**
         * Theme Meta Boxes.
         *
         * @since 0.3.0
         */
        public function ysp_theme_meta_boxes()
        {
            /* Page Settings */
            include YSP_ENGINE_DIR . '/admin/admin-page-settings.php';
        }

        /**
         * Theme Third Party Integrations.
         *
         * @since 0.3.0
         */
        public function ysp_theme_third_party_integrations()
        {
            /* Visual Composer */
            if ( class_exists( 'WPBakeryShortCode' ) ) {
                include YSP_ENGINE_DIR . '/components/visual-composer/ysp-vc-integration.php';
            }

            /* If we initiate fallback while VC is active, the fallback shortcodes will overwrite the VC shortcodes */
            if ( !class_exists( 'WPBakeryShortCode' ) ) {
                include YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-shortcode-fallbacks.php';
            }
        }
    
        /**
         * Theme Set Default Hidden Columns.
         *
         * @since 1.4.3
         */
        public function ysp_set_default_hidden_columns()
        {
            
            include YSP_ENGINE_DIR . '/admin/admin-default-hidden-columns.php';
        }
        
    }
    
}

/* Execute Theme Setup */
$ysp_theme_setup = new YSP_Theme_Setup();