<?php

if ( ! class_exists( 'Ysp_Woo_Header_Utility' ) ) {

    class Ysp_Woo_Header_Utility {

        public function __construct() {

            if ( ! ysp_is_woo_active() ) {
                return;
            }

            $option = ysp_get_option( 'ysp-woo-remove-header-utility' );
            if ( '1' == $option ) {
                return;
            }

            add_action( 'ysp_after_site_navigation', array( $this, 'header_cart' ), 5, 2 );

            if ( defined( 'WC_VERSION' ) && version_compare( WC_VERSION, '2.3', '>=' ) ) {
                add_filter( 'woocommerce_add_to_cart_fragments', array( $this, 'cart_link_fragment' ) );
            } else {
                add_filter( 'add_to_cart_fragments', array( $this, 'cart_link_fragment' ) );
            }
        }

        public static function header_cart() {

            if ( ysp_is_woo_active() ) {
                if ( is_cart() ) {
                    $class = 'class="current-menu-item"';
                } else {
                    $class = '';
                }
                ?>
                
                <div class="woo-header-utility-wrapper">
                    <ul id="site-header-user" class="site-header-user menu">
                        <li>
                            <?php self::header_user(); ?>
                        </li>
                    </ul>
                    <ul id="site-header-cart" class="site-header-cart menu">
                        <li <?php echo esc_attr( $class ); ?>>
                            <?php self::cart_link(); ?>
                        </li>
                        <li>
                            <?php
                                $title = __('Cart', YSP_TEXT_DOMAIN);
                                the_widget( 'WC_Widget_Cart', 'title='. $title );
                            ?>
                        </li>
                    </ul>
                </div>

                <?php
            }
        }

        public static function cart_link_fragment( $fragments ) {

            ob_start();
            self::cart_link();
            $fragments['a.cart-contents'] = ob_get_clean();

            return $fragments;
        }

        public static function header_user() {

            $output    = '';
            
            $user_icon = class_exists('Ysp_Woo_Helpers') ? Ysp_Woo_Helpers::woo_icon( 'fal-user' ) : '';

            $myaccount_page_id  =   get_option( 'woocommerce_myaccount_page_id' );
            $account_url        =   get_permalink( get_option( 'woocommerce_myaccount_page_id' ) );
            $is_active          =   is_page( $myaccount_page_id ) ? ' account-page-active' : '';

            if ( $myaccount_page_id ) {

                $logout_url = wp_logout_url( get_permalink( $myaccount_page_id ) );

                if ( get_option( 'woocommerce_force_ssl_checkout' ) == 'yes' ) {
                    $logout_url = str_replace( 'http:', 'https:', $logout_url );
                }
            }

            $user_utility = sprintf(
                '<div class="woo-header-utility"><a href="' . $account_url . '" title="' . __( 'My Account', YSP_TEXT_DOMAIN ) . '"><span class="woo-header-utility__symbol">%s</span></a></div>',
                $user_icon
            );

            $login_label = is_user_logged_in() ? __( 'My account', YSP_TEXT_DOMAIN ) : __( 'Login', YSP_TEXT_DOMAIN );

            $logout_link = is_user_logged_in() ? '<li><a class="woo-header-utility__account-logout-link" href="' . $logout_url . '">' . __( 'Logout', YSP_TEXT_DOMAIN ) . '</a></li>' : '';

            $account_link = '<li><a class="woo-header-utility__account-link'. $is_active .'" href="' . $account_url . '" title="' . $login_label . '">' . $login_label . '</a></li>';

            $output = sprintf(
                '%1$s<ul class="site-header-user__list">%2$s%3$s</ul>',
                $user_utility,
                $account_link,
                $logout_link
            );

            echo $output;
        }

        public static function cart_link() {

            $output    = '';
            
            $cart_icon = class_exists('Ysp_Woo_Helpers') ? Ysp_Woo_Helpers::woo_icon( 'fal-shopping-cart' ) : '';

            $cart_content = WC()->cart->get_cart_contents_count();

            $cart_utility = sprintf(
                '<div class="woo-header-utility"><span class="woo-header-utility__symbol">%s</span><span class="woo-header-utility__cart-count count">%s</span></div>',
                $cart_icon,
                $cart_content
            );

            $output .= '<a class="cart-contents" href="' . esc_url( wc_get_cart_url() ) . '" title="' . esc_attr( 'My Cart' ) . '">';
                $output .= $cart_utility;
            $output .= '</a>';

            echo $output;
        }
    }

    new Ysp_Woo_Header_Utility();
}