<?php
/**
 * Display single product reviews (comments)
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/single-product-reviews.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see     https://docs.woocommerce.com/document/template-structure/
 * @package WooCommerce/Templates
 * @version 3.6.0
 */

if ( ! class_exists( 'Ysp_Woo_Stock_Status' ) ) {
    
    class Ysp_Woo_Stock_Status {

        public function __construct() {

            // Add Product Stock Status
            add_action( 'woocommerce_after_shop_loop_item_title', array( $this, 'product_stock_status' ), 10 );
        }

        static function display_stock_status() {
        
            global $product;

            $check_solid = class_exists('Ysp_Woo_Helpers') ? Ysp_Woo_Helpers::woo_icon( 'fas-check' ) : '';
            $exclamation_solid = class_exists('Ysp_Woo_Helpers') ? Ysp_Woo_Helpers::woo_icon( 'exclamation-solid' ) : '';
            $times_solid = class_exists('Ysp_Woo_Helpers') ? Ysp_Woo_Helpers::woo_icon( 'fas-times' ) : '';
            
            // Stock Status and Icons
            $stock_status = array(
                'instock' => array(
                    'label' => __( 'In stock', YSP_TEXT_DOMAIN ),
                    'icon' => $check_solid,
                ),
                'onbackorder' => array(
                    'label' => __( 'On backorder', YSP_TEXT_DOMAIN ),
                    'icon' => $exclamation_solid,
                ),
                'outofstock' => array(
                    'label' => __( 'Out of stock', YSP_TEXT_DOMAIN ),
                    'icon' => $times_solid,
                ),
            );

            $output = '';
            
            // Product IS Simple and NOT managed
            if ( $product->is_type( 'simple' ) && !$product->managing_stock() ) {

                $simple_stock_status = get_post_meta( $product->get_id(), '_stock_status', true );
                $stock_status_meta = get_post_meta($product->get_id(), 'product_stockstatus_'.$simple_stock_status, true);
                $stock_status_label = ( $stock_status_meta ) ? $stock_status_meta : $stock_status[$simple_stock_status]['label'];

                $output .= '<div class="woo-product-stock-status stock-status-'. $simple_stock_status .'">';
                    $output .= '<div class="woo-product-stock-status-icon">'. $stock_status[$simple_stock_status]['icon'] .'</div>';
                    $output .= '<div class="woo-product-stock-status-label">'. $stock_status_label .'</div>';
                $output .= '</div>';

            // Product IS in stock and quantity IS more than 0
            } else if ( $product->is_in_stock() && $product->get_stock_quantity() > 0 ) {
                
                $stock_status_meta = get_post_meta($product->get_id(), 'product_stockstatus_instock', true);
                $stock_status_label = ( $stock_status_meta ) ? $stock_status_meta : $stock_status['instock']['label'];
                
                $output .= '<div class="woo-product-stock-status stock-status-instock">';
                    $output .= '<div class="woo-product-stock-status-icon">'. $stock_status['instock']['icon'] .'</div>';
                    $output .= '<div class="woo-product-stock-status-label">'. $stock_status_label .'</div>';
                $output .= '</div>';
                
            // Product is on backorder
            } else if ( $product->is_on_backorder() ) {
                
                $stock_status_meta = get_post_meta($product->get_id(), 'product_stockstatus_onbackorder', true);
                $stock_status_label = ( $stock_status_meta ) ? $stock_status_meta : $stock_status['onbackorder']['label'];
                
                $output .= '<div class="woo-product-stock-status stock-status-onbackorder">';
                    $output .= '<div class="woo-product-stock-status-icon">'. $stock_status['onbackorder']['icon'] .'</div>';
                    $output .= '<div class="woo-product-stock-status-label">'. $stock_status_label .'</div>';
                $output .= '</div>';
                
            // Product IS out of stock
            } else {

                $stock_status_meta = get_post_meta($product->get_id(), 'product_stockstatus_outofstock', true);
                $stock_status_label = ( $stock_status_meta ) ? $stock_status_meta : $stock_status['outofstock']['label'];

                $output .= '<div class="woo-product-stock-status stock-status-outofstock">';
                    $output .= '<div class="woo-product-stock-status-icon">'. $stock_status['outofstock']['icon'] .'</div>';
                    $output .= '<div class="woo-product-stock-status-label">'. $stock_status_label .'</div>';
                $output .= '</div>';

            }

            echo $output;
        }

        // Add Product Stock Status
        public function product_stock_status( $product ) {
            Ysp_Woo_Stock_Status::display_stock_status();
        }
    }

    new Ysp_Woo_Stock_Status();
    
}
