<?php

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if (!class_exists('Ysp_Woo_Layout')) {

    class Ysp_Woo_Layout {
        public function __construct() {
            add_action( 'woocommerce_before_main_content', array( $this, 'woocommerce_single_setup' ), 10, 2 );
        }

        public function woocommerce_single_setup() {

            if ( ! ysp_is_woo_active() ) {
                return;
            }

            if ( ! is_product() ) {
                return false;
            }

            // remove_action('ysp_before_content', 'ysp_spacing_before_content');
            remove_action('ysp_after_content', 'ysp_spacing_after_content');

            // Product Single - Remove Breadcrumbs
            remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );

            // Product Single - Wrap Notices (start)
            add_action( 'woocommerce_before_single_product', array( $this, 'woocommerce_single_product_notices_start'), 8 );
            
            // Product Single - Wrap Notices (end)
            add_action( 'woocommerce_before_single_product', array( $this, 'woocommerce_single_product_notices_end'), 12 );

            // Product Single - Remove Sale Label
            remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );

            // Single Product - Remove Tabs
            remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_product_data_tabs', 10 );

            // Single Product - Add Average Rating
            // remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );

            // Single Product - Add Short Description
            // remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_excerpt', 20 );

            // Single Product - Remove Product Meta
            remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_meta', 40 );

            // Add product description
            add_action( 'woocommerce_after_single_product_summary', array( $this, 'product_description' ) );

            // Add product characteristics
            add_action( 'woocommerce_after_single_product_summary', array( $this, 'product_attributes' ) );
            
            // Reviews (Hook Prio: 12) -> woo/woo-reviews.php
            // add_action( 'woocommerce_after_single_product_summary', array( $this, 'product_reviews' ) );

            // Pre content area
            // add_action( 'woocommerce_before_single_product', array( $this, 'ysp_before_main_content' ) );

            // Remove Sidebar
            remove_action('woocommerce_sidebar', 'woocommerce_get_sidebar', 10);

        }
        
        public function woocommerce_single_product_notices_start() {

            $output = '';

            $output .= '<div class="c-container"><div class="c-row"><div class="c-col">';

            echo $output;

        }

        public function woocommerce_single_product_notices_end() {

            $output = '';

            $output .= '</div></div></div>';

            echo $output;

        }

        public function product_description() {

            $title   = '<h2>'. __( 'Description', YSP_TEXT_DOMAIN ) .'</h2>';
            $title   = apply_filters( 'ysp_woo_single_product_description_title', $title );

            $content = apply_filters( 'the_content', get_the_content() );
            $content_length = strlen( $content );
            
            $text_more = __( 'Read more', YSP_TEXT_DOMAIN );
            $text_less = __( 'Read less', YSP_TEXT_DOMAIN );
            
            // Read More/Less Button Class
            $btn_class = apply_filters( 'ysp_woo_single_product_description_button_class', 'c-button c-button--sm' );

            $label = '';
            if ( $content_length > 300 ) {
                $label .= '<label for="product-read-more-toggle" class="woo-single-product-desc-readmore">';
                    $label .= '<span id="product-read-more-toggle" class="product-read-more-trigger '. $btn_class .'" data-text-more="'. $text_more .'" data-text-less="'. $text_less .'">';
                        $label .= '<span class="sr-only sr-only-focusable">'. $text_more .'</span>';
                    $label .= '</span>';
                $label .= '</label>';
            }

            $output = sprintf(
                '<div class="woo-single-product-description">
                    <input type="checkbox" class="product-read-more-state" id="product-read-more-toggle"/>
                    <div class="product-content">%s%s</div>
                    %s
                </div>',
                $title,
                $content,
                $label
            );
            
            echo $output;
        }

        public function product_attributes() {

            global $product;

            $formatted_attributes = array();

            $attributes = $product->get_attributes();
            foreach ( $attributes as $attr => $attr_deets ) {
                $attribute_label = wc_attribute_label( $attr );
                if ( isset( $attributes[ $attr ] ) || isset( $attributes[ 'pa_' . $attr ] ) ) {
                    $attribute = isset( $attributes[ $attr ] ) ? $attributes[ $attr ] : $attributes[ 'pa_' . $attr ];
                    if ( $attribute['is_taxonomy'] ) {
                        $formatted_attributes[ $attribute_label ] = array(
                            'name' => $attr,
                            'options' => implode( ', ', wc_get_product_terms( $product->get_id(), $attribute['name'], array( 'fields' => 'names' ) ) ),
                        );
                    } else {
                        $formatted_attributes[ $attribute_label ] = array(
                            'name' => $attr,
                            'options' => $attribute['value'],
                        );
                    }
                }
            }
            
            $output  = '';
            
            if ( $formatted_attributes ) {

                $title = '<h2>' . __( 'Attributes', YSP_TEXT_DOMAIN ) . '</h2>';
                $title = apply_filters( 'ysp_woo_single_product_attributes_title', $title );

                $output .= '<div class="woo-single-product-attributes">';
                    $output .= $title;
                    $output .= '<div class="woo-table-responsive">';
                        $output .= '<table class="woocommerce-product-attributes shop_attributes">';

                        foreach ( $formatted_attributes as $label => $value ) {

                            $output .= '<tr class="woocommerce-product-attributes-item woocommerce-product-attributes-item--' . $value['name'] . '">';
                                $output .= '<th class="woocommerce-product-attributes-item__label">' . $label . '</th>';
                                $output .= '<td class="woocommerce-product-attributes-item__value">' . $value['options'] . '</td>';
                            $output .= '</tr>';

                        }

                        $output .= '</table>';
                    $output .= '</div>';
                $output .= '</div>';

            }
            
            echo $output;
        }

        // Before content area
        public function ysp_before_main_content() {

            $content = get_option( 'ysp_woo_single_header_start_area', false );

            if ( ! $content ) {
                return;
            }

            $content = sprintf(
                '<div class="woo-pre-single-content"><div class="woo-pre-single-content__inner">%1$s</div></div>',
                do_shortcode( $content )
            );

            echo $content;
        }
    }

    new Ysp_Woo_Layout();

}