<?php
/**
* PAGE SETTINGS
*/

add_action('admin_init', 'ysp_page_settings_meta_box');
if (!function_exists('ysp_page_settings_meta_box')) {
    function ysp_page_settings_meta_box() {
        $post_types = array('page', 'post', 'product');
        $post_types = apply_filters('ysp_page_settings', $post_types);
        add_meta_box('ysp_page_settings', __('Page Settings', YSP_TEXT_DOMAIN) , 'ysp_page_settings', $post_types, 'side');
    }
}
 
if (!function_exists('ysp_page_settings')) {
    function ysp_page_settings( $post ) {

        $checkboxMeta = get_post_meta( $post->ID );

        $spacing_before = get_post_meta( get_the_id(), 'spacing_before_content', true );
        $spacing_after = get_post_meta( get_the_id(), 'spacing_after_content', true );

        // Page Settings: Title
        wp_nonce_field( 'set_title_visibility_nonce', 'title_visibility' ); // Nonce Field

        echo '<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="page_title_visibility">'. __("Page Title Visibility", YSP_TEXT_DOMAIN) .'</label></p>';    
        echo '<input type="checkbox" name="page_title_visibility" id="page_title_visibility" value="hide" '. ( isset(  $checkboxMeta['page_title_visibility'] ) ? checked(  $checkboxMeta['page_title_visibility'][0], 'hide' , false ) : '' ) .'> '. __("Hide Title", YSP_TEXT_DOMAIN);

        // Page Settings: Margins
        wp_nonce_field( 'set_content_spacing_nonce', 'content_spacing' ); // nonce Field

        // Content Spacing - Before
        echo '<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="spacing_before_content">'. __('Before Content Spacing', YSP_TEXT_DOMAIN) .'</label></p>';
        echo '<select name="spacing_before_content" id="spacing_before_content">';
            foreach ( ysp_spacings() as $value => $spacing ) {
                $selected = ( strval($value) == $spacing_before ) ? ' selected' : '';
                echo '<option value="'. $value .'"'. $selected .'>'. $spacing .'</option>';
            }
        echo '</select>';

        // Content Spacing - After
        echo '<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="spacing_after_content">'. __('After Content Spacing', YSP_TEXT_DOMAIN) .'</label></p>';
        echo '<select name="spacing_after_content" id="spacing_after_content">';
            foreach ( ysp_spacings() as $value => $spacing ) {
                $selected = ( strval($value) == $spacing_after ) ? ' selected' : '';
                echo '<option value="'. $value .'"'. $selected .'>'. $spacing .'</option>';
            }
        echo '</select>';

        // Page Settings: Site Header Transparency
        wp_nonce_field( 'set_header_transparency_nonce', 'header_transparency' ); // Nonce Field

        echo '<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="site_header_transparency">'. __("Page Site Header", YSP_TEXT_DOMAIN) .'</label></p>';    
        echo '<input type="checkbox" name="site_header_transparency" id="site_header_transparency" value="transparent" '. ( isset(  $checkboxMeta['site_header_transparency'] ) ? checked(  $checkboxMeta['site_header_transparency'][0], 'transparent' , false ) : '' ) .'> '. __("Make Transparent", YSP_TEXT_DOMAIN);

        echo '<p class="post-attributes-label-wrapper"><label class="post-attributes-label" for="site_footer_alternative">'. __("Page Site Footer", YSP_TEXT_DOMAIN) .'</label></p>';    
        echo '<input type="checkbox" name="site_footer_alternative" id="site_footer_alternative" value="transparent" '. ( isset(  $checkboxMeta['site_footer_alternative'] ) ? checked(  $checkboxMeta['site_footer_alternative'][0], 'alternative' , false ) : '' ) .'> '. __("Show Alternative", YSP_TEXT_DOMAIN);

    }
}

add_action('save_post', 'ysp_page_settings_save_postdata');
if (!function_exists('ysp_page_settings_save_postdata')) {
    function ysp_page_settings_save_postdata( $post_id ){ 

        $post_type = get_post_type($post_id);
        $post_types = array('page', 'post', 'product');
        $post_types = apply_filters('ysp_page_settings', $post_types);        
        if ( array_search($post_type, $post_types) === FALSE ) {
            return;
        }

        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) 
        return;
        
        // Pointless if $_POST is empty (this happens on bulk edit)
        if ( empty( $_POST ) )
        return $post_id;

        // Verify that a nonce is correct and unexpired with the respect to a specified action. nonce / nonce_action
        if ( ( isset( $_POST['set_title_visibility_nonce'] ) ) && ( !wp_verify_nonce( $_POST['set_title_visibility_nonce'], 'title_visibility' ) ) )
            return;
                
        // Verify that a nonce is correct and unexpired with the respect to a specified action. nonce / nonce_action
        if ( ( isset( $_POST['set_content_spacing_nonce'] ) ) && ( !wp_verify_nonce( $_POST['set_content_spacing_nonce'], 'content_spacing' ) ) ) 
            return;

        // Verify that a nonce is correct and unexpired with the respect to a specified action. nonce / nonce_action
        if ( ( isset( $_POST['set_header_transparency_nonce'] ) ) && ( !wp_verify_nonce( $_POST['set_header_transparency_nonce'], 'header_transparency' ) ) )
            return;

        // Check if we are on a page and not other post type and user is allowed to edit these fields
        if ( ( isset( $_POST['post_type'] ) ) && ( array_search($_POST['post_type'], $post_types) !== FALSE )  ) {
            if ( !current_user_can( 'edit_page', $post_id ) ) {
                return;
            }
        } else {
            if ( !current_user_can( 'edit_post', $post_id ) ) {
                return;
            }
        }

        // Update Fields
        if ( isset( $_POST['page_title_visibility'] ) ) {
            update_post_meta( $post_id , 'page_title_visibility', 'hide');
        } else {
            update_post_meta( $post_id , 'page_title_visibility', 'show');
        }

        if ( isset( $_POST['spacing_before_content'] ) ) {
            update_post_meta( $post_id , 'spacing_before_content', $_POST['spacing_before_content'] );
        }

        if ( isset( $_POST['spacing_after_content'] ) ) {
            update_post_meta( $post_id , 'spacing_after_content', $_POST['spacing_after_content'] );
        }

        if ( isset( $_POST['site_header_transparency'] ) ) {
            update_post_meta( $post_id , 'site_header_transparency', 'transparent');
        } else {
            update_post_meta( $post_id , 'site_header_transparency', 'normal');
        }

        if ( isset( $_POST['site_footer_alternative'] ) ) {
            update_post_meta( $post_id , 'site_footer_alternative', 'alternative');
        } else {
            update_post_meta( $post_id , 'site_footer_alternative', 'normal');
        }
    }
}