<?php
/**
 * yourstyle+ Compatability
 * 
 * Adds compatability for common Wordpress plugins and handles backwards
 * compatability with older Wordpress versions.
 *
 * @package yourstyle+
 */

/**
 * Prevent switching to Yourstyle+ on old versions of WordPress.
 *
 * Switches to the default theme.
 */
if (!function_exists('ysp_switch_theme')) {
    function ysp_switch_theme() {
        switch_theme(WP_DEFAULT_THEME);
        unset($_GET['activated']);
        add_action('admin_notices', 'ysp_upgrade_notice');
    }
}

if (version_compare($GLOBALS['wp_version'], '5.0', '<' )) {
    add_action('after_switch_theme', 'ysp_switch_theme');
}

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * Yourstyle+ on WordPress versions prior to 5.0.
 *
 * @global string $wp_version WordPress version.
 */
if (!function_exists('ysp_upgrade_notice')) {
    function ysp_upgrade_notice() {
        $message = sprintf(__('Yourstyle+ requires at least WordPress version 5.0. You are running version %s. Please upgrade and try again.', YSP_TEXT_DOMAIN), $GLOBALS['wp_version']);
        printf('<div class="error"><p>%s</p></div>', $message);
    }
}

/**
 * Wordpress Block Editor
 */
require get_template_directory() . '/inc/compatibility/wp-editor.php';

/**
 * Load Jetpack compatibility file.
 */
if (defined('JETPACK__VERSION')) {
	require YSP_ENGINE_DIR . '/compatibility/jetpack.php';
}
