<?php
/**
 * Wordpress Block Editor Compatability
 *
 * @package yourstyle+
 */

// Add support for Block Styles.
add_theme_support( 'wp-block-styles' );

// Add support for wide align blocks.
add_theme_support( 'align-wide' );

// Add support for editor styles.
add_theme_support( 'editor-styles' );

// Enqueue editor styles.
add_editor_style( 'style-editor.css' );

// Add custom editor font sizes.
add_theme_support(
    'editor-font-sizes',
    array(
        array(
            'name'      => __( 'Small', YSP_TEXT_DOMAIN ),
            'shortName' => 'S',
            'size'      => 12,
            'slug'      => 'small',
        ),
        array(
            'name'      => __( 'Normal', YSP_TEXT_DOMAIN ),
            'shortName' => 'M',
            'size'      => 16,
            'slug'      => 'normal',
        ),
        array(
            'name'      => __( 'Large', YSP_TEXT_DOMAIN ),
            'shortName' => 'L',
            'size'      => 36,
            'slug'      => 'large',
        ),
        array(
            'name'      => __( 'Huge', YSP_TEXT_DOMAIN ),
            'shortName' => 'XL',
            'size'      => 50,
            'slug'      => 'huge',
        ),
    )
);

// Editor color palette.
add_theme_support(
    'editor-color-palette',
    array(
        array(
            'name'  => __('Body Color', YSP_TEXT_DOMAIN),
            'slug'  => 'body-color',
            'color' => ysp_get_option('body-color'),
        ),
        array(
            'name'  => __('Text Color', YSP_TEXT_DOMAIN),
            'slug'  => 'text-color',
            'color' => ysp_get_option('text-color'),
        ),
        array(
            'name'  => __('Link Color', YSP_TEXT_DOMAIN),
            'slug'  => 'link-color',
            'color' => ysp_get_option('link-color'),
        ),
        array(
            'name'  => __('Color Default', YSP_TEXT_DOMAIN),
            'slug'  => 'color-default',
            'color' => ysp_get_option('color-default'),
        ),
        array(
            'name'  => __('Color 1', YSP_TEXT_DOMAIN),
            'slug'  => 'color-1',
            'color' => ysp_get_option('color-1'),
        ),
        array(
            'name'  => __('Color 2', YSP_TEXT_DOMAIN),
            'slug'  => 'color-2',
            'color' => ysp_get_option('color-2'),
        ),
        array(
            'name'  => __('Color 3', YSP_TEXT_DOMAIN),
            'slug'  => 'color-3',
            'color' => ysp_get_option('color-3'),
        ),
        array(
            'name'  => __('Color 4', YSP_TEXT_DOMAIN),
            'slug'  => 'color-4',
            'color' => ysp_get_option('color-4'),
        ),
        array(
            'name'  => __('Color 5', YSP_TEXT_DOMAIN),
            'slug'  => 'color-5',
            'color' => ysp_get_option('color-5'),
        ),
        array(
            'name'  => __('Color 6', YSP_TEXT_DOMAIN),
            'slug'  => 'color-6',
            'color' => ysp_get_option('color-6'),
        ),
        array(
            'name'  => __('Color 7', YSP_TEXT_DOMAIN),
            'slug'  => 'color-7',
            'color' => ysp_get_option('color-7'),
        ),
        array(
            'name'  => __('Color 8', YSP_TEXT_DOMAIN),
            'slug'  => 'color-8',
            'color' => ysp_get_option('color-8'),
        ),
        array(
            'name'  => __('Color 9', YSP_TEXT_DOMAIN),
            'slug'  => 'color-9',
            'color' => ysp_get_option('color-9'),
        ),
        array(
            'name'  => __('Color 10', YSP_TEXT_DOMAIN),
            'slug'  => 'color-0',
            'color' => ysp_get_option('color-0'),
        ),
        array(
            'name'  => __('Gray 1', YSP_TEXT_DOMAIN),
            'slug'  => 'gray-1',
            'color' => ysp_get_option('gray-1'),
        ),
        array(
            'name'  => __('Gray 2', YSP_TEXT_DOMAIN),
            'slug'  => 'gray-2',
            'color' => ysp_get_option('gray-2'),
        ),
        array(
            'name'  => __('Gray 3', YSP_TEXT_DOMAIN),
            'slug'  => 'gray-3',
            'color' => ysp_get_option('gray-3'),
        ),
        array(
            'name'  => __('Gray 4', YSP_TEXT_DOMAIN),
            'slug'  => 'gray-4',
            'color' => ysp_get_option('gray-4'),
        ),
        array(
            'name'  => __('Gray 5', YSP_TEXT_DOMAIN),
            'slug'  => 'gray-5',
            'color' => ysp_get_option('gray-5'),
        ),
        array(
            'name'  => __('White', YSP_TEXT_DOMAIN),
            'slug'  => 'white',
            'color' => '#fff',
        ),
        array(
            'name'  => __('Black', YSP_TEXT_DOMAIN),
            'slug'  => 'black',
            'color' => '#000',
        ),
    )
);

// Add support for responsive embedded content.
add_theme_support('responsive-embeds');