<?php
/**
 * Custom Buttons
 * ex:  [ysp_button class="c-button--small,c-button--large,c-button--primary,c-button--secondary,c-button--tertiary" link="http://www...." label="button label"].
 *
 * @param array $atts an associative array of attributes, or an empty string if no attributes are given
 *
 * @return string
 */
if (!function_exists('ysp_buttons_shortcode')) {
    function ysp_buttons_shortcode( $atts ) {
        $options = shortcode_atts(
            array(
                'btn_url'       =>  '',
                'btn_label'     =>  '',
                'btn_color'     =>  '',
                'btn_outline'   =>  '',
                'btn_round'     =>  '',
                'btn_aspect'    =>  '',
                'btn_size'      =>  '',
                'btn_align'     =>  '',
                'btn_class'     =>  '',
                'onclick'       =>  '',
                'icon_name'     =>  '',
                'icon_prefix'   =>  '',
                'icon_size'     =>  '',
                'icon_color'    =>  '',
                'icon_class'    =>  '',
                'icon_position' =>  '',
                'anim_data'     =>  '',
                'margin'        =>  '',
                'padding'       =>  '',
            ), $atts
        );

        // Use standard button color
        if ($options['btn_color'] == '') {
            $options['btn_color'] = get_theme_mod('components-default-button-color', ysp_customizer_defaults('components-default-button-color'));
        }

        // Button URL
        $link = ' href="#"';
        $link_list = '';
        if ( $options['btn_url'] ) {
            $link_list = ysp_generate_url_param_list($options['btn_url']);
            $link = $link_list ? $link_list : '';
        }

        // Button Outline
        if ( !empty( $options['btn_color'] ) && $options['btn_outline'] ) {
            $options['btn_color'] = substr_replace($options['btn_color'], 'outline-', 10, 0);
        } else if ( empty( $options['btn_color'] ) && $options['btn_outline'] ) {
            $options['btn_color'] = 'c-button--outline';
        } else {
            // DEFAULT
        }

        // Button Round
        $btn_round = '';
        if ( $options['btn_round'] ) {
            // Button Round // Legacy
            if ( $options['btn_round'] === 'yes' ) {
                $btn_round = 'c-button--round';
            }
            // Button Pill
            if( $options['btn_round'] === 'pill' ) {
                $btn_round = 'c-button--pill';
            }
        }

        // Button Icon
        $icon_position = '';
        if ( $options['icon_name'] ) {
            if ( $options['icon_position'] === 'start' ) {
                $icon_position = 'c-button__icon--start';
            } else if ( $options['icon_position'] !== 'start' && $options['icon_position'] !== 'as_label' ) {
                $icon_position = 'c-button__icon--end';
            }
        }

        // Button Classes
        $styleClass = ysp_getExtraClass(
            array(
                $options['btn_class'],
                $options['btn_color'],
                $options['btn_size'],
                $btn_round,
                $options['btn_aspect'],
                $options['btn_align'],
                $icon_position,
                $options['margin'],
                $options['padding'],
            )
        );   

        // Button Icon Class
        $btn_icon_class = ysp_getExtraClass(
            array(
                'c-button__icon',
                $options['icon_class'],
            )
        );
            
        // Icon Args
        $icon_args = array(
            'icon_name' => $options['icon_name'],
            'icon_prefix' => $options['icon_prefix'],
            'icon_size' => $options['icon_size'],
            'icon_color' => $options['icon_color'],
            'icon_class' => $btn_icon_class,
        );

        // Run Button Icon
        $btn_icon = ysp_run_icon($icon_args);
        
        // Button Label
        if ( $options['btn_label'] ) {
            $btn_label = do_shortcode( $options['btn_label'] );
        } else if ( $link_list ) {
            $btn_label = vc_build_link($options['btn_url'])['title'];
        } else {
            $btn_label = '';
        }
        
        // Icon Position
        $btn_end = $btn_icon;
        $btn_start = '';
        if ( $options['icon_position'] === 'start' ) {
            $btn_end = '';
            $btn_start = $btn_icon;
        } else if ( $options['icon_position'] === 'as_label' ) {
            $btn_end = '';
            $btn_start = '';
            $btn_label = $btn_icon; // Replace Button Label with Icon
        }

        // Onclick
        $on_click = $options['onclick'] ? ' onclick="'. $options['onclick'] .'"' : '';

        // Animate
        $anim = $options['anim_data'] ? ' data-animate="'. $options['anim_data'] .'"' : '';

        // Output
        $output = '';

        if ( $btn_label ) {
            $output = '<a class="c-button'. $styleClass .'" '. $link . $on_click . $anim .'>'. $btn_start . $btn_label . $btn_end .'</a>';
        }

        if ( $options['btn_align'] === 'c-button--center' ) {
            $output = '<div class="c-button-holder c-button-holder--center">'. $output .'</div>';
        }

        if ( $options['btn_align'] === 'c-button--right' ) {
            $output = '<div class="c-button-holder c-button-holder--right">'. $output .'</div>';
        }

        return $output;
    }
}