<?php

if (!function_exists('ysp_hero_block_shortcode')) {
    function ysp_hero_block_shortcode( $atts, $content = null ) {

        $options = shortcode_atts(
            array(
                'title'             => false,
                'title_size'        => false,
                'title_font_weight' => false,
                'title_color'       => 'u-text-color-body',
                'sub_title'         => false,
                'sub_title_size'    => false,
                'sub_title_font_weight' => false,
                'sub_title_color'   => 'u-text-color-body',
                'hero_height'       => false,
                'horizontal_align'  => '',
                'vertical_align'    => '',
                'content_width'     => 'default',
                'class'             => '',
                'url'               => '',
                'img_id'            => false,
                'img_size'          => 'full',
                'img_behave'        => false,
                'img_pos'           => false,
                'video_url'         => false,
                'video_media_id'    => false,
                'overlay_filter'    => false,
                'overlay_color'     => false,
                'text_shadow'       => false,
            ),
            $atts,
            'ysp_hero_block'
        );
        
        $output       = '';
        $video        = '';
        $bg_image_url = '';
        $bg_img       = '';

        // Generate bg image
        if ( $options['img_id'] && is_numeric( $options['img_id'] ) ) { // Make sure we have numeric value
            $bg_image_url = wp_get_attachment_image_url( $options['img_id'], $options['img_size'] );
            $bg_img = ' style="background-image:url('. $bg_image_url .');"';
        }

        $video_url = $options['video_url'];
        if ( ! empty( $video_url ) && ! $options['video_media_id'] ) {
            if ( ! empty( ysp_get_video_type($video_url) ) ) {
                // YouTube
                if ( ysp_get_video_type($video_url) == 'youtube' ) {
                    $video_id = ysp_extract_youtube_id( $video_url );
                    $video = '<span class="ysp-ytube-video ysd-bg-video" data-video-bg-id="'. $video_id .'"></span>';
                    wp_enqueue_script( 'ysp_vc_yt_bg' );
                }
                // Vimeo
                if ( ysp_get_video_type($video_url) == 'vimeo' ) {
                    $video_id = ysp_extract_vimeo_id( $video_url );
                    $video = '<span class="ysp-vimeo-video ysd-bg-video" data-video-bg-id="'. $video_id .'"></span>';
                    wp_enqueue_script( 'ysp_vc_vimeo_bg' );
                }
            }
        }

        if ( is_numeric( $options['video_media_id'] ) ) {
            $video  = '<div class="ysp-bg-video-wrapper"><video playsinline autoplay muted loop ';
            $video .= $bg_image_url ? 'poster="'. $bg_image_url .'" ' : '';
            $video .= 'class="ysp-bg-video">';
            $video .= '<source src="'. wp_get_attachment_url( $options['video_media_id'] ) .'" type="video/mp4"></video></div>';
            wp_enqueue_script( 'ysp_vc_yt_bg' );
        }

        $title_class = ysp_getExtraClass(
            array(
                'c-hero-block__title',
                $options['title_color'] ? $options['title_color'] : '',
                $options['title_size'] ? $options['title_size'] : '',
                $options['title_font_weight'] ? $options['title_font_weight'] : '',
            ),
            true
        );

        $subtitle_class = ysp_getExtraClass(
            array(
                'c-hero-block__sub-title',
                $options['sub_title_color'] ? $options['sub_title_color'] : '',
                $options['sub_title_size'] ? $options['sub_title_size'] : '',
                $options['sub_title_font_weight'] ? $options['sub_title_font_weight'] : '',
            ),
            true
        );

        $title    = $options['title'] ? '<h2 class="'. $title_class .'">'. $options['title'] .'</h2>' : '';
        $subtitle = $options['sub_title'] ? '<p class="'. $subtitle_class .'"> '. $options['sub_title'] .'</p>' : '';

        $has_video = $video ? 'c-hero-block--video vc_video-bg-container' : '';

        // Add custom class
        $css_class = ysp_getExtraClass(
            array(
                'c-hero-block',
                $options['hero_height'] ? 'c-hero-block--height-'. $options['hero_height'] : '',
                $options['content_width'] ? 'c-hero-block-size-'. $options['content_width'] : '',
                $has_video,
                $options['class'] ? $options['class'] : '',
                $options['overlay_filter'] ? 'has-overlay-filter-'. $options['overlay_filter'] : '',
                $options['overlay_color'] ? 'has-overlay-color-'. $options['overlay_color'] : '',
                $options['text_shadow'] ? 'has-text-shadow' : '',
                $options['img_behave'] ? $options['img_behave'] : '',
                $options['img_pos'] ? $options['img_pos'] : '',
            ),
            true
        );

        // Add custom class
        $css_inner_class = ysp_getExtraClass(
            array(
                $options['vertical_align'] ? $options['vertical_align'] : '',
                $options['horizontal_align'] ? $options['horizontal_align'] : '',
            ),
            false
        );

        // URL
        $link_start = $link_end = '';
        if ( $options['url'] ) {
            $link_list = ysp_generate_url_param_list( $options['url'] );
            if ( $link_list ){
                $link_start = '<a class="c-hero-block__link"'. $link_list .'>';
                $link_end = '</a>';
            }
        }

        $content = $content ? '<div class="c-hero-block__content">'. do_shortcode( $content ) .'</div>' : '';

        // Output
        $output = '<div class="'. $css_class .'"'. $bg_img .'>'. $video . $link_start .'<div class="c-hero-block__wrapper"><div class="c-hero-block__inner'. $css_inner_class .'"><div class="c-hero-block__limiter">'. $title . $subtitle . $content .'</div></div></div>'. $link_end .'</div>';

        return $output;
    }
}