<?php

/**
 * 5 Image.
 *
 * @param array  $atts    an associative array of attributes, or an empty string if no attributes are given
 * @param string $content the enclosed content
 *
 * @return string
 */
if (!function_exists('ysp_image_shortcode')) {
    function ysp_image_shortcode($atts, $content = null) {
        $options = shortcode_atts(
            array(
                'image_id'          => false,
                'image_url'         => '',
                'image_size'        => 'full',
                'add_img_sizes'     => '',
                'object_fit'        => '',
                'image_alt'         => '',
                'wrap_class'        => '',
                'class'             => '',
                'url'               => '',
                'url_class'         => '',
                'onclick'           => '',
                'img_height'        => '',
                'auto_height'       => 'yes',
                'margin'            => '',
                'padding'           => '',
                'anim_data'         => '',
            ), $atts
        );

        // Animate
        $anim = $options['anim_data'] ? ' data-animate="'. $options['anim_data'] .'"' : '';

        // Object Fit
        $object_fit = $options['object_fit'] ? 'u-object-fit-'. $options['object_fit'] : '';

        // Image Height
        $img_height = $options['auto_height'] != 'yes' && $options['img_height'] ? $options['img_height'] : '';

        // Image Classes
        $image_class = ysp_getExtraClass(
            array(
                'c-image-tag',
                $object_fit,
                $img_height,
                $options['class'],
                $options['margin'],
                $options['padding'],
            ),
            true
        );

        // Image Alt
        $image_alt_fb = get_post_meta( $options['image_id'], '_wp_attachment_image_alt', true );
        $image_title  = get_the_title( $options['image_id'] );
        
        $image_alt = '';
        if ( !empty( $options['image_alt'] ) ) {
            $image_alt = $options['image_alt'];
        } else if ( !empty( $image_alt_fb ) ) {
            $image_alt = $image_alt_fb;
        } else if ( !empty( $image_title ) ) {
            $image_alt = $image_title;
        }

        // Image Output
        $image = wp_get_attachment_image(
            $options['image_id'],
            $options['image_size'],
            '',
            array(
                'class' => $image_class,
                'alt' => $image_alt,
            )
        );

        if (!empty($options['image_url'])) {
            $image = '<img class="'.$image_class.'" alt="'.$image_alt.'" src="'.$options['image_url'].'" />';
        }

        // URL
        $has_link = false;
        if ( $options['url'] ) {
            $link_list = ysp_generate_url_param_list( $options['url'] );
            if ( $link_list ){
                $has_link = true;
                $link = $link_list;
            }
        }

        // URL Class
        $url_class = $options['url_class'] ? 'class="'. $options['url_class'] .'" ' : '';
        
        // On Click
        $on_click = $options['onclick'] ? ' onclick="'. $options['onclick'] .'"' : '';

        // Auto Height
        $auto_height = $options['auto_height'] == 'yes' ? 'c-image--auto-height' : '';

        // Wrap Class
        $wrap_class = $options['wrap_class'] ? $options['wrap_class'] : '';

        // Image Classes
        $img_class = ysp_getExtraClass(
            array(
                'c-image',
                $auto_height,
                $wrap_class,
            ),
            true
        );

        // Output
        $output = '';
        if ( $has_link ) {
            $output = sprintf('<a %s%s%s>%s</a>', 
                $url_class,
                $link,
                $on_click,           
                $image
            );
        } else {
            $output = $image;
        }

        return '<div class="'. $img_class .'"'. $anim .'>'. $output .'</div>';
    }
}