<?php

/**
 * 1 Row Item Markup
 * ex. [ysp_row class="lap-and-up..." wrapper="false" wrapper_class="custom-class"].
 *
 * @param array  $atts    an associative array of attributes, or an empty string if no attributes are given
 * @param string $content the enclosed content
 *
 * @return string
 */
if (!function_exists('ysp_row_shortcode')) {
    function ysp_row_shortcode($atts, $content = null) {
        $options = shortcode_atts(
            array(
                'class' => '',
                'wrapper' => '',
                'wrapper_size' => '',
                'wrapper_class' => '',
                'holder_img' => '',
                'holder_class' => '',
                'holder_id' => '',
                'holder_img_size' => 'full',
                'background' => '',
                'use_parallax' => false,
                'holder_margin' => '',
                'holder_padding' => '',
                'holder_img_pos' => '',
                'holder_bg_fx' => '',
                'row_v_align' => '',
                'row_h_align' => '',
                'row_adjust' => '',
                'grid_col_full_height' => '',
                'grid_col_equal_height' => '',
                'row_align' => '',
                'v_bg' => '',
                'v_youtube' => '',
                'v_hosted' => '',
                'v_hosted_mobile' => '',
                'v_placeholder' => '',
                'video_bg' => '',
                'hosted_video' => '',
                'tube_video' => '',
            ), $atts
        );

        $v_bg = $v_youtube = $v_hosted = $v_hosted_mobile = $v_placeholder = $video_bg = $hosted_video = $tube_video = $wrapper = $css_class = $background = '';

        $holder_start = $holder_end = '';
        $wrapper_start = $wrapper_end = '';
        $output = '';

        $css_classes = array();

        $has_tube_bg = (!empty($options['v_bg']) && !empty($options['v_youtube']) && ysp_extract_youtube_id($options['v_youtube']));
        $has_hosted_bg = (!empty($options['v_bg']) && !empty($options['v_hosted']));

        if ($has_tube_bg && ysp_extract_youtube_id($options['v_youtube'])) {
            // $parallax_image = $options['v_youtube'];
            $css_classes[] = 'vc_video-bg-container';
            $tube_video = '<span class="ysp-ytube-video" data-video-bg-id="'.ysp_extract_youtube_id($options['v_youtube']).'"></span>';
        }

        if ($has_hosted_bg) {
            $hosted_video = '<div class="ysp-bg-video-wrapper"><video playsinline autoplay muted loop ';
            $hosted_video .= wp_get_attachment_url($options['v_placeholder']) ? 'poster="'.wp_get_attachment_url($options['v_placeholder']).'" ' : '';
            $hosted_video .= 'class="ysp-bg-video">';
            $hosted_video .= '<source src="'.wp_get_attachment_url( $v_hosted ).'" type="video/mp4" data-mobile="'. wp_get_attachment_url( $v_hosted_mobile ) .'"></video></div>';
        }

        if ($has_tube_bg || $has_hosted_bg) {
            $video_bg = $has_tube_bg ? $tube_video : $hosted_video;
            wp_enqueue_script('ysp_vc_video_bg');
        }

        // Layout Classes
        $class = ysp_getExtraClass(
            array(
                $options['class'],
                $options['row_v_align'],
                $options['row_h_align'],
                $options['row_align'],
                $options['row_adjust'],
                $options['grid_col_equal_height'] ? ysp_getExtraClass('c-row--equal-height') : '',
                $options['grid_col_full_height'] ? ysp_getExtraClass('c-row--full-height') : '',
            )
        );

        // Holder Classes
        $class_h = ysp_getExtraClass(
            array(
                $options['video_bg'] ? ysp_getExtraClass('c-holder--video') : '',
                $options['holder_class'],
                $options['holder_img_pos'],
                $options['holder_bg_fx'],
                $options['holder_margin'],
                $options['holder_padding'],
            )
        );

        // Wrapper Classes
        $container = $options['wrapper'];
        $wrapper_size = $options['wrapper_size'] ? ' '. $options['wrapper_size'] : '';

        // Holder ID
        $row_id = $options['holder_id'] ? ' id="'.$options['holder_id'].'" ' : '';

        if ($options['holder_img'] && !$has_hosted_bg) {
            $image = wp_get_attachment_image_src($options['holder_img'], $options['holder_img_size'], false);
            $background = $image ? " style='background-image:url({$image[0]});'" : '';

            if ($options['use_parallax']) {
                wp_enqueue_script('ysp_parallax'); // Registered in functions
                $background = $image ? " data-parallax=\"scroll\" data-image-src=\"{$image[0]}\"" : '';
                $class_h .= ysp_getExtraClass('parallax-window');
            }
        }

        if ( $background || $class_h || $row_id || $video_bg ) {
            $holder_start = '<div '. $row_id .'class="c-holder'. $class_h .'"'. $background .'>'. $video_bg;
            $holder_end = '</div>';
        }

        if ( $container ) {
            $wrapper_start = '<div class="'. $container . $wrapper_size .'">';
            $wrapper_end = '</div>';
        } else {
            $wrapper_start = '<div class="c-no-container">';
            $wrapper_end = '</div>';
        }

        $css_classes = array(
            'c-row',
            $class,
        );

        $css_class = preg_replace('/\s+/', ' ', implode(' ', array_filter(array_unique($css_classes))));

        $output .= $holder_start;
            $output .= $wrapper_start;
                $output .= '<div class="'. esc_attr(trim($css_class)) .'">';
                    $output .= ysp_remove_wpautop($content, true);
                $output .= '</div>';
            $output .= $wrapper_end;
        $output .= $holder_end;

        return $output;
    }
}