<?php

/*
 * Swiper Slider
 */
if ( ! function_exists( 'ysp_swiper_slider_shortcode' ) ) {
    function ysp_swiper_slider_shortcode( $atts, $content = null ){
        
        $options = shortcode_atts(
            array(
                'slider_slides'           => '4',
                'slider_slides_lg'        => '2',
                'slider_slides_md'        => '1',
                'slider_slides_sm'        => '1',
                'slider_slides_xs'        => '1',
                'slider_height'           => '',
                'slider_autoplay'         => 'false',
                'slider_speed'            => '5000',
                'slider_loop'             => 'false',
                'slider_space'            => '16',
                'slider_effect'           => 'slide',
                'slider_navigation'       => true,
                'slider_navigation_color' => false,
                'slider_pagination'       => true,
                'slider_pagination_type'  => 'bullets',
                'slider_pagination_color' => false,
                'class' => '',
            ),
            $atts,
            'ysp_swiper_slider'
        );

        $output = '';
        $slider_height = $options['slider_height'] ? 'c-swiper-slider--height-'. $options['slider_height'] : '';

        // Let's say you want multiple sliders on one page. Then all those sliders require a unique ID, otherwise javascript will sh*t itself.
        $random_id = substr(str_shuffle(str_repeat($x='abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ', ceil(10/strlen($x)))), 1, 10);

        // Add Custom Class
        $customCss = ysp_getExtraClass(
            array(
                $options['class'] ? ' '. $options['class'] : '',
                $slider_height,
            ),
            false
        );

        // Enqueue script and style
        wp_enqueue_script( 'ysp_swiper_slider' );
        wp_enqueue_style( 'swiper_style_core' );
        
        // Slide Output
        $slide_output = '';
        if ( $content ):
            $slide_output = do_shortcode( $content );
        else:
            $output = __('Sorry, no slides were set', YSP_TEXT_DOMAIN);
        endif;
        
        // Options
        $pagination_color = ($options['slider_pagination_color']) ? 'style="color:'. $options['slider_pagination_color'] .';"' : '';
        $navigation_color = ($options['slider_navigation_color']) ? 'style="color:'. $options['slider_navigation_color'] .';"' : '';
        $pagination = ($options['slider_pagination']) ? '<div class="swiper-pagination swiper-pagination-'.$random_id.'"'. $pagination_color .'></div>' : '';
        $navigation = ($options['slider_navigation']) ? '<div class="swiper-button-prev swiper-button-prev-'.$random_id.'"'. $navigation_color .'></div><div class="swiper-button-next swiper-button-next-'.$random_id.'"'. $navigation_color .'></div>' : '';

		// Wrap all output.
		$output = sprintf(
			'<div class="c-swiper-slider%s">
				<div class="swiper">
					<div class="swiper-container" data-id="%s" data-slides="%s" data-slides-lg="%s" data-slides-md="%s" data-slides-sm="%s" data-slides-xs="%s" data-autoplay="%s" data-speed="%s" data-loop="%s" data-space="%s" data-effect="%s" data-pagination-type="%s">
                        <div class="swiper-wrapper">%s</div>
                        %s
                        %s
				    </div>
			    </div>
			</div>',
			$customCss,
			$random_id,
            $options['slider_slides'],
            $options['slider_slides_lg'],
            $options['slider_slides_md'],
            $options['slider_slides_sm'],
            $options['slider_slides_xs'],
			$options['slider_autoplay'],
			$options['slider_speed'],
			$options['slider_loop'],
			$options['slider_space'],
			$options['slider_effect'],
			$options['slider_pagination_type'],
			$slide_output,
            $pagination,
            $navigation
		);
        
        return $output;
    }
}

/*
 * Swiper Slider Slide
 */
if ( ! function_exists( 'ysp_swiper_slider_slide_shortcode' ) ) {
    function ysp_swiper_slider_slide_shortcode( $atts, $content = null ) {
        
        $options = shortcode_atts(
        array(
            'img_id' => false,
            'img_size' => false,
            'img_behave' => false,
            'img_pos' => false,
            'video_url' => false,
            'video_media_id' => false,
            'overlay_filter' => false,
            'overlay_color' => false,
            'container' => false,
            'horizontal_align' => false,
            'link' => false,
            'class' => '',
        ), $atts, 'ysp_swiper_slider_slide');

        $output = $video = $bg_img = $link_s = $link_e = '';

        // Generate bg image
        if ( $options['img_id'] && is_numeric( $options['img_id'] ) ) { // Make sure we have numeric value
            $bg_image_url = wp_get_attachment_image_url( $options['img_id'], $options['img_size'] );
            $bg_img = ' style="background-image:url('. $bg_image_url .');"';
        }

        $video_url = $options['video_url'];
        if ( ! empty( $video_url ) && ! $options['video_media_id'] ) {
            if ( ! empty( ysp_get_video_type($video_url) ) ) {
                // YouTube
                if ( ysp_get_video_type($video_url) == 'youtube' ) {
                    $video_id = ysp_extract_youtube_id( $video_url );
                    $video = '<span class="ysp-swiper-ytube-video ysd-bg-video" data-video-bg-id="'. $video_id .'"></span>';
                    wp_enqueue_script( 'ysp_vc_yt_bg' );
                }
                // Vimeo
                if ( ysp_get_video_type($video_url) == 'vimeo' ) {
                    $video_id = ysp_extract_vimeo_id( $video_url );
                    $video = '<span class="ysp-vimeo-video ysd-bg-video" data-video-bg-id="'. $video_id .'"></span>';
                    wp_enqueue_script( 'ysp_vc_vimeo_bg' );
                }
            }
        }

        if ( is_numeric( $options['video_media_id'] ) ) {
            $video  = '<div class="ysp-bg-video-wrapper"><video playsinline autoplay muted loop ';
            $video .= $bg_image_url ? 'poster="'. $bg_image_url .'" ' : '';
            $video .= 'class="ysp-bg-video">';
            $video .= '<source src="'. wp_get_attachment_url( $options['video_media_id'] ) .'" type="video/mp4"></video></div>';
            wp_enqueue_script( 'ysp_vc_yt_bg' );
        }

        // Has video
        $has_video = $video ? 'c-swiper-slider--video vc_video-bg-container' : '';

        // Add Custom Class
        $customCss = $options['class'] ? $options['class'] : '';
        
        $slide_output = '';

        if ( $content ) {
            $slide_output = do_shortcode( $content );
        } else {
            $slide_output = __('Sorry, no slides were set', YSP_TEXT_DOMAIN);
        }

        // Slide Inner output
        $container_class = '';
        if ( $options['container'] == 'yes' ) {
            $container_class = 'u-container-max-width';
        }

        // Wrap classes
        $wrapCss = ysp_getExtraClass(
            array(
                $options['img_behave'] ? $options['img_behave'] : '',
                $options['img_pos'] ? $options['img_pos'] : '',
                $options['overlay_filter'] ? 'has-overlay-filter-'. $options['overlay_filter'] : '',
                $options['overlay_color'] ? 'has-overlay-color-'. $options['overlay_color'] : '',
                $has_video,
                $customCss,
            )
        );

        // Inner classes
        $innerCss = ysp_getExtraClass(
            array(
                $container_class,
            )
        );

        // Align classes
        $alignCss = ysp_getExtraClass(
            array(
                $options['horizontal_align'] ? $options['horizontal_align'] : '',
            )
        );

        // Link
        $link = vc_build_link( $options['link'] );
        if ( $link['url'] ) {
            $link_title = $link['title'] ? ' title="'. $link['title'] .'"' : '';
            $link_target = $link['target'] ? ' target="'. $link['target'] .'"' : '';
            $link_rel = $link['rel'] ? ' rel="'. $link['rel'] .'"' : '';
            $link_s = '<a href="'. $link['url'] .'"'. $link_title . $link_target . $link_rel .'>';
            $link_e = '</a>';
        }

        // Inner output
        $output_inner = '<div class="c-swiper-slider-slide-inner'. $innerCss .'"><div class="c-swiper-slider-slide-inner-content'. $alignCss .'">'. $link_s . $slide_output . $link_e .'</div></div>';

        // Wrap output
        $output = '<div class="c-swiper-slider-slide swiper-slide'. $wrapCss .'"'. $bg_img .'>'. $video . $output_inner .'</div>';
        
        return $output;
    }
}