<?php
/**
 * Theme Shortcodes Helpers.
 */

/**
 * @param $class
 *
 * @return string
 */
if (!function_exists('ysp_getExtraClass')) {
    function ysp_getExtraClass($class, $flush = false) {
        $output = '';
        $space = $flush ? '' : ' ';

        // Check is we get an array
        if (is_array($class)) {
            $isFirst = 0;

            foreach ($class as $css_class) {
                ++$isFirst;

                // if we have multiple values flush only the first space
                if (1 === $isFirst && $flush) {
                    $space = '';
                } else {
                    $space = ' ';
                }

                // Check if we have a valid value and field is not empty
                if (!empty($css_class)) {
                    $output .= $space.$css_class;
                }
            }
        } else {
            // Check if we have a valid value and field is not empty
            if (!empty($class)) {
                $output = $space.$class;
            }
        }

        return $output;
    }
}

// Wrap video iframe in extra field used by responsive video js
add_filter('embed_oembed_html', 'tdd_oembed_filter', 99, 4);
if (!function_exists('tdd_oembed_filter')) {
    function tdd_oembed_filter($html, $url, $attr, $post_ID)
    {
        return  '<figure class="videoWrapper">'.$html.'</figure>';
    }
}

/**
 * Extract video ID from Video url.
 *
 * @param string $url Video url
 *
 * @return string
 */
if (!function_exists('ysp_get_video_type')) {
    function ysp_get_video_type($url)
    {
        if (strpos($url, 'youtube') > 0) {
            return 'youtube';
        } elseif (strpos($url, 'vimeo') > 0) {
            return 'vimeo';
        } else {
            return 'unknown';
        }
    }
}

/**
 * Extract video ID from YouTube url.
 *
 * @param string $url YouTube url
 *
 * @return string
 */
if (!function_exists('ysp_extract_youtube_id')) {
    function ysp_extract_youtube_id($url)
    {
        parse_str(parse_url($url, PHP_URL_QUERY), $vars);

        if (!isset($vars['v'])) {
            return '';
        }

        return $vars['v'];
    }
}

/**
 * Extract video ID from Vimeo url.
 *
 * @param string $url Vimeo url
 *
 * @return string
 */
if (!function_exists('ysp_extract_vimeo_id')) {
    function ysp_extract_vimeo_id($url)
    {
        $regs = array();

        $id = '';

        if (preg_match('%^https?:\/\/(?:www\.|player\.)?vimeo.com\/(?:channels\/(?:\w+\/)?|groups\/([^\/]*)\/videos\/|album\/(\d+)\/video\/|video\/|)(\d+)(?:$|\/|\#?)(?:[?]?.*)$%im', $url, $regs)) {
            $id = $regs[3];
        }

        return $id;
    }
}

/**
 * Remove the auto-p wrap from WP
 *
 * @param string $content The content
 *
 * @return string
 */
if (!function_exists('ysp_remove_wpautop')) {
    function ysp_remove_wpautop($content, $autop = false)
    {
        if ($autop) {
            $content = wpautop(preg_replace('/<\/?p\>/', "\n", $content)."\n");
        }

        // Don’t auto-p wrap shortcodes that stand alone
        // ref: https://developer.wordpress.org/reference/functions/shortcode_unautop/
        return do_shortcode(shortcode_unautop($content));
    }
}