<?php
/**
* VC custom parameter for columns width setup
* Parameters follow the css architecture grid classes
*/

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * @property mixed data
 */
if (!class_exists('YSP_Vc_Column_Offset')) {
    class YSP_Vc_Column_Offset {
        /**
         * @var array
         */
        protected $settings = array();
        /**
         * @var string
         */
        protected $value = '';
        /**
         * @var array
         */
        protected function sizeTypes() {
            $size_types = array(
                'c-col-xxl-' =>  __('Desktop (Large)', YSP_TEXT_DOMAIN),
                'c-col-xl-' =>  __('Desktop', YSP_TEXT_DOMAIN),
                'c-col-lg-' =>  __('Laptop', YSP_TEXT_DOMAIN),
                'c-col-md-' =>  __('Tablet', YSP_TEXT_DOMAIN),
                'c-col-sm-' =>  __('Mobile (Large)', YSP_TEXT_DOMAIN),
                'c-col-'    =>  __('Mobile', YSP_TEXT_DOMAIN),
            );
            return $size_types;
        }
        /**
         * @var array
         */
        protected $column_width_list = array();

        /**
         * @param $settings
         * @param $value
         */
        public function __construct( $settings, $value ) {
            $this->settings = $settings;
            $this->value = $value;

            $this->column_width_list = array(
                __( '1 column - 1/12', YSP_TEXT_DOMAIN )        => '1',
                __( '2 columns - 1/6', YSP_TEXT_DOMAIN )        => '2',
                __( '3 columns - 1/4', YSP_TEXT_DOMAIN )        => '3',
                __( '4 columns - 1/3', YSP_TEXT_DOMAIN )        => '4',
                __( '5 columns - 5/12', YSP_TEXT_DOMAIN )       => '5',
                __( '6 columns - 1/2', YSP_TEXT_DOMAIN )        => '6',
                __( '7 columns - 7/12', YSP_TEXT_DOMAIN )       => '7',
                __( '8 columns - 2/3', YSP_TEXT_DOMAIN )        => '8',
                __( '9 columns - 3/4', YSP_TEXT_DOMAIN )        => '9',
                __( '10 columns - 5/6', YSP_TEXT_DOMAIN )       => '10',
                __( '11 columns - 11/12', YSP_TEXT_DOMAIN )     => '11',
                __( '12 columns - 1/1', YSP_TEXT_DOMAIN )       => '12',
            );
        }

        /**
         * @return string
         */
        public function render() {
            ob_start();
            ysp_vc_offset_include_template( array(
                'settings'      => $this->settings,
                'value'         => $this->value,
                'data'          => $this->valueData(),
                'sizes'         => $this->sizeTypes(),
                'param'         => $this,
            ) );

            return ob_get_clean();
        }

        /**
         * @return array|mixed
         */
        public function valueData() {
            if ( ! isset( $this->data ) ) {
                $this->data = preg_split( '/\s+/', $this->value );
            }

            return $this->data;
        }

        /**
         * @param $size
         *
         * @return string
         */
        public function sizeControl( $size ) {
            $empty_label = 'c-col-lg-' === $size ? __( 'Default value from width attribute', YSP_TEXT_DOMAIN ) : __( 'Inherit from smaller', YSP_TEXT_DOMAIN );
            $output = '<select name="ysp_vc_col_size_' . $size . '" class="ysp_vc_column_offset_field" data-type="size-' . $size . '">' . '<option value="" style="color: #ccc;">' . $empty_label . '</option>';
            foreach ( $this->column_width_list as $label => $index ) {
                $value = $size . $index;
                $output .= '<option value="' . $value . '"' . ( in_array( $value, $this->data ) ? ' selected="true"' : '' ) . '>' . $label . '</option>';
            }
            $output .= '</select>';

            return $output;
        }
    }
}

/**
 * @param $settings
 * @param $value
 *
 * @return string
 */
if (!function_exists('ysp_vc_column_offset_form_field')) {
    function ysp_vc_column_offset_form_field( $settings, $value ) {
        $column_offset = new YSP_Vc_Column_Offset( $settings, $value );

        return $column_offset->render();
    }
}

/**
 * Hook Column Settings to Element
 */
if (!function_exists('ysp_vc_load_column_offset_param')) {
    function ysp_vc_load_column_offset_param() {
        vc_add_shortcode_param( 'ysp_column_offset', 'ysp_vc_column_offset_form_field', get_template_directory_uri() . '/inc/components/visual-composer/js/ysp_width.js' );
    }
}
//vc_add_shortcode_param( 'ysp_column_offset', 'ysp_vc_column_offset_form_field' );
add_action( 'vc_load_default_params', 'ysp_vc_load_column_offset_param' );