<?php
/**
* VC custom parameter for hero height setup
* Parameters follow the css architecture grid classes
*/

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * @property mixed data
 */
if (!class_exists('YSP_Vc_Hero_Height')) {
    class YSP_Vc_Hero_Height {
        /**
         * @var array
         */
        protected $settings = array();
        /**
         * @var string
         */
        protected $value = '';
        /**
         * @var array
         */
        protected function sizeTypes() {
            $size_types = array(
                'c-hero-block--height-xl-'  =>  __('Desktop', YSP_TEXT_DOMAIN),
                'c-hero-block--height-lg-'  =>  __('Laptop', YSP_TEXT_DOMAIN),
                'c-hero-block--height-md-'  =>  __('Tablet', YSP_TEXT_DOMAIN),
                'c-hero-block--height-sm-'  =>  __('Mobile (Large)', YSP_TEXT_DOMAIN),
                'c-hero-block--height-'     =>  __('Mobile', YSP_TEXT_DOMAIN),
            );
            return $size_types;
        }
        /**
         * @var array
         */
        protected $hero_height_list = array();

        /**
         * @param $settings
         * @param $value
         */
        public function __construct( $settings, $value ) {
            $this->settings = $settings;
            $this->value = $value;

            $this->hero_height_list = array(
                __( 'Reset', YSP_TEXT_DOMAIN )  => '0',
                'XS'     => '1',
                'SM'     => '2',
                'MD'     => '3',
                'LG'     => '4',
                'XL'     => '5',
                'XXL'    => '6',
            );
        }

        /**
         * @return string
         */
        public function render() {
            ob_start();
            ysp_vc_hero_height_include_template( array(
                'settings'      => $this->settings,
                'value'         => $this->value,
                'data'          => $this->valueData(),
                'sizes'         => $this->sizeTypes(),
                'param'         => $this,
            ) );

            return ob_get_clean();
        }

        /**
         * @return array|mixed
         */
        public function valueData() {
            if ( ! isset( $this->data ) ) {
                $this->data = preg_split( '/\s+/', $this->value );
            }

            return $this->data;
        }

        /**
         * @param $size
         *
         * @return string
         */
        public function sizeControl( $size ) {
            $empty_label = $size === 'c-hero-block--height-' ? __( 'Select Hero Height', YSP_TEXT_DOMAIN ) : __( 'Inherit from smaller', YSP_TEXT_DOMAIN );
            $output = '<select name="ysp_vc_col_size_'. $size .'" class="ysp_vc_hero_height_field" data-type="size-'. $size .'">';
                $output .= '<option value="" style="color: #ccc;">'. $empty_label .'</option>';
                foreach ( $this->hero_height_list as $label => $index ) {
                    $value = $size . $index ;
                    $output .= '<option value="'. $value .'"'. ( in_array( $value, $this->data ) ? ' selected="true"' : '' ) .'>'. $label .'</option>';
                }
            $output .= '</select>';

            return $output;
        }
    }
}

/**
 * @param $settings
 * @param $value
 *
 * @return string
 */
if (!function_exists('ysp_vc_hero_height_form_field')) {
    function ysp_vc_hero_height_form_field( $settings, $value ) {
        $hero_height = new YSP_Vc_Hero_Height( $settings, $value );

        return $hero_height->render();
    }
}

/**
 * Hook Hero Height Settings to Element
 */
if (!function_exists('ysp_vc_load_hero_height_param')) {
    function ysp_vc_load_hero_height_param() {
        vc_add_shortcode_param( 'ysp_hero_height', 'ysp_vc_hero_height_form_field', get_template_directory_uri() . '/inc/components/visual-composer/js/ysp_height.js' );
    }
}
//vc_add_shortcode_param( 'ysp_hero_height', 'ysp_vc_hero_height_form_field' );
add_action( 'vc_load_default_params', 'ysp_vc_load_hero_height_param' );