<?php
/**
* VC custom parameter to apply margin css classes used in components options
*/

if ( ! defined( 'ABSPATH' ) ) {
	die( '-1' );
}

/**
 * @property mixed data
 */
if (!class_exists('YSP_Vc_Margin')) {
    class YSP_Vc_Margin {
        /**
         * @var array
         */
        protected $settings = array();
        /**
         * @var string
         */
        protected $value = '';
        /**
         * @var array
         */
        protected function sizeTypes() {
            $size_types = array(
                'u-m'   => __( 'Margin General', YSP_TEXT_DOMAIN ), // u-margin
                'u-my'  => __( 'Margin Top/Bottom', YSP_TEXT_DOMAIN ), // u-margin-vertical
                'u-mx'  => __( 'Margin Left/Right', YSP_TEXT_DOMAIN ), // u-margin-horizontal
                'u-mt'  => __( 'Margin Top', YSP_TEXT_DOMAIN ), // u-margin-top
                'u-mr'  => __( 'Margin Right', YSP_TEXT_DOMAIN ), // u-margin-right
                'u-mb'  => __( 'Margin Bottom', YSP_TEXT_DOMAIN ), // u-margin-bottom
                'u-ml'  => __( 'Margin Left', YSP_TEXT_DOMAIN ), // u-margin-left
            );
            return $size_types;
        }
        /**
         * @var array
         */
        protected $column_width_list = array();

        /**
         * @param $settings
         * @param $value
         */
        public function __construct( $settings, $value ) {
            $this->settings = $settings;
            $this->value = $value;

            $this->column_width_list = array(
                __( 'Reset', YSP_TEXT_DOMAIN )  => '-0',
                __( 'Auto', YSP_TEXT_DOMAIN )  => '-auto',
                'XS'    => '-1', // -xs
                'SM'    => '-2', // -sm
                'MD'    => '-3', // -md
                'LG'    => '-4', // -lg
                'XL'    => '-5', // -xl
                'XXL'   => '-6', // -xxl
            );
        }

        /**
         * @return string
         */
        public function render() {
            ob_start();
            ysp_vc_margin_include_template( array(
                'settings' => $this->settings,
                'value' => $this->value,
                'data' => $this->valueData(),
                'sizes' => $this->sizeTypes(),
                'param' => $this,
            ) );

            return ob_get_clean();
        }

        /**
         * @return array|mixed
         */
        public function valueData() {
            if ( ! isset( $this->data ) ) {
                $this->data = preg_split( '/\s+/', $this->value );
            }

            return $this->data;
        }

        /**
         * @param $size
         *
         * @return string
         */
        public function sizeControl( $size ) {
            if ( 'c-col-lg' === $size ) {
                return '<span class="vc_description">' . __( 'Default value from width attribute', YSP_TEXT_DOMAIN ) . '</span>';
            }
            $empty_label = '' === $size ? '' : __( 'None', YSP_TEXT_DOMAIN );
            $output = '<select name="ysp_vc_col_size_' . $size . '" class="ysp_vc_margin_field" data-type="size-' . $size . '">' . '<option value="" style="color: #ccc;">' . $empty_label . '</option>';
            foreach ( $this->column_width_list as $label => $index ) {
                $value = $size . $index;
                $output .= '<option value="' . $value . '"' . ( in_array( $value, $this->data ) ? ' selected="true"' : '' ) . '>' . $label . '</option>';
            }
            $output .= '</select>';

            return $output;
        }
    }
}

/**
 * @param $settings
 * @param $value
 *
 * @return string
 */
if (!function_exists('ysp_vc_margin_form_field')) {
    function ysp_vc_margin_form_field( $settings, $value ) {
        $margin = new YSP_Vc_Margin( $settings, $value );

        return $margin->render();
    }
}

/**
 * Hook Margin Settings To Element
 */
if (!function_exists('ysp_vc_load_margin_param')) {
    function ysp_vc_load_margin_param() {
        vc_add_shortcode_param( 'ysp_margin', 'ysp_vc_margin_form_field', get_template_directory_uri() . '/inc/components/visual-composer/js/ysp_margin.js' );
    }
}
add_action( 'vc_load_default_params', 'ysp_vc_load_margin_param' );