<?php
/**
 * VC custom parameter to apply padding css classes used in components options
 */

if (! defined('ABSPATH') ) {
    die('-1');
}

/**
 * @property mixed data
 */
if (!class_exists('YSP_Vc_Padding')) {
    class YSP_Vc_Padding {
        /**
         * @var array
         */
        protected $settings = array();
        /**
         * @var string
         */
        protected $value = '';
        /**
         * @var array
         */
        protected function sizeTypes() {
            $size_types = array(
                'u-padding'             =>  __( 'Padding General', YSP_TEXT_DOMAIN ),
                'u-padding-vertical'    =>  __( 'Padding Top/Bottom', YSP_TEXT_DOMAIN ),
                'u-padding-horizontal'  =>  __( 'Padding Left/Right', YSP_TEXT_DOMAIN ),
                'u-padding-top'         =>  __( 'Padding Top', YSP_TEXT_DOMAIN ),
                'u-padding-right'       =>  __( 'Padding Right', YSP_TEXT_DOMAIN ),
                'u-padding-bottom'      =>  __( 'Padding Bottom', YSP_TEXT_DOMAIN ),
                'u-padding-left'        =>  __( 'Padding Left', YSP_TEXT_DOMAIN ),
            );
            return $size_types;
        }
        /**
         * @var array
         */
        protected $column_width_list = array();

        /**
         * @param $settings
         * @param $value
         */
        public function __construct( $settings, $value ) {
            $this->settings = $settings;
            $this->value = $value;

            $this->column_width_list = array(
                __( 'Reset', YSP_TEXT_DOMAIN )  =>  '-none',
                'XS'     =>  '-xs',
                'SM'     =>  '-sm',
                'MD'     =>  '-md',
                'LG'     =>  '-lg',
                'XL'     =>  '-xl',
                'XXL'    =>  '-xxl',
                '3XL'    =>  '-3xl',
            );
        }

        /**
         * @return string
         */
        public function render() {
            ob_start();
            ysp_vc_padding_include_template(
                array(
                    'settings' => $this->settings,
                    'value' => $this->value,
                    'data' => $this->valueData(),
                    'sizes' => $this->sizeTypes(),
                    'param' => $this,
                ) 
            );

            return ob_get_clean();
        }

        /**
         * @return array|mixed
         */
        public function valueData() {
            if (! isset($this->data) ) {
                $this->data = preg_split('/\s+/', $this->value);
            }

            return $this->data;
        }

        /**
         * @param $size
         *
         * @return string
         */
        public function sizeControl( $size ) {
            if ('c-col-lg' === $size ) {
                return '<span class="vc_description">' . __('Default value from width attribute', YSP_TEXT_DOMAIN) . '</span>';
            }
            $empty_label = '' === $size ? '' : __('None', YSP_TEXT_DOMAIN);
            $output = '<select name="ysp_vc_col_size_' . $size . '" class="ysp_vc_padding_field" data-type="size-' . $size . '">' . '<option value="" style="color: #ccc;">' . $empty_label . '</option>';
            foreach ( $this->column_width_list as $label => $index ) {
                $value = $size . $index;
                $output .= '<option value="' . $value . '"' . ( in_array($value, $this->data) ? ' selected="true"' : '' ) . '>' . $label . '</option>';
            }
            $output .= '</select>';

            return $output;
        }
    }
}

/**
 * @param $settings
 * @param $value
 *
 * @return string
 */
if (!function_exists('ysp_vc_padding_form_field')) {
    function ysp_vc_padding_form_field( $settings, $value ) {
        $padding = new YSP_Vc_Padding($settings, $value);

        return $padding->render();
    }
}

/**
 * Hook Padding Settings To Element
 */
if (!function_exists('ysp_vc_load_padding_param')) {
    function ysp_vc_load_padding_param() {
        vc_add_shortcode_param('ysp_padding', 'ysp_vc_padding_form_field', get_template_directory_uri() . '/inc/components/visual-composer/js/ysp_padding.js');
    }
}
add_action('vc_load_default_params', 'ysp_vc_load_padding_param');
