<?php

/**
 *   Accordion Shortcode.
 */
if (!function_exists('ysp_vc_accordion_shortcode')) {
    function ysp_vc_accordion_shortcode() {

        $params = array(
            array(
                'type' => 'checkbox',
                'heading' => __( 'Autoclose', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'autoclose',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'description' => __('Sets whether accordion items close automatically when you open the next item.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Openfirst', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'openfirst',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'description' => __('Sets whether the first accordion item is open by default. This setting will be overridden if openall is set to true.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Open All', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'openall',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'description' => __('Sets whether all accordion items are open by default. It is recommended that this setting be used with clicktoclose', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Click to close', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'clicktoclose',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'description' => __('Sets whether clicking an open title closes it', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Scroll', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'scroll',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'description' => __('Sets whether to scroll to the title when it is clicked open. This is useful if you have a lot of content within your accordion items.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Custom CSS class', YSP_TEXT_DOMAIN ),
                'param_name' => 'class',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Advanced', YSP_TEXT_DOMAIN),
                'description' => __('Sets a custom CSS class for the accordion group or individual accordion items.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __('Animation data CSS class', YSP_TEXT_DOMAIN),
                'param_name' => 'anim_data',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Animation', YSP_TEXT_DOMAIN),
                'description' => __('Add custom animation data (css class) to element. ex. animated bounce | https://github.com/daneden/animate.css', YSP_TEXT_DOMAIN),
            ),
        );

        // Register "container" content element. It will hold all your inner (child) content elements
        vc_map(
            array(
                'name' => __('Accordion', YSP_TEXT_DOMAIN),
                'base' => 'ysp_accordion',
                'description' => '',
                'as_parent' => array(
                    'only' => 'ysp_accordion_item'
                ), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
                'content_element' => true,
                'show_settings_on_create' => false,
                'is_container' => true,
                'params' => $params,
                'icon' => 'icon-wpb-ui-accordion',
                'js_view' => 'VcColumnView',
            )
        );
    }
}

/*
 * Accordion Inner Element
 */
if (!function_exists('ysp_vc_accordion_item_shortcode')) {
    function ysp_vc_accordion_item_shortcode() {

        // Add custom parameters
        $params = array();

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Title', YSP_TEXT_DOMAIN ),
            'param_name' => 'title',
            'admin_label' => true,
            'value' => '',
            'description' => __('Add the title.', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'vc_link',
            'heading' => __('URL', YSP_TEXT_DOMAIN),
            'param_name' => 'title_url',
            'value' => '',
            'description' => __('Set link', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __( 'HTML Tag', YSP_TEXT_DOMAIN ),
            'param_name' => 'tag',
            'value' => array(
                'H2'    =>  'h2',
                'H3'    =>  'h3',
                'H4'    =>  'h4',
                'H5'    =>  'h5',
            ),
            'std' => 'h4',
            'group' => esc_html__('Advanced', YSP_TEXT_DOMAIN),
            'description' => __('Set the title wrapper tag', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'CSS Class', YSP_TEXT_DOMAIN ),
            'param_name' => 'class',
            'admin_label' => true,
            'value' => '',
            'group' => esc_html__('Advanced', YSP_TEXT_DOMAIN),
            'description' => __('Add custom CSS class.', YSP_TEXT_DOMAIN),
        );

        // Plugin Check Start
        if ( class_exists('FortAwesome\FontAwesome_Loader') ) {

            /**
             * Icon Start
             */
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Icon name', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_name_start',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon name ex. coffee', YSP_TEXT_DOMAIN),
            );

            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon prefix', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_prefix_start',
                'admin_label' => true,
                'value' => array(
                    __('Solid', YSP_TEXT_DOMAIN)    =>  'fas',
                    __('Regular', YSP_TEXT_DOMAIN)  =>  'far',
                    __('Light', YSP_TEXT_DOMAIN)    =>  'fal',
                    __('Duotone', YSP_TEXT_DOMAIN)  =>  'fad',
                    __('Brands', YSP_TEXT_DOMAIN)   =>  'fab',
                ),
                'std' => 'far',
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Set the font family type', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon size', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_size_start',
                'admin_label' => true,
                'value' => ysp_icon_size(),
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon size', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon color', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_color_start',
                'admin_label' => true,
                'value' => ysp_icon_colors(),
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon color', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Extra Class', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_class_start',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Add custom CSS class.', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'checkbox',
                'heading' => __('Icon Rotate', YSP_TEXT_DOMAIN),
                'admin_label' => true,
                'param_name' => 'icon_rotate_start',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'group' => esc_html__('Icon start', YSP_TEXT_DOMAIN),
                'description' => __('Let the icon rotate on click.', YSP_TEXT_DOMAIN),
            );

            /**
             * Icon End
             */
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Icon name', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_name_end',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon name ex. coffee', YSP_TEXT_DOMAIN),
            );

            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon prefix', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_prefix_end',
                'admin_label' => true,
                'value' => array(
                    __('Solid', YSP_TEXT_DOMAIN)    =>  'fas',
                    __('Regular', YSP_TEXT_DOMAIN)  =>  'far',
                    __('Light', YSP_TEXT_DOMAIN)    =>  'fal',
                    __('Duotone', YSP_TEXT_DOMAIN)  =>  'fad',
                    __('Brands', YSP_TEXT_DOMAIN)   =>  'fab',
                ),
                'std' => 'far',
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Set the font family type', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon size', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_size_end',
                'admin_label' => true,
                'value' => ysp_icon_size(),
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon size', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon color', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_color_end',
                'admin_label' => true,
                'value' => ysp_icon_colors(),
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon color', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Extra Class', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_class_end',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Add custom CSS class.', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'checkbox',
                'heading' => __('Icon Rotate', YSP_TEXT_DOMAIN),
                'admin_label' => true,
                'param_name' => 'icon_rotate_end',
                'value' => array(
                    __('Yes', YSP_TEXT_DOMAIN) => 'yes'
                ),
                'group' => esc_html__('Icon end', YSP_TEXT_DOMAIN),
                'description' => __('Let the icon rotate on click.', YSP_TEXT_DOMAIN),
            );
        }
        // Plugin Check End

        $params[] = array(
            'type' => 'textarea_html',
            'holder' => 'div',
            'heading' => __('Content', YSP_TEXT_DOMAIN),
            'param_name' => 'content',
            'value' => __('<p>Click edit button to change the content. Click edit button to change the content. Click edit button to change the content. Click edit button to change the content. Click edit button to change the content.</p>', YSP_TEXT_DOMAIN),
        );

        vc_map(
            array(
                'name' => __('Accordion item', YSP_TEXT_DOMAIN),
                'base' => 'ysp_accordion_item',
                'content_element' => true,
                'as_child' => array(
                    'only' => 'ysp_accordion'
                ), // Use only|except attributes to limit parent (separate multiple values with comma)
                'icon' => 'vc_icon-vc-gitem-image',
                'params' => $params,
            )
        );
    }
}

// Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_ysp_accordion extends WPBakeryShortCodesContainer {}
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_ysp_accordion_item extends WPBakeryShortCode {}
}
