<?php

if (!function_exists('ysp_vc_image_shortcode')) {
    function ysp_vc_image_shortcode() {

        // Add custom parameters
        $params = [];

        $params[] = array(
            'type' => 'attach_image',
            'heading' => __( 'Select Image', YSP_TEXT_DOMAIN ),
            'holder' => 'img',
            'admin_label' => true,
            'param_name' => 'image_id',
            'value' => '',
            'description' => __('Set an image', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __( 'Image size', YSP_TEXT_DOMAIN ),
            'param_name' => 'image_size',
            'value' => ysp_image_sizes(),
            'std' => 'full',
            'description' => __('Set custom image size (Default: full)', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Select External Image (URL)', YSP_TEXT_DOMAIN ),
            'holder' => 'img',
            'admin_label' => true,
            'param_name' => 'image_url',
            'value' => '',
            'description' => __('Use an image from an external URL. This overrides the image fields above.', YSP_TEXT_DOMAIN),
        );        

        // Auto Height
        $params[] = array(
            'type' => 'checkbox',
            'heading' => __( 'Auto Height', YSP_TEXT_DOMAIN ),
            'param_name' => 'auto_height',
            'value'       => array(
                __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
            ),
            'std' => 'yes',
            'description' => __( 'If checked, above settings are being ignored.', YSP_TEXT_DOMAIN ),
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => 'Object Fit',
            'admin_label' => true,
            'param_name' => 'object_fit',
            'value' => ysp_object_fit(),
            'description' => __('Set image object-fit (Default: empty)', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Custom image alt', YSP_TEXT_DOMAIN ),
            'param_name' => 'image_alt',
            'admin_label' => true,
            'value' => '',
            'description' => __('Add a custom image alt text', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __('Custom Outer CSS class', YSP_TEXT_DOMAIN),
            'admin_label' => true,
            'param_name' => 'wrap_class',            
            'value' => '',
            'description' => __('Add custom outer class', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __('Custom CSS class', YSP_TEXT_DOMAIN),
            'admin_label' => true,
            'param_name' => 'class',            
            'value' => '',
            'description' => __('Add custom tag class', YSP_TEXT_DOMAIN)
        );

        $params[] = array(
            'type' => 'vc_link',
            'heading' => __('URL', YSP_TEXT_DOMAIN),
            'param_name' => 'url',
            'group' => esc_html__( 'Link', YSP_TEXT_DOMAIN ),
            'description' => __('Set link', YSP_TEXT_DOMAIN),
        );
        
        $params[] = array(
            'type' => 'textfield',
            'heading' => __('Custom CSS class', YSP_TEXT_DOMAIN),
            'admin_label' => true,
            'param_name' => 'url_class',
            'group' => esc_html__( 'Link', YSP_TEXT_DOMAIN ),
            'value' => '',
            'description' => __('Add custom link class', YSP_TEXT_DOMAIN)
        );
        
        $params[] = array(
            'type' => 'textfield',
            'heading' => __('Custom onclick action', YSP_TEXT_DOMAIN),
            'admin_label' => true,
            'param_name' => 'onclick',
            'group' => esc_html__( 'Link', YSP_TEXT_DOMAIN ),
            'value' => '',
            'description' => __('<small>Add custom onclick functionality</small><br/><smal>ex. event.preventDefault(); console.log(event.target);</small>', YSP_TEXT_DOMAIN),
        );

        // Responsive Height
        $params[] = array(
            'type' => 'ysp_hero_height',
            'heading' => __( 'Responsive Height', YSP_TEXT_DOMAIN ),
            'param_name' => 'img_height',
            'group' => esc_html__( 'Responsive Options', YSP_TEXT_DOMAIN ),
            'description' => __( 'Adjust height for different screen sizes. Control height and visibility settings.', YSP_TEXT_DOMAIN ),
        );

        // Add margins and paddings
        $params = array_merge( $params, ysp_vc_spacing_params() );

        // Animation
        $params[] = array(
            'type' => 'dropdown',
            'heading' => __('Animation', YSP_TEXT_DOMAIN),
            'param_name' => 'anim_data',
            'admin_label' => true,
            'value' => ysp_animations(),
            'group' => esc_html__( 'Animation', YSP_TEXT_DOMAIN ),
            'description' => __( 'Select an animation from the list. See https://animate.style', YSP_TEXT_DOMAIN )
        );

        vc_map(
            array(
                'name' => __( 'Image' , YSP_TEXT_DOMAIN),
                'base' => 'ysp_image',
                'category' => __( 'Content', YSP_TEXT_DOMAIN),
                'icon' => 'icon-wpb-single-image',
                'params' => $params    
            )
        );   
    }
}