<?php

if (!function_exists('ysp_vc_mediabox_shortcode')) {
    function ysp_vc_mediabox_shortcode() {

        // Add custom parameters
        $params = array();

        $params[] = array(
            'type' => 'attach_image',
            'heading' => __( 'Attach Image', YSP_TEXT_DOMAIN ),
            'holder' => 'img',
            'admin_label' => true,
            'param_name' => 'image_id',
            'value' => '',
            'group' => esc_html__('Image', YSP_TEXT_DOMAIN),
            'description' => __('Set an image', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __( 'Image size', YSP_TEXT_DOMAIN ),
            'param_name' => 'image_size',
            'value' => ysp_image_sizes(),
            'std' => 'full',
            'group' => esc_html__('Image', YSP_TEXT_DOMAIN),
            'description' => __('Set custom image size (Default: full)', YSP_TEXT_DOMAIN),
        );        

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Attach External Image (URL)', YSP_TEXT_DOMAIN ),
            'holder' => 'img',
            'admin_label' => true,
            'param_name' => 'image_url',
            'value' => '',
            'group' => esc_html__('Image', YSP_TEXT_DOMAIN),
            'description' => __('Use an image from an external URL. This overrides the image field above.', YSP_TEXT_DOMAIN),
        );        

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Image link', YSP_TEXT_DOMAIN ),
            'admin_label' => true,
            'param_name' => 'image_link',
            'value' => '',
            'group' => esc_html__('Image', YSP_TEXT_DOMAIN),
            'description' => __('Add custom link', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Image custom CSS class', YSP_TEXT_DOMAIN ),
            'admin_label' => true,
            'param_name' => 'image_class',
            'value' => '',
            'group' => esc_html__('Image', YSP_TEXT_DOMAIN),
            'description' => __('Add custom class', YSP_TEXT_DOMAIN),
        );

        // Plugin Check Start
        if ( class_exists('FortAwesome\FontAwesome_Loader') ) {
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Icon name', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_name',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon name ex. coffee', YSP_TEXT_DOMAIN),
            );

            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon prefix', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_prefix',
                'admin_label' => true,
                'value' => array(
                    __('Solid', YSP_TEXT_DOMAIN)    =>  'fas',
                    __('Regular', YSP_TEXT_DOMAIN)  =>  'far',
                    __('Light', YSP_TEXT_DOMAIN)    =>  'fal',
                    __('Duotone', YSP_TEXT_DOMAIN)  =>  'fad',
                    __('Brands', YSP_TEXT_DOMAIN)   =>  'fab',
                ),
                'std' => 'far',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the font family type', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon size', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_size',
                'admin_label' => true,
                'value' => ysp_icon_size(),
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon size', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon color', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_color',
                'admin_label' => true,
                'value' => ysp_icon_colors(),
                'std' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon color', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Extra Class', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_class',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Add custom CSS class.', YSP_TEXT_DOMAIN),
            );
        }
        // Plugin Check End

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __('Media Type', YSP_TEXT_DOMAIN),
            'admin_label' => true,
            'param_name' => 'type',
            'value' => array(
                __('Default', YSP_TEXT_DOMAIN)  =>  false,
                __('Flag', YSP_TEXT_DOMAIN)     =>  'o-flag',
                __('Media', YSP_TEXT_DOMAIN)    =>  'o-media',
            ),
            'group' => esc_html__('Media settings', YSP_TEXT_DOMAIN),
            'description' => __('Set media type', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __( 'Media Spacing', YSP_TEXT_DOMAIN ),
            'admin_label' => true,
            'param_name' => 'type_spacing',
            'value' => array(
                __('Default', YSP_TEXT_DOMAIN ) =>  false,
                'XS'      =>  '--xs',
                'SM'      =>  '--sm',
                'MD'      =>  '--md',
                'LG'      =>  '--lg',
                'XL'      =>  '--xl',
                'XXL'     =>  '--xxl',
                __('None', YSP_TEXT_DOMAIN)     =>  '--none',
            ),
            'group' => esc_html__('Media settings', YSP_TEXT_DOMAIN),
            'description' => __('Set elements spacing. By default the Media|Flag media type has a \'normal\' spacing. If you use the default media type there is no spacing between elements.', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'checkbox',
            'heading' => __( 'Media order reverse', YSP_TEXT_DOMAIN ),
            'param_name' => 'type_reverse',
            'value' => array(
                __('Yes', YSP_TEXT_DOMAIN) => 'yes'
            ),
            'admin_label' => true,
            'group' => esc_html__('Media settings', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'checkbox',
            'heading' => __( 'Not Responsive', YSP_TEXT_DOMAIN ),
            'param_name' => 'not_responsive',
            'value' => array(
                __('Yes', YSP_TEXT_DOMAIN) => 'yes'
            ),
            'admin_label' => true,
            'group' => esc_html__('Media settings', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'textarea_html',
            'heading' => __('Content', YSP_TEXT_DOMAIN),
            'holder' => 'div',
            'group' => esc_html__('Content', YSP_TEXT_DOMAIN),
            'param_name' => 'content',
        );

        $params[] = array(
            'type' => 'dropdown',
            'heading' => __( 'Text Color', YSP_TEXT_DOMAIN ),
            'param_name' => 'txt_color',
            'admin_label' => true,
            'value' => ysp_txt_color(),
            'std' => '',
            'group' => esc_html__('Content', YSP_TEXT_DOMAIN),
            'description' => __('Color applies to icon color also (if icon color is NOT set)', YSP_TEXT_DOMAIN),
        );

        // Only for VC UI functionality
        $params[] = array(
            'type' => 'checkbox',
            'heading' => __( 'Set Margin', YSP_TEXT_DOMAIN ),
            'param_name' => 'set_margin',
            'admin_label' => false,
            'group' => esc_html__('Margin', YSP_TEXT_DOMAIN),
        );
        /////////////////////////////////

        $params[] = array(
            'type' => 'ysp_margin',
            'heading' => __( 'Margin Settings', YSP_TEXT_DOMAIN ),
            'param_name' => 'margin',
            'admin_label' => true,
            'group' => esc_html__('Margin', YSP_TEXT_DOMAIN),
            'dependency' => array(
                'element' => 'set_margin',
                'value' => 'true'
            ),
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Mediabox wrapper class', YSP_TEXT_DOMAIN ),
            'param_name' => 'class',
            'admin_label' => true,
            'value' => '',
            'group' => esc_html__('Advanced', YSP_TEXT_DOMAIN),
            'description' => __('Add custom CSS class to mediabox wrapper.', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Media type extra class', YSP_TEXT_DOMAIN ),
            'param_name' => 'type_class',
            'admin_label' => true,
            'value' => '',
            'group' => esc_html__('Advanced', YSP_TEXT_DOMAIN),
            'description' => __('Add custom CSS class to media object.', YSP_TEXT_DOMAIN),
        );

        // Animation
        $params[] = array(
            'type' => 'dropdown',
            'heading' => __('Animation', YSP_TEXT_DOMAIN),
            'param_name' => 'anim_data',
            'admin_label' => true,
            'value' => ysp_animations(),
            'group' => esc_html__( 'Animation', YSP_TEXT_DOMAIN ),
            'description' => __( 'Select an animation from the list. See https://animate.style', YSP_TEXT_DOMAIN )
        );

        // Title
        vc_map(
            array(
                'name' => __('Mediabox', YSP_TEXT_DOMAIN),
                'base' => 'ysp_mediabox',
                'description' => __('Image text combination that can rearange itself on responsive devices', YSP_TEXT_DOMAIN),
                'category' => __('Content', YSP_TEXT_DOMAIN),
                'icon' => 'icon-wpb-toggle-small-expand',
                'params' => $params,
            )
        );
    }
}