<?php
/*
* YSP Custom column row options setup
*/

if (!function_exists('ysp_vc_row_shortcode')) {
    function ysp_vc_row_shortcode(){

        // Remove Default Parameters
        vc_remove_param( 'vc_row', 'full_width' );
        vc_remove_param( 'vc_row', 'gap' );
        vc_remove_param( 'vc_row', 'css' );
        vc_remove_param( 'vc_row', 'full_height' );
        vc_remove_param( 'vc_row', 'equal_height' );
        vc_remove_param( 'vc_row', 'columns_placement' );
        vc_remove_param( 'vc_row', 'content_placement' );
        vc_remove_param( 'vc_row', 'video_bg' );
        vc_remove_param( 'vc_row', 'parallax' );
        vc_remove_param( 'vc_row', 'el_id' );
        vc_remove_param( 'vc_row', 'el_class' );
        vc_remove_param( 'vc_row', 'video_bg_url' );
        vc_remove_param( 'vc_row', 'video_bg_parallax' );
        vc_remove_param( 'vc_row', 'parallax_image' );
        vc_remove_param( 'vc_row', 'parallax_speed_bg' );
        vc_remove_param( 'vc_row', 'parallax_speed_video' );
        vc_remove_param( 'vc_row', 'disable_element' );
        vc_remove_param( 'vc_row', 'css_animation' );
        vc_remove_param( 'vc_row', 'rtl_reverse' );
        
        // Add custom parameters
        $attributes = array(
            array(
                'type' => 'dropdown',
                'heading' => __( 'Add wrapper', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'wrapper',
                'value' => ysp_containers(),
                'std' => '',
                'description' => __('Add a container around the row. This is useful when you are using the full width template. <b>Notice</b>: use the "None" option when using the default template.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type'        => 'dropdown',
                'heading'     => __( 'Wrapper size', YSP_TEXT_DOMAIN ),
                'param_name'  => 'wrapper_size',
                'admin_label' => true,
                'value'       => ysp_container_size(),
                'std'         => '',
                'description' => __( 'Adjust the width of the wrapper, only works if wrapper is container', YSP_TEXT_DOMAIN ),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Row horizontal align', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'row_h_align',
                'value' => ysp_row_horizontal_align(),
                'std' => '',
                'description' => __('Set horizontal alignment of the grid columns', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Row vertical align', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'row_v_align',
                'value' => ysp_row_vertical_align(),
                'std' => '',
                'description' => __('Set vertical alignment of the grid columns', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Row columns spacing', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'row_adjust',
                'value' => ysp_row_adjust(),
                'std' => '',
                'description' => __('Adjust column spacing', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Text Color', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_txt_clr',
                'admin_label' => true,
                'value' => ysp_txt_color(),
                'std' => '',
                'description' => __('Text Color', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Custom row CSS class', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'class',
                'value' => '',
                'description' => __('Add optional CSS classes to the row element, classes can contain the column control classes defined in the theme css architecture', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Wrapper CSS class', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'wrapper_class',
                'value' => '',
                'description' => __('Add optional CSS class to the wrapper (if activated). Optional classes can contain background color extra paddings or any CSS rule that would apply to the wrapper. This setting requires a good knowledge of the css architecture used in the theme', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Wrapper outer CSS class', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'holder_class',
                'value' => '',
                'description' => __('Add custom class to be applied on the row outer holder element. Ex: add (predefined) class that centers the background image', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Wrapper outer ID', YSP_TEXT_DOMAIN ),
                'admin_label' => true,
                'param_name' => 'holder_id',
                'value' => '',
                'description' => __('Add unique ID to be applied on the row outer holder element.', YSP_TEXT_DOMAIN),
            ),
            // Only for VC UI functionality
            array(
                'type' => 'checkbox',
                'heading' => __( 'Wrapper Outer Margin', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_set_margin',
                'admin_label' => false,
                'value' => '',
                'group' => 'Margins/Paddings',
            ),
            /////////////////////////////////
            array(
                'type' => 'ysp_margin',
                'heading' => __( 'Wrapper Outer Margin Settings', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_margin',
                'admin_label' => true,
                'dependency' => array('element' => 'holder_set_margin', 'value' => 'true'),
                'group' => 'Margins/Paddings',
            ),
            // Only for VC UI functionality
            array(
                'type' => 'checkbox',
                'heading' => __( 'Wrapper Outer Padding', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_set_padding',
                'admin_label' => false,
                'value' => '',
                'group' => 'Margins/Paddings',
            ),
            /////////////////////////////
            array(
                'type' => 'ysp_padding',
                'heading' => __( 'Wrapper Outer Padding Settings', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_padding',
                'admin_label' => true,
                'dependency' => array('element' => 'holder_set_padding', 'value' => 'true'),
                'group' => 'Margins/Paddings',
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Background Color', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_bg_fx',
                'admin_label' => true,
                'value' => ysp_bg_color(),
                'std' => '',
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Background Color', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'attach_image',
                'heading' => __( 'Wrapper outer image', YSP_TEXT_DOMAIN ),
                'holder' => 'img',
                'admin_label' => true,
                'param_name' => 'holder_img',
                'value' => false,
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Add image to be used as a background for the current row. Limit to 1 image', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Wrapper outer image size', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_img_size',
                'admin_label' => true,
                'value' => ysp_image_sizes(),
                'std' => 'full',
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Add image to be used as a background for the current row. Limit to 1 image', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Background image behavior', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_img_behave',
                'admin_label' => true,
                'value' => ysp_bg_behavior(),
                'std' => '',
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Background image behavior settings', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __( 'Background position', YSP_TEXT_DOMAIN ),
                'param_name' => 'holder_img_pos',
                'admin_label' => true,
                'value' => ysp_bg_positions(),
                'std' => '',
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Background Image Position', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Use parallax', YSP_TEXT_DOMAIN ),
                'param_name' => 'use_parallax',
                'value' => array(
                    __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
                ),
                'admin_label' => true,
                'group' => esc_html__( 'Outer Background', YSP_TEXT_DOMAIN ),
                'description' => __('Use parallax', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Use video background', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_bg',
                'value' => array(
                    __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
                ),
                'admin_label' => true,
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('Enable Video Background', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading'     => __( 'Add a Youtube or Vimeo link', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_youtube',
                'admin_label' => true,
                'value' => '',
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __( 'Use a YouTube or Vimeo video as background (image will be used as placeholder) <br/> https://youtube.com/watch?v=LXb3EKWsInQ <br/> https://vimeo.com/51589652', YSP_TEXT_DOMAIN ),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Add self hosted video ID', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_hosted',
                'admin_label' => true,
                'value' => '',
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('See the video ID in the media library (mp4)', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Include a subtitle file', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_hosted_subtitle',
                'admin_label' => true,
                'value' => '',
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('See the subtitle ID in the media library (vtt)', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Add Self hosted Video ID (mobile)', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_hosted_mobile',
                'admin_label' => true,
                'value' => '',
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('See the video ID in the media library (mp4)', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Include a subtitle file', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_hosted_mobile_subtitle',
                'admin_label' => true,
                'value' => '',
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('See the subtitle ID in the media library (vtt)', YSP_TEXT_DOMAIN),
            ),            
            array(
                'type' => 'attach_image',
                'heading' => __( 'Video background placeholder image', YSP_TEXT_DOMAIN ),
                'param_name' => 'v_placeholder',
                'admin_label' => true,
                'value' => false,
                'std' => '',
                'group' => esc_html__( 'Outer Video', YSP_TEXT_DOMAIN ),
                'description' => __('Add a background Image for the video. (only for self hosted video)', YSP_TEXT_DOMAIN),
            ),   
            array(
                'type' => 'checkbox',
                'heading' => __( 'Equal height columns', YSP_TEXT_DOMAIN ),
                'param_name' => 'grid_col_equal_height',
                'value' => array(
                    __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
                ),
                'admin_label' => true,
                'group' => esc_html__( 'Advanced', YSP_TEXT_DOMAIN ),
                'description' => __('Make the columns inside equal their height to the tallest column', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Full-screen height row', YSP_TEXT_DOMAIN ),
                'param_name' => 'grid_col_full_height',
                'value' => array(
                    __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
                ),
                'admin_label' => true,
                'group' => esc_html__( 'Advanced', YSP_TEXT_DOMAIN ),
                'description' => __('Make the row height equal the device height.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'checkbox',
                'heading' => __( 'Disable this element', YSP_TEXT_DOMAIN ),
                'param_name' => 'disable_element',
                'value' => array(
                    __( 'Yes', YSP_TEXT_DOMAIN ) => 'yes'
                ),
                'admin_label' => true,
                'group' => esc_html__( 'Advanced', YSP_TEXT_DOMAIN ),
            ),
            array(
                'type' => 'textfield',
                'heading' => __( 'Row hook', YSP_TEXT_DOMAIN ),
                'param_name' => 'row_hook',
                'value' => '',
                'admin_label' => true,
                'group' => esc_html__( 'Advanced', YSP_TEXT_DOMAIN ),
                'description' => __('Create a hook for this row.', YSP_TEXT_DOMAIN),
            ),
            array(
                'type' => 'dropdown',
                'heading' => __('Animation', YSP_TEXT_DOMAIN),
                'param_name' => 'anim_data',
                'admin_label' => true,
                'value' => ysp_animations(),
                'group' => esc_html__( 'Animation', YSP_TEXT_DOMAIN ),
                'description' => __( 'Select an animation from the list. See https://animate.style', YSP_TEXT_DOMAIN )
            ),
        );

        vc_add_params( 'vc_row', $attributes );
        
        // Change default VC Row UI template
        vc_map_update( 'vc_row', array( 'html_template' => locate_template( 'vc_templates/vc_row.php' ) ) );
    }
}