<?php
/**
*	@since 1.4.5
*/

/**
*	Shortcodes row and column
*/
if ( !class_exists( 'Ysp_Vc_Fallback_Shortcodes' ) ) {

	class Ysp_Vc_Fallback_Shortcodes{

        /**
         * Class constructor
         * Sets up the plugin, including: textdomain, adding shortcodes, registering
         * scripts and adding buttons.
         */
        function __construct() {
            // Load text domain
            load_plugin_textdomain( YSP_TEXT_DOMAIN, false, YSP_THEME_DIR . '/languages/' );

            add_shortcode( 'vc_row', array( $this, 'ysp_vc_row_shortcode_fallback' ) );
            add_shortcode( 'vc_row_inner', array( $this, 'ysp_vc_row_inner_shortcode_fallback' ) );
            add_shortcode( 'vc_column', array( $this, 'ysp_vc_column_shortcode_fallback' ) );
            add_shortcode( 'vc_column_inner', array( $this, 'ysp_vc_column_inner_shortcode_fallback' ) );
            add_shortcode( 'vc_column_text', array( $this,' ysp_vc_column_text_shortcode_fallback' ) );
        }

        /**
         * Row shortcode
         */
        public function ysp_vc_row_shortcode_fallback($atts, $content = null) {

            $options = shortcode_atts(array(			
                'class' => '',
                'wrapper_class' => '',
                'holder_class' => '',
                'wrapper' => false,
                'holder_img' => '',
                'holder_img_size' => 'full',
                'holder_img_pos' =>'',
                'holder_bg_fx' =>'',
                'row_h_align' =>'',
                'row_v_align' =>'',
                'row_adjust' => '',
                'video_bg' => false,
                'video_bg_url' =>'',
            ), $atts );

            // Setup Defaults
            $style = $video_bg = $video_bg_url = '';
            $output = '';

            // Stack Classes
            $class = ysp_getExtraClass(
                array( 
                    $options['class'],
                    $options['row_h_align'],
                    $options['row_v_align'],
                    $options['row_adjust']
                )
            );			

            $class_h = ysp_getExtraClass(
                array(
                    $options['holder_class'],
                    $options['holder_img_pos'],
                    $options['holder_bg_fx']
                )
            );

            $container = $options['wrapper'];
            $class_w =  ysp_getExtraClass( $options['wrapper_class'] );

            $css_classes = array();

            $has_video_bg = ( ! empty( $video_bg ) && ! empty( $video_bg_url ) && vc_extract_youtube_id( $video_bg_url ) );

            if ( $has_video_bg ) {

                $parallax_image = $video_bg_url;
                $css_classes[] = 'vc_video-bg-container';
                wp_enqueue_script( 'vc_youtube_iframe_api_js' );
            }

            if ( $video_bg ) {
                $wrapper_attributes[] = 'data-vc-video-bg="' . esc_attr( $video_bg_url ) . '"';
            }

            $css_class = preg_replace( '/\s+/', ' ', implode( ' ', array_filter( array_unique( $css_classes ) ) ) );

            // Check for background Image and setup inline style
            if ( $options['holder_img'] ) {
                $image = wp_get_attachment_image_src( $options['holder_img'],$options['holder_img_size'],false );
                $style = $image ? " style='background-image:url({$image[0]});'" : '';
            }

            // Prepare Output
            $output = sprintf('%1$s%2$s<div class="c-row%3$s">%4$s</div>%5$s%6$s',
                // %1$s
                $style || $class_h ? "<div class=\"c-holder{$class_h}".esc_attr( trim( $css_class ) )."\"{$style}>" : '',
                // %2$s
                $container ? "<div class=\"{$container} .' '. {$class_w}\">" : "<div class=\"c-no-container .' '. {$class_w}\">",
                // %3$s
                $class,
                // %4$s
                do_shortcode( $content ),
                // %5$s
                $container ? "</div>" : '',
                // %6$s
                $style || $class_h ? "</div>" : ''
            );

            return $output;
        }

        /**
         * Inner Row shortcode
         */
        public function ysp_vc_row_inner_shortcode_fallback( $atts, $content = null ) {
            return $this->ysp_vc_row_shortcode_fallback( $atts, $content );
        }

        /**
         * Column shortcode
         */
        public function ysp_vc_column_shortcode_fallback( $atts, $content = null ) {
            $options = shortcode_atts( array(
                'width' => '',
                'class' => '',
                'inner'=>true,
                'inner_class'=>'',
                'row_width' => '',
                'margin'=>'',
                'padding'=>'',
                'margin_inner'=>'',
                'padding_inner'=>'',
                'inner_img' => '',
                'inner_img_size' => 'full',
                'inner_img_pos' =>'',
                'inner_bg_fx' =>'',
                'align_content_inner' => ''
            ), $atts );
        
            $style = $width = '';

            $width = $options['width'] ?  'c-col-'.ysp_wpb_translateColumnWidthToSpan($options['width']) : '';

            // Stack Classes
            $class = ysp_getExtraClass(
                array(
                    $options['class'] ?  $options['class'] : '',
                    $width,
                    $options['margin'] ?  $options['margin'] : '',
                    $options['padding'] ?  $options['padding'] : ''
                )
            );
        
            $inner_class  = ysp_getExtraClass(
                array(
                    $options['inner_class'] ?  ' '.$options['inner_class'] : '',
                    $options['margin_inner'] ?  ' '.$options['margin_inner'] : '',
                    $options['padding_inner'] ?  ' '.$options['padding_inner'] : '',
                    $options['inner_img_pos'],
                    $options['inner_bg_fx'],
                    $options['align_content_inner'],
                )
            );

            if ( $options['inner_img'] ) {
                $image = wp_get_attachment_image_src( $options['inner_img'],$options['inner_img_size'],false );
                $style = $image ? " style='background-image:url({$image[0]});'" : '';
            }
        
            /* Just fill the inner_class argument to activate, and deactivate by setting inner 
            *  to false this way you can deactivate the inner element 
            *  whithout deleting the inner_class argument
            */
        
            // Prepare Output
            $output = sprintf('<div class="col%1$s%2$s">%3$s%4$s%5$s</div>',
                // %1$s
                $class,
                // %2$s
                $options['row_width'] ?  ' '. $options['row_width'] : '',
                // %3$s
                true === $options['inner'] && '' !== $inner_class || '' !== $style ? "<div class=\"inner{$inner_class}\"{$style}>" : '',
                // %4$s
                do_shortcode( $content ),
                // %5$s
                true === $options['inner'] && '' !== $inner_class || '' !== $style ? "</div>" : ''
            );																													  
            return  $output;
        }

        /**
         * Column inner shortcode
         */
        public function ysp_vc_column_inner_shortcode_fallback($atts, $content = null) {
            return $this->ysp_vc_column_shortcode_fallback($atts, $content);
        }

        /**
         * Column Text inner shortcode
         */
        function ysp_vc_column_text_shortcode_fallback( $atts, $content = null ) {
            $options = shortcode_atts(
                array(
                    'el_class' => '',
                    'margin'=>'',
                    'padding'=>'',
                    'bg_fx'=>'',
                    'txt_color'=>'',
                    'txt_align'=>''
                ),
                $atts
            );

            // Stack Classes
            $css_class = '';
            $content = do_shortcode( $content );
            $css_class = ysp_getExtraClass( $options );

            // Prepare Output
            $output = sprintf('%1$s%2$s%3$s',
                // %1$s
                "<div class=\"c-text-block{$css_class}\">",
                // %2$s
                ysp_remove_wpautop( $content, true ),
                // %3$s
                "</div>"
            );
            return  $output;
        }
    }

    // This Extend was correct
    class Ysp_Vc_Row_Inner_Shortcodes extends Ysp_Vc_Fallback_Shortcodes {

        /**
         * Class constructor
         * Sets up the plugin, including: textdomain, adding shortcodes, registering
         * scripts and adding buttons.
         */
        function __construct() {
            add_shortcode('vc_row_inner', array($this, 'ysp_vc_row_inner_shortcode_fallback'));
        }
        var $these_atts, $these_content;		

        public function ysp_vc_row_inner_shortcode_fallback( $atts, $content = null ) {
            $this->these_atts = $atts;
            $this->these_content = $content;
            return parent::ysp_vc_row_shortcode_fallback( $atts, $content );
        }	
    }

    $Ysp_Vc_Fallback_Shortcodes = new Ysp_Vc_Fallback_Shortcodes;

}