<?php

/**
 *   Tab Shortcode.
 */
if (!function_exists('ysp_vc_tab_shortcode')) {
    function ysp_vc_tab_shortcode() {

        // Register "container" content element. It will hold all your inner (child) content elements
        vc_map(
            array(
                'name' => __('Tab', YSP_TEXT_DOMAIN),
                'base' => 'ysp_tab',
                'description' => '',
                'as_parent' => array(
                    'only' => 'ysp_tab_item'
                ), // Use only|except attributes to limit child shortcodes (separate multiple values with comma)
                'content_element' => true,
                'show_settings_on_create' => false,
                'is_container' => true,
                'params' => array(),
                'icon' => 'icon-wpb-ui-tab-content',
                'js_view' => 'VcColumnView',
            )
        );
    }
}

/*
 * Tab Item
*/
if (!function_exists('ysp_vc_tab_item_shortcode')) {
    function ysp_vc_tab_item_shortcode() {

        // Add custom parameters
        $params = array();

        $params[] = array(
            'type' => 'textfield',
            'heading' => __( 'Tab Title', YSP_TEXT_DOMAIN ),
            'param_name' => 'title',
            'admin_label' => true,
            'value' => '',
            'description' => __('Add title to tab', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'checkbox',
            'heading' => __( 'Open', YSP_TEXT_DOMAIN ),
            'param_name' => 'open',
            'admin_label' => true,
            'value' => false,
            'description' => __('If you use the \'open\' shortcode parameter in one of your tab shortcodes, ensure that you only add it to single tab as having more than one tab open within a tab group is not supported.', YSP_TEXT_DOMAIN),
        );

        $params[] = array(
            'type' => 'textarea_html',
            'heading' => __('Content', YSP_TEXT_DOMAIN),
            'holder' => 'div',
            'group' => esc_html__('Content', YSP_TEXT_DOMAIN),
            'param_name' => 'content',
        );

        // Plugin Check Start
        if ( class_exists('FortAwesome\FontAwesome_Loader') ) {
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Icon name', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_name',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon name ex. coffee', YSP_TEXT_DOMAIN),
            );

            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon prefix', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_prefix',
                'admin_label' => true,
                'value' => array(
                    __('Solid', YSP_TEXT_DOMAIN)    =>  'fas',
                    __('Regular', YSP_TEXT_DOMAIN)  =>  'far',
                    __('Light', YSP_TEXT_DOMAIN)    =>  'fal',
                    __('Duotone', YSP_TEXT_DOMAIN)  =>  'fad',
                    __('Brands', YSP_TEXT_DOMAIN)   =>  'fab',
                ),
                'std' => 'far',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the font family type', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon size', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_size',
                'admin_label' => true,
                'value' => ysp_icon_size(),
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon size', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'dropdown',
                'heading' => __('Icon color', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_color',
                'admin_label' => true,
                'value' => ysp_icon_colors(),
                'std' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Set the icon color', YSP_TEXT_DOMAIN),
            );
            
            $params[] = array(
                'type' => 'textfield',
                'heading' => __('Extra Class', YSP_TEXT_DOMAIN),
                'param_name' => 'icon_class',
                'admin_label' => true,
                'value' => '',
                'group' => esc_html__('Icon', YSP_TEXT_DOMAIN),
                'description' => __('Add custom CSS class.', YSP_TEXT_DOMAIN),
            );
        }
        // Plugin Check End

        vc_map(
            array(
                'name' => __('Tab item', YSP_TEXT_DOMAIN),
                'base' => 'ysp_tab_item',
                'content_element' => true,
                'as_child' => array('only' => 'ysp_tab'), // Use only|except attributes to limit parent (separate multiple values with comma)
                'icon' => 'vc_icon-vc-gitem-image',
                'params' => $params,
            )
        );
    }
}

// Your "container" content element should extend WPBakeryShortCodesContainer class to inherit all required functionality
if ( class_exists( 'WPBakeryShortCodesContainer' ) ) {
    class WPBakeryShortCode_ysp_tab extends WPBakeryShortCodesContainer {}
}

if ( class_exists( 'WPBakeryShortCode' ) ) {
    class WPBakeryShortCode_ysp_tab_item extends WPBakeryShortCode {}
}
