<?php
/**
* Helper functions that ease population of component options
* Functions that return arrays with prepopulated data
* @since 1.4.4
*/

/**
 * Returns array of image sizes
 * @todo: change image sizes options
 *
 */
if (!function_exists('ysp_image_sizes')) {
    function ysp_image_sizes() {
        global $_wp_additional_image_sizes;

        $sizes = array();
        $output = array();

        $get_sizes = get_intermediate_image_sizes();
        array_unshift( $get_sizes, 'full' );
        $get_sizes = array_combine( $get_sizes, $get_sizes );

        foreach ( $get_sizes as $_size ) {

            if ( in_array( $_size, array('full', 'thumbnail', 'medium', 'medium_large', 'large') ) ) {
                $sizes[ $_size ]['width']  = get_option( "{$_size}_size_w" );
                $sizes[ $_size ]['height'] = get_option( "{$_size}_size_h" );
                $sizes[ $_size ]['crop']   = (bool) get_option( "{$_size}_crop" );
            } elseif ( isset( $_wp_additional_image_sizes[ $_size ] ) ) {
                $sizes[ $_size ] = array(
                    'width'  => $_wp_additional_image_sizes[ $_size ]['width'],
                    'height' => $_wp_additional_image_sizes[ $_size ]['height'],
                    'crop'   => $_wp_additional_image_sizes[ $_size ]['crop'],
                );
            }
        }

        foreach ( $sizes as $image_size => $image_size_data ) {

            $crop = $height = $width = ''; 

            // Create image size name
            $img_size_name = str_replace("_"," ", ucwords( $image_size ) );

            // If image size is not full
            if ( $image_size_data['height'] != false && $image_size_data['width'] != false ) {

                $height = $image_size_data['height'] === '0' ? 'auto' : $image_size_data['height'];
                $width = $image_size_data['width'] === '0' ? 'auto' : $image_size_data['width'];

                $img_size_name .= ' ('. $width .' x '. $height.')';
        }

        // Croop info
        // if ( is_array( $image_size_data['crop'] ) ) {
        //     $crop = 'true '.$image_size_data['crop'][0].'-'.$image_size_data['crop'][0];
        // } else {
        //     $crop = $image_size_data['crop'] ? 'true auto' : 'false';
        // }
            $output[$img_size_name] =  $image_size; 
        }
        return $output;
    }
}

/**
 * Returns array of object fit options
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_object_fit' ) ) {
	function ysp_object_fit() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )    => '',
            'Contain'                           => 'contain',
            'Cover'                             => 'cover',
            'Fill'                              => 'fill',
            'Inherit'                           => 'inherit',
            'Initial'                           => 'initial',
            'None'                              => 'none',
            'Revert'                            => 'revert',
            'Scale-down'                        => 'scale-down',
            'Unset'                             => 'unset',
        );
		return $output;
	}
}

/**
 * Returns array of predefined css classes
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_icon_colors' ) ) {
	function ysp_icon_colors() {
		$output = array(
            __( 'Color default', YSP_TEXT_DOMAIN )        => '',
            __( 'Color 1', YSP_TEXT_DOMAIN )              => 'icon--color-1',
            __( 'Color 2', YSP_TEXT_DOMAIN )              => 'icon--color-2',
            __( 'Color 3', YSP_TEXT_DOMAIN )              => 'icon--color-3',
            __( 'Color 4', YSP_TEXT_DOMAIN )              => 'icon--color-4',
            __( 'Color 5', YSP_TEXT_DOMAIN )              => 'icon--color-5',
            __( 'Color 6', YSP_TEXT_DOMAIN )              => 'icon--color-6',
            __( 'Color 7', YSP_TEXT_DOMAIN )              => 'icon--color-7',
            __( 'Color 8', YSP_TEXT_DOMAIN )              => 'icon--color-8',
            __( 'Color 9', YSP_TEXT_DOMAIN )              => 'icon--color-9',
            __( 'Color 10', YSP_TEXT_DOMAIN )             => 'icon--color-0',
            __( 'Color Body', YSP_TEXT_DOMAIN )           => 'icon--color-body',
            __( 'Color White', YSP_TEXT_DOMAIN )          => 'icon--color-white',
            __( 'Color Black', YSP_TEXT_DOMAIN )          => 'icon--color-black',
        );
		return $output;
	}
}

/**
 * Returns array of predefined css classes
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_icon_size' ) ) {
	function ysp_icon_size() {
		$output = array(
            __( 'Default size', YSP_TEXT_DOMAIN )    => '',
			'XS'         => 'icon--xs',
			'SM'         => 'icon--sm',
			'MD'         => 'icon--md',
			'LG'         => 'icon--lg',
			'XL'         => 'icon--xl',
			'XXL'        => 'icon--xxl',
        );
		return $output;
	}
}

/**
 * Container Type
 *
 * @since 1.4.4
 */
if ( !function_exists( 'ysp_containers' ) ) {
	function ysp_containers() {
		$output = array(
            __( 'None', YSP_TEXT_DOMAIN )   => '',
            'Container'                     => 'c-container',
            'Container Fluid'               => 'c-container-fluid',
        );
		return $output;
	}
}

/**
*	Background Color
* 	@since 1.4.5
*/
if ( !function_exists( 'ysp_bg_color' ) ) {
	function ysp_bg_color() {
		$output = array(
            __( 'None', YSP_TEXT_DOMAIN )                 => '',
            __( 'Color Body', YSP_TEXT_DOMAIN )           => 'u-background-color-body',
            __( 'Color White', YSP_TEXT_DOMAIN )          => 'u-background-color-white',
            __( 'Color Black', YSP_TEXT_DOMAIN )          => 'u-background-color-black',
            __( 'Color One', YSP_TEXT_DOMAIN )            => 'u-background-color-1',
            __( 'Color Two', YSP_TEXT_DOMAIN )            => 'u-background-color-2',
            __( 'Color Three', YSP_TEXT_DOMAIN )          => 'u-background-color-3',
            __( 'Color Four', YSP_TEXT_DOMAIN )           => 'u-background-color-4',
            __( 'Color Five', YSP_TEXT_DOMAIN )           => 'u-background-color-5',
            __( 'Color Six', YSP_TEXT_DOMAIN )            => 'u-background-color-6',
            __( 'Color Seven', YSP_TEXT_DOMAIN )          => 'u-background-color-7',
            __( 'Color Eight', YSP_TEXT_DOMAIN )          => 'u-background-color-8',
            __( 'Color Nine', YSP_TEXT_DOMAIN )           => 'u-background-color-9',
            __( 'Color Ten', YSP_TEXT_DOMAIN )            => 'u-background-color-0',
            __( 'Color Gray One', YSP_TEXT_DOMAIN )       => 'u-background-color-gray-1',
            __( 'Color Gray Two', YSP_TEXT_DOMAIN )       => 'u-background-color-gray-2',
            __( 'Color Gray Three', YSP_TEXT_DOMAIN )     => 'u-background-color-gray-3',
            __( 'Color Gray Four', YSP_TEXT_DOMAIN )      => 'u-background-color-gray-4',
            __( 'Color Gray Five', YSP_TEXT_DOMAIN )      => 'u-background-color-gray-5',
        );
		return $output;
	}
}

/**
*	Text effects
* 	@since 1.4.5
*/
if ( !function_exists( 'ysp_txt_color' ) ) {
	function ysp_txt_color() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )              => '',
            __( 'Color Body', YSP_TEXT_DOMAIN )           => 'u-text-color-body',
            __( 'Color White', YSP_TEXT_DOMAIN )          => 'u-text-color-white',
            __( 'Color Black', YSP_TEXT_DOMAIN )          => 'u-text-color-black',
            __( 'Color One', YSP_TEXT_DOMAIN )            => 'u-text-color-1',
            __( 'Color Two', YSP_TEXT_DOMAIN )            => 'u-text-color-2',
            __( 'Color Three', YSP_TEXT_DOMAIN )          => 'u-text-color-3',
            __( 'Color Four', YSP_TEXT_DOMAIN )           => 'u-text-color-4',
            __( 'Color Five', YSP_TEXT_DOMAIN )           => 'u-text-color-5',
            __( 'Color Six', YSP_TEXT_DOMAIN )            => 'u-text-color-6',
            __( 'Color Seven', YSP_TEXT_DOMAIN )          => 'u-text-color-7',
            __( 'Color Eight', YSP_TEXT_DOMAIN )          => 'u-text-color-8',
            __( 'Color Nine', YSP_TEXT_DOMAIN )           => 'u-text-color-9',
            __( 'Color Ten', YSP_TEXT_DOMAIN )            => 'u-text-color-0',
            __( 'Color Gray One', YSP_TEXT_DOMAIN )       => 'u-text-color-gray-1',
            __( 'Color Gray Two', YSP_TEXT_DOMAIN )       => 'u-text-color-gray-2',
            __( 'Color Gray Three', YSP_TEXT_DOMAIN )     => 'u-text-color-gray-3',
            __( 'Color Gray Four', YSP_TEXT_DOMAIN )      => 'u-text-color-gray-4',
            __( 'Color Gray Five', YSP_TEXT_DOMAIN )      => 'u-text-color-gray-5',
        );
		return $output;
	}
}

/**
*	Text aligns
* 	@since 1.4.5
*/
if ( !function_exists( 'ysp_txt_align' ) ) {
	function ysp_txt_align() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN ) 	          => '',
            __( 'Right', YSP_TEXT_DOMAIN )                => 'u-text-right',
            __( 'Center', YSP_TEXT_DOMAIN ) 	          => 'u-text-center',
        );
		return $output;
	}
}

/**
 * Returns array of predefined css classes
 *
 * @since 1.4.4
 */
if ( !function_exists( 'ysp_bg_behavior' ) ) {
	function ysp_bg_behavior() {
		$output = array(
            __( 'Default (Repeat)', YSP_TEXT_DOMAIN )   => '',
            'No Repeat'                                 => 'u-background-no-repeat',
            'Cover'                                     => 'u-background-cover',
            'Contain'                                   => 'u-background-contain',
        );
		return $output;
	}
}

/**
 * Returns array of predefined css classes
 *
 * @since 1.4.4
 */
if ( ! function_exists( 'ysp_container_size' ) ) {
	function ysp_container_size() {
		$output = array(
			__( 'Default', YSP_TEXT_DOMAIN )                =>  '',
			_x( 'Small', 'Width Size', YSP_TEXT_DOMAIN )    =>  'c-container--small',
			__( 'Wide', YSP_TEXT_DOMAIN )                   =>  'c-container--wide',
			__( 'Wider', YSP_TEXT_DOMAIN )                  =>  'c-container--wider',
			__( 'Widest', YSP_TEXT_DOMAIN )                 =>  'c-container--widest',
		);
		return $output;
	}
}

/**
 * Returns array of predefined css classes
 *
 * @since 1.4.4
 */
if ( !function_exists( 'ysp_bg_positions' ) ) {
	function ysp_bg_positions() {
		$output = array(
            __( 'Default (Top Left)', YSP_TEXT_DOMAIN )   => '',
            'Center'            =>  'u-background-pos-center',
            'Top Center'        =>  'u-background-pos-top-center',
            'Top Right'         =>  'u-background-pos-top-right',
            'Bottom Left'       =>  'u-background-pos-bottom-left',
            'Bottom Center'     =>  'u-background-pos-bottom-center',
            'Bottom Right'      =>  'u-background-pos-bottom-right',
        );
		return $output;
	}
}

/**
 * Layout Adjust
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_row_adjust' ) ) {
	function ysp_row_adjust() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )              => '',
            __( 'Column Space None', YSP_TEXT_DOMAIN )    => 'c-row--no-gutter',
            __( 'Column Space XS', YSP_TEXT_DOMAIN )      => 'c-row--xs-gutter',
            __( 'Column Space SM', YSP_TEXT_DOMAIN )      => 'c-row--sm-gutter',
            __( 'Column Space MD', YSP_TEXT_DOMAIN )      => 'c-row--md-gutter',
            __( 'Column Space LG', YSP_TEXT_DOMAIN )      => 'c-row--lg-gutter',
            __( 'Column Space XL', YSP_TEXT_DOMAIN )      => 'c-row--xl-gutter',
            __( 'Column Space XXL', YSP_TEXT_DOMAIN )     => 'c-row--xxl-gutter',
        );
		return $output;
	}
}

/**
 * Layout Horizontal Align
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_row_horizontal_align' ) ) {
	function ysp_row_horizontal_align() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )			  => '',
            __( 'Align Center', YSP_TEXT_DOMAIN )         => 'u-justify-content-center',
            __( 'Align Right', YSP_TEXT_DOMAIN ) 		  => 'u-justify-content-end',
        );
		return $output;
	}
}

/**
 * Layout Verical Align
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_row_vertical_align' ) ) {
	function ysp_row_vertical_align() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )              => '',
            __( 'Align Top', YSP_TEXT_DOMAIN )            => 'u-align-items-start',
            __( 'Align Middle', YSP_TEXT_DOMAIN )         => 'u-align-items-center',
            __( 'Align Bottom', YSP_TEXT_DOMAIN )         => 'u-align-items-end',
        );
		return $output;
	}
}

/**
 * Column inner element vertical align
 *
 * @since 1.5.1
 */
if( !function_exists( 'ysp_col_inner_element_vertical_align' ) ) {
	function ysp_col_inner_element_vertical_align() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )              => '',
            __( 'Align Middle', YSP_TEXT_DOMAIN )         => 'c-col-inner--middle',
            __( 'Align Bottom', YSP_TEXT_DOMAIN )         => 'c-col-inner--end',
        );
		return $output;
	}
}

/**
 * Button Color
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_btn_color' ) ) {
	function ysp_btn_color() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )              => '',
            __( 'Color 1', YSP_TEXT_DOMAIN )              => 'c-button--color-1',
            __( 'Color 2', YSP_TEXT_DOMAIN )              => 'c-button--color-2',
            __( 'Color 3', YSP_TEXT_DOMAIN )              => 'c-button--color-3',
            __( 'Color 4', YSP_TEXT_DOMAIN )              => 'c-button--color-4',
            __( 'Color 5', YSP_TEXT_DOMAIN )              => 'c-button--color-5',
            __( 'Color 6', YSP_TEXT_DOMAIN )              => 'c-button--color-6',
            __( 'Color 7', YSP_TEXT_DOMAIN )              => 'c-button--color-7',
            __( 'Color 8', YSP_TEXT_DOMAIN )              => 'c-button--color-8',
            __( 'Color 9', YSP_TEXT_DOMAIN )              => 'c-button--color-9',
            __( 'Color 10', YSP_TEXT_DOMAIN )             => 'c-button--color-0',
            __( 'Color White', YSP_TEXT_DOMAIN )          => 'c-button--color-white',
            __( 'Color Black', YSP_TEXT_DOMAIN )          => 'c-button--color-black',
        );
		return $output;
	}
}

/**
 * Button size
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_btn_size' ) ) {
	function ysp_btn_size() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )    =>  '',
            __( 'Small', YSP_TEXT_DOMAIN )      =>  'c-button--sm',
            __( 'Large', YSP_TEXT_DOMAIN )      =>  'c-button--lg',
        );
		return $output;
	}
}

/**
 * Button Round
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_btn_round' ) ) {
	function ysp_btn_round() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )    => '',
            __( 'Round', YSP_TEXT_DOMAIN ) 	    => 'yes', // For Legacy Purposes
            __( 'Pill', YSP_TEXT_DOMAIN ) 	    => 'pill',
        );
		return $output;
	}
}

/**
 * Button Aspect
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_btn_aspect' ) ) {
	function ysp_btn_aspect() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )		      => '',
            __( 'Full width', YSP_TEXT_DOMAIN ) 	      => 'c-button--full',
            __( 'Wide', YSP_TEXT_DOMAIN )			      => 'c-button--wide',
            __( 'Fit content', YSP_TEXT_DOMAIN ) 	      => 'c-button--fit-content',
        );
		return $output;
	}
}

/**
 * Button Position
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_btn_pos' ) ) {
	function ysp_btn_pos() {
		$output = array(
            __( 'Default', YSP_TEXT_DOMAIN )	          => '',
            __( 'Center', YSP_TEXT_DOMAIN )	              => 'c-button--center',
            __( 'Right', YSP_TEXT_DOMAIN )                => 'c-button--right',
        );
		return $output;
	}
}

/**
 * Parent Pages
 *
 * @since 1.4.4
 */
if( !function_exists( 'ysp_parent_pages' ) ) {
	function ysp_parent_pages() {
        $args = array(
            'post_type'         =>  'page',
            'posts_per_page'    =>  -1,
            'order'             =>  'ASC',
            'orderby'           =>  'name',
        );
        
        $output = '';
        $pages_query = new WP_Query($args);

        if ($pages_query->posts) {
            $output = array();
            foreach ($pages_query->posts as $key => $data) {
                $page_id = $data->ID;
                $page_title = $data->post_title;
                $output[$page_title] = $page_id;
            }
        }

		return $output;
	}
}

/**
 * Returns array of animations
 *
 * @since 1.11.0
 */
if( !function_exists( 'ysp_animations' ) ) {
	function ysp_animations() {
		$output = array(
            __('-- select animation --', YSP_TEXT_DOMAIN) => '',
            'bounce' => 'bounce',
            'flash' => 'flash',
            'pulse' => 'pulse',
            'rubberBand' => 'rubberBand',
            'shakeX' => 'shakeX',
            'shakeY' => 'shakeY',
            'headShake' => 'headShake',
            'swing' => 'swing',
            'tada' => 'tada',
            'wobble' => 'wobble',
            'jello' => 'jello',
            'heartBeat' => 'heartBeat',
            'backInDown' => 'backInDown',
            'backInLeft' => 'backInLeft',
            'backInRight' => 'backInRight',
            'backInUp' => 'backInUp',
            'backOutDown' => 'backOutDown',
            'backOutLeft' => 'backOutLeft',
            'backOutRight' => 'backOutRight',
            'backOutUp' => 'backOutUp',
            'bounceIn' => 'bounceIn',
            'bounceInDown' => 'bounceInDown',
            'bounceInLeft' => 'bounceInLeft',
            'bounceInRight' => 'bounceInRight',
            'bounceInUp' => 'bounceInUp',
            'bounceOut' => 'bounceOut',
            'bounceOutDown' => 'bounceOutDown',
            'bounceOutLeft' => 'bounceOutLeft',
            'bounceOutRight' => 'bounceOutRight',
            'bounceOutUp' => 'bounceOutUp',
            'fadeIn' => 'fadeIn',
            'fadeInDown' => 'fadeInDown',
            'fadeInDownBig' => 'fadeInDownBig',
            'fadeInLeft' => 'fadeInLeft',
            'fadeInLeftBig' => 'fadeInLeftBig',
            'fadeInRight' => 'fadeInRight',
            'fadeInRightBig' => 'fadeInRightBig',
            'fadeInUp' => 'fadeInUp',
            'fadeInUpBig' => 'fadeInUpBig',
            'fadeInTopLeft' => 'fadeInTopLeft',
            'fadeInTopRight' => 'fadeInTopRight',
            'fadeInBottomLeft' => 'fadeInBottomLeft',
            'fadeInBottomRight' => 'fadeInBottomRight',
            'fadeOut' => 'fadeOut',
            'fadeOutDown' => 'fadeOutDown',
            'fadeOutDownBig' => 'fadeOutDownBig',
            'fadeOutLeft' => 'fadeOutLeft',
            'fadeOutLeftBig' => 'fadeOutLeftBig',
            'fadeOutRight' => 'fadeOutRight',
            'fadeOutRightBig' => 'fadeOutRightBig',
            'fadeOutUp' => 'fadeOutUp',
            'fadeOutUpBig' => 'fadeOutUpBig',
            'fadeOutTopLeft' => 'fadeOutTopLeft',
            'fadeOutTopRight' => 'fadeOutTopRight',
            'fadeOutBottomRight' => 'fadeOutBottomRight',
            'fadeOutBottomLeft' => 'fadeOutBottomLeft',
            'animated.animate__flip' => 'animated.animate__flip',
            'flipInX' => 'flipInX',
            'flipInY' => 'flipInY',
            'flipOutX' => 'flipOutX',
            'flipOutY' => 'flipOutY',
            'lightSpeedInRight' => 'lightSpeedInRight',
            'lightSpeedInLeft' => 'lightSpeedInLeft',
            'lightSpeedOutRight' => 'lightSpeedOutRight',
            'lightSpeedOutLeft' => 'lightSpeedOutLeft',
            'rotateIn' => 'rotateIn',
            'rotateInDownLeft' => 'rotateInDownLeft',
            'rotateInDownRight' => 'rotateInDownRight',
            'rotateInUpLeft' => 'rotateInUpLeft',
            'rotateInUpRight' => 'rotateInUpRight',
            'rotateOut' => 'rotateOut',
            'rotateOutDownLeft' => 'rotateOutDownLeft',
            'rotateOutDownRight' => 'rotateOutDownRight',
            'rotateOutUpLeft' => 'rotateOutUpLeft',
            'rotateOutUpRight' => 'rotateOutUpRight',
            'hinge' => 'hinge',
            'jackInTheBox' => 'jackInTheBox',
            'rollIn' => 'rollIn',
            'rollOut' => 'rollOut',
            'zoomIn' => 'zoomIn',
            'zoomInDown' => 'zoomInDown',
            'zoomInLeft' => 'zoomInLeft',
            'zoomInRight' => 'zoomInRight',
            'zoomInUp' => 'zoomInUp',
            'zoomOut' => 'zoomOut',
            'zoomOutDown' => 'zoomOutDown',
            'zoomOutLeft' => 'zoomOutLeft',
            'zoomOutRight' => 'zoomOutRight',
            'zoomOutUp' => 'zoomOutUp',
            'slideInDown' => 'slideInDown',
            'slideInLeft' => 'slideInLeft',
            'slideInRight' => 'slideInRight',
            'slideInUp' => 'slideInUp',
            'slideOutDown' => 'slideOutDown',
            'slideOutLeft' => 'slideOutLeft',
            'slideOutRight' => 'slideOutRight',
            'slideOutUp' => 'slideOutUp',
        );
		return $output;
	}
}

/**
* Find file, check if is child theme, file is in child theme
* @since 1.4.4
*/
if( !function_exists( 'get_ysp_file_location' ) ) {
    function get_ysp_file_location($file = '', $default = '') {
        $location = get_template_directory_uri().$default.'/'.$file;    
        if ( is_child_theme() ) {
            if ( file_exists(get_stylesheet_directory().'/'.$file) ) {
                $location = get_stylesheet_directory_uri().'/'.$file;
            }
        }
        return $location;
    }
}

/**
 * Include template from templates dir.
 *
 * @since 1.4.4
 *
 * @param $template
 * @param array $variables - passed variables to the template.
 *
 * @param bool $once
 *
 * @return mixed
 */
if(!function_exists('ysp_vc_hero_height_include_template')) {
    function ysp_vc_hero_height_include_template( $variables = array(), $once = false ) {
        is_array( $variables ) && extract( $variables );
        if ( $once ) {
            return require_once get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_hero_height_tpl.php';
        } else {
            return require get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_hero_height_tpl.php';
        }
    }
}

if(!function_exists('ysp_vc_offset_include_template')) {
    function ysp_vc_offset_include_template( $variables = array(), $once = false ) {
        is_array( $variables ) && extract( $variables );
        if ( $once ) {
            return require_once get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_offset_tpl.php';
        } else {
            return require get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_offset_tpl.php';
        }
    }
}

if(!function_exists('ysp_vc_margin_include_template')) {
    function ysp_vc_margin_include_template( $variables = array(), $once = false ) {
        is_array( $variables ) && extract( $variables );
        if ( $once ) {
            return require_once get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_margin_tpl.php';
        } else {
            return require get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_margin_tpl.php';
        }
    }
}

if(!function_exists('ysp_vc_padding_include_template')) {
    function ysp_vc_padding_include_template( $variables = array(), $once = false ) {
        is_array( $variables ) && extract( $variables );
        if ( $once ) {
            return require_once get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_padding_tpl.php';
        } else {
            return require get_template_directory() . '/inc/components/visual-composer/params/templates/ysp_padding_tpl.php';
        }
    }
}

if(!function_exists('ysp_vc_spacing_params')) {
    function ysp_vc_spacing_params(){
        $params = array(
            // Only for VC UI functionality
            array(
                'type' => 'checkbox',
                'heading' => __( "Set Margin", YSP_TEXT_DOMAIN ),
                'param_name' => 'set_margin',
                'admin_label' => false,
                'weight' => 99,
                'group' => 'Margins/Paddings',
            ),
            array(
                'type' => 'ysp_margin',
                'heading' => __( "Margin Settings", YSP_TEXT_DOMAIN ),
                'param_name' => 'margin',
                'admin_label' => true,
                'weight' => 99,
                'dependency' => array('element' => 'set_margin', 'value' => 'true'),
                'group' => 'Margins/Paddings',
            ),
            // Only for VC UI functionality
            array(
                'type' => 'checkbox',
                'heading' => __( "Set Padding", YSP_TEXT_DOMAIN ),
                'param_name' => 'set_padding',
                'admin_label' => false,
                'group' => 'Margins/Paddings',
            ),
            array(
                'type' => 'ysp_padding',
                'heading' => __( "Padding Settings", YSP_TEXT_DOMAIN ),
                'param_name' => 'padding',
                'admin_label' => true,
                'dependency' => array('element' => 'set_padding', 'value' => 'true'),
                'group' => 'Margins/Paddings',
            )
        );
        return $params;
    }
}