<?php
/**
 * Custom VC config file for YSP.
 *
 * Require VC helper fuctions
 * Require custom VC parameters
 * Remove VC default icons
 * Remove VC default elements
 * Disable Front End Editor
 * Deregister VC default style and script from front end
 * Include ysp-to-vc shortcode register file
 * Include VC modified shortcodes
 * Re-Register customized VC components
 * - custom-column
 * - custom row
 * - custom inner-column
 * - custom inner-row
 * - custom text component
 * - custom video component
 * Register custom backend VC style ( custom style VC components  )
 *
 * @since 1.4.4
 */

/**
 * YSP VC COMPONENT SYMBOL
 */
define( 'YSP_VC_COMPONENT_SYMBOL', YSP_THEME_URI . '/inc/components/visual-composer/images/yourstyle-plus-icon.svg' );

/**
 * change default template directory where Visual Composer looks for content elements template files.
 */
$dir = YSP_ENGINE_DIR . '/components/visual-composer/vc_templates';
vc_set_shortcodes_templates_dir($dir);

/**
 * Remove VC default elements.
 */

// YSP VC helpers and custom parameters
require YSP_ENGINE_DIR . '/components/visual-composer/ysp-vc-helpers.php';
require YSP_ENGINE_DIR . '/components/visual-composer/params/ysp-vc-hero-params.php';
require YSP_ENGINE_DIR . '/components/visual-composer/params/ysp-vc-column-params.php';
require YSP_ENGINE_DIR . '/components/visual-composer/params/ysp-vc-margin-params.php';
require YSP_ENGINE_DIR . '/components/visual-composer/params/ysp-vc-padding-params.php';

// Deque VC default icons
add_action('vc_base_register_admin_css', 'remove_vc_styles', 99);
if (!function_exists('remove_vc_styles')) {
    function remove_vc_styles() {
        wp_deregister_style('vc_openiconic');
        wp_deregister_style('vc_monosocialiconsfont');
        wp_deregister_style('font-awesome');
    }
}

// VC Components (On)
// vc_remove_element("vc_column_text"); // Default Off
// vc_remove_element("vc_column_inner"); // Default Off
// vc_remove_element("vc_video"); // Default Off
// vc_remove_element("vc_raw_html"); // Default Off

// VC Components (Off)
$vcis = array(
    'vc_custom_heading' => array(
        'name' => 'Custom Heading',
        'description' => '',
        'option' => 'vc_custom_heading',
    ),
    'vc_empty_space' => array(
        'name' => 'Empty Space',
        'description' => '',
        'option' => 'vc_empty_space',
    ),
    'vc_flickr' => array(
        'name' => 'Flickr',
        'description' => '',
        'option' => 'vc_flickr',
    ),
    'vc_gallery' => array(
        'name' => 'Gallery',
        'description' => '',
        'option' => 'vc_gallery',
    ),
    'vc_gmaps' => array(
        'name' => 'GMaps',
        'description' => '',
        'option' => 'vc_gmaps',
    ),
    'vc_icon' => array(
        'name' => 'Icon',
        'description' => '',
        'option' => 'vc_icon',
    ),
    'vc_images_carousel' => array(
        'name' => 'Images Carousel',
        'description' => '',
        'option' => 'vc_images_carousel',
    ),
    'vc_line_chart' => array(
        'name' => 'Line Chart',
        'description' => '',
        'option' => 'vc_line_chart',
    ),
    'vc_message' => array(
        'name' => 'Message',
        'description' => '',
        'option' => 'vc_message',
    ),
    'vc_pie' => array(
        'name' => 'PIE',
        'description' => '',
        'option' => 'vc_pie',
    ),
    'vc_posts_slider' => array(
        'name' => 'Posts Slider',
        'description' => '',
        'option' => 'vc_posts_slider',
    ),
    'vc_progress_bar' => array(
        'name' => 'Progress Bar',
        'description' => '',
        'option' => 'vc_progress_bar',
    ),
    'vc_round_chart' => array(
        'name' => 'Round Chart',
        'description' => '',
        'option' => 'vc_round_chart',
    ),
    'vc_separator' => array(
        'name' => 'Separator',
        'description' => '',
        'option' => 'vc_separator',
    ),
    'vc_single_image' => array(
        'name' => 'Single Image',
        'description' => '',
        'option' => 'vc_single_image',
    ),
    'vc_text_separator' => array(
        'name' => 'Text Separator',
        'description' => '',
        'option' => 'vc_text_separator',
    ),
    'vc_toggle' => array(
        'name' => 'Toggle',
        'description' => '',
        'option' => 'vc_toggle',
    ),
    'vc_icon_element' => array(
        'name' => 'Icon Element',
        'description' => '',
        'option' => 'vc_icon_element',
    ),
    'vc_btn' => array(
        'name' => 'BTN',
        'description' => '',
        'option' => 'vc_btn',
    ),
    'vc_cta' => array(
        'name' => 'CTA',
        'description' => '',
        'option' => 'vc_cta',
    ),
    'vc_section' => array(
        'name' => 'Section',
        'description' => '',
        'option' => 'vc_section',
    ),
    'vc_hoverbox' => array(
        'name' => 'Hoverbox',
        'description' => '',
        'option' => 'vc_hoverbox',
    ),
    'vc_zigzag' => array(
        'name' => 'ZigZag',
        'description' => '',
        'option' => 'vc_zigzag',
    ),
    'vc_widget_sidebar' => array(
        'name' => 'Widget Sidebar',
        'description' => '',
        'option' => 'vc_widget_sidebar',
    ),
    'vc_raw_js' => array(
        'name' => 'Raw JS',
        'description' => '',
        'option' => 'vc_raw_js',
    ),
    'vc_facebook' => array(
        'name' => 'Facebook',
        'description' => '',
        'option' => 'vc_facebook',
    ),
    'vc_googleplus' => array(
        'name' => 'GooglePlus',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_googleplus',
    ),
    'vc_pinterest' => array(
        'name' => 'Pinterest',
        'description' => '',
        'option' => 'vc_pinterest',
    ),
    'vc_tweetmeme' => array(
        'name' => 'Tweetmeme',
        'description' => '',
        'option' => 'vc_tweetmeme',
    ),
    'vc_grids_common' => array(
        'name' => 'Grids Common',
        'description' => '',
        'option' => 'vc_grids_common',
    ),
    'vc_basic_grid' => array(
        'name' => 'Basic Grid',
        'description' => '',
        'option' => 'vc_basic_grid',
    ),
    'vc_masonry_grid' => array(
        'name' => 'Masonry Grid',
        'description' => '',
        'option' => 'vc_masonry_grid',
    ),
    'vc_masonry_media_grid' => array(
        'name' => 'Masonry Media Grid',
        'description' => '',
        'option' => 'vc_masonry_media_grid',
    ),
    'vc_media_grid' => array(
        'name' => 'Media Grid',
        'description' => '',
        'option' => 'vc_media_grid',
    ),
    'vc_tta_accordion' => array(
        'name' => 'TTA Accordion',
        'description' => '',
        'option' => 'vc_tta_accordion',
    ),
    'vc_tta_pageable' => array(
        'name' => 'TTA Pageable',
        'description' => '',
        'option' => 'vc_tta_pageable',
    ),
    'vc_tta_section' => array(
        'name' => 'TTA Section',
        'description' => '',
        'option' => 'vc_tta_section',
    ),
    'vc_tta_tabs' => array(
        'name' => 'TTA Tabs',
        'description' => '',
        'option' => 'vc_tta_tabs',
    ),
    'vc_tta_tour' => array(
        'name' => 'TTA Tour',
        'description' => '',
        'option' => 'vc_tta_tour',
    ),
    'vc_tabs' => array(
        'name' => 'Tabs',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_tabs',
    ),
    'vc_tour' => array(
        'name' => 'Tour',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_tour',
    ),
    'vc_tab' => array(
        'name' => 'Tab',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_tab',
    ),
    'vc_accordion' => array(
        'name' => 'Accordion',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_accordion',
    ),
    'vc_accordion_tab' => array(
        'name' => 'Accordion Tab',
        'description' => __('Deprecated', 'yourstyle-plus-companion-plugin'),
        'option' => 'vc_accordion_tab',
    ),
    'vc_posts_grid' => array(
        'name' => 'Posts Grid',
        'description' => '',
        'option' => 'vc_posts_grid',
    ),
    'vc_carousel' => array(
        'name' => 'Carousel',
        'description' => '',
        'option' => 'vc_carousel',
    ),
    'vc_button' => array(
        'name' => 'Button',
        'description' => '',
        'option' => 'vc_button',
    ),
    'vc_button2' => array(
        'name' => 'Button2',
        'description' => '',
        'option' => 'vc_button2',
    ),
    'vc_cta_button' => array(
        'name' => 'CTA Button',
        'description' => '',
        'option' => 'vc_cta_button',
    ),
    'vc_cta_button2' => array(
        'name' => 'CTA Button2',
        'description' => '',
        'option' => 'vc_cta_button2',
    ),
    'vc_wp_archives' => array(
        'name' => 'WP Archives',
        'description' => '',
        'option' => 'vc_wp_archives',
    ),
    'vc_wp_categories' => array(
        'name' => 'WP Categories',
        'description' => '',
        'option' => 'vc_wp_categories',
    ),
    'vc_wp_calendar' => array(
        'name' => 'WP Calendar',
        'description' => '',
        'option' => 'vc_wp_calendar',
    ),
    'vc_wp_custommenu' => array(
        'name' => 'WP Custom Menu',
        'description' => '',
        'option' => 'vc_wp_custommenu',
    ),
    'vc_wp_links' => array(
        'name' => 'WP Links',
        'description' => '',
        'option' => 'vc_wp_links',
    ),
    'vc_wp_meta' => array(
        'name' => 'WP Meta',
        'description' => '',
        'option' => 'vc_wp_meta',
    ),
    'vc_wp_pages' => array(
        'name' => 'WP Pages',
        'description' => '',
        'option' => 'vc_wp_pages',
    ),
    'vc_wp_posts' => array(
        'name' => 'WP Posts',
        'description' => '',
        'option' => 'vc_wp_posts',
    ),
    'vc_wp_recentcomments' => array(
        'name' => 'WP Recent Comments',
        'description' => '',
        'option' => 'vc_wp_recentcomments',
    ),
    'vc_wp_rss' => array(
        'name' => 'WP RSS',
        'description' => '',
        'option' => 'vc_wp_rss',
    ),
    'vc_wp_search' => array(
        'name' => 'WP Search',
        'description' => '',
        'option' => 'vc_wp_search',
    ),
    'vc_wp_tagcloud' => array(
        'name' => 'WP Tag Cloud',
        'description' => '',
        'option' => 'vc_wp_tagcloud',
    ),
    'vc_wp_text' => array(
        'name' => 'WP Text',
        'description' => '',
        'option' => 'vc_wp_text',
    ),
);

if ( !class_exists('Yourstyle_Plus_Companion_Plugin') ) {

    // Deregister VC style and script from the frontend
    if ( !vc_is_inline() ) {
        add_action('wp_enqueue_scripts', 'ysp_vc_default_dequeue_styles');
        add_action('wp_print_scripts', 'ysp_vc_default_dequeue_scripts');
    }

    foreach ($vcis as $vci) {
        if ( $vci['option'] ) {
            vc_remove_element($vci['option']);
        }
    }

} else {

    $dequeue_vc_frontend = true;
    foreach ($vcis as $vci) {
        if ( get_option($vci['option']) == "0" ) {
            vc_remove_element($vci['option']);
        }
        if ( get_option($vci['option']) == "1" ) {
            $dequeue_vc_frontend = false;
        }
    }

    if ( $dequeue_vc_frontend ) {
        // Deregister VC style and script from the frontend
        if ( !vc_is_inline() ) {
            add_action('wp_enqueue_scripts', 'ysp_vc_default_dequeue_styles');
            add_action('wp_print_scripts', 'ysp_vc_default_dequeue_scripts');
        }
    }

}

/* Disable frontend editor */
if ( function_exists('vc_disable_frontend') ) {
    vc_disable_frontend();
}

/* Disable styles */
if (!function_exists('ysp_vc_default_dequeue_styles')) {
    function ysp_vc_default_dequeue_styles() {
        wp_deregister_style('js_composer_front');
    }
}

/* Disable scripts */
if (!function_exists('ysp_vc_default_dequeue_scripts')) {
    function ysp_vc_default_dequeue_scripts() {
        wp_deregister_script('wpb_composer_front_js');
        wp_dequeue_script('wpb_composer_front_js');
    }
}

/* Disable Instructional/Help Pointers */
add_action( 'vc_before_init', 'vc_remove_all_pointers' );
function vc_remove_all_pointers() {
    remove_action( 'admin_enqueue_scripts', 'vc_pointer_load' );
}

// Alter Visual Composer shortcodes
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-row.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-row-inner.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-column.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-column-inner.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-column-text.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-video.php';

// Map/Integrate YSP defined shortcodes
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-accordion.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-button.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-button-group.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-child-pages.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-divider.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-heading.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-hero-block.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-hero-simple.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-icon.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-image.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-mediabox.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-shortcode.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-sliders.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-styled-list.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-swiper-slider.php';
require YSP_ENGINE_DIR . '/components/visual-composer/shortcodes/ysp-vc-tabs.php';

// Register customized VC for YSP
add_action('vc_after_init', 'ysp_vc_row_shortcode');
add_action('vc_after_init', 'ysp_vc_row_inner_shortcode');
add_action('vc_after_init', 'ysp_vc_column_shortcodes');
add_action('vc_after_init', 'ysp_vc_column_inner_shortcode');
add_action('vc_after_init', 'ysp_vc_column_text_shortcode');

// Register customized VC for YSP
add_action('vc_after_init', 'ysp_vc_accordion_shortcode');
add_action('vc_after_init', 'ysp_vc_accordion_item_shortcode');
add_action('vc_after_init', 'ysp_vc_button_shortcode');
add_action('vc_after_init', 'ysp_vc_button_group_shortcode');
add_action('vc_after_init', 'ysp_vc_divider_shortcode');
add_action('vc_after_init', 'ysp_vc_child_pages_shortcode');
add_action('vc_after_init', 'ysp_vc_heading_shortcode');
add_action('vc_after_init', 'ysp_vc_hero_block_shortcode');
add_action('vc_after_init', 'ysp_vc_hero_simple_shortcode');
add_action('vc_after_init', 'ysp_vc_icon_shortcode');
add_action('vc_after_init', 'ysp_vc_image_shortcode');
add_action('vc_after_init', 'ysp_vc_list_shortcode');
add_action('vc_after_init', 'ysp_vc_mediabox_shortcode');
add_action('vc_after_init', 'ysp_vc_tab_shortcode');
add_action('vc_after_init', 'ysp_vc_tab_item_shortcode');
add_action('vc_after_init', 'ysp_vc_video_shortcode');
add_action('vc_after_init', 'ysp_vc_shortcode_shortcode');
add_action('vc_after_init', 'ysp_vc_ysp_slider_shortcode');
add_action('vc_after_init', 'ysp_vc_ysp_slider_item_shortcode');
add_action('vc_after_init', 'ysp_vc_swiper_slider_shortcode');
add_action('vc_after_init', 'ysp_vc_swiper_slider_item_shortcode');

// YSP-VC custom style
if (!function_exists('ysp_vc_admin_style')) {
    function ysp_vc_admin_style() {
        // Check if we are on a page and we edit that page
        if (get_post_meta(get_the_ID(), '_wpb_vc_js_status', true) && isset($_GET['action'])) {
            if ('edit' === $_GET['action']) {
                wp_register_style('ysp_vc_style', get_ysp_file_location('style-editor.css', '/assets/src/css'), false, '1.0.0');
                wp_enqueue_style('ysp_vc_style');
            }
        }
    }
}
add_action('admin_enqueue_scripts', 'ysp_vc_admin_style');
