<?php
/**
 * yourstyle+ Theme Customizer: Advanced Settings
 *
 * @package yourstyle+
 */

/**
 * Customizer Defaults
 */
add_filter( 'ysp_customizer_defaults', 'ysp_customizer_defaults_advanced' );
if ( ! function_exists( 'ysp_customizer_defaults_advanced' ) ) {

	function ysp_customizer_defaults_advanced( $option ) {

		$options = array(
            // Containers
            "container-max-width-sm" => 960,
            "container-max-width-md" => 1140,
            "container-max-width-lg" => 1320,
            "container-max-width-xl" => 1500,
            "container-max-width-xxl" => 1680,
            // Content
            "ysp-before-header-content" => null,
            "ysp-after-header-content" => null,
            "ysp-header-content-start" => null,
            "ysp-before-main-content" => null,
            "ysp-after-main-content" => null,
            "ysp-before-footer-content" => null,
            // Debugging
            "ysp-visible-hooks" => "0",
            // Footer
            "ysp-footer-layout" => "static",
            "ysp-poweredby-link" => "1",
            // Enhancements
            "ysp-enhance-emoji-scripts" => "0",
            "ysp-enhance-dashicons-scripts" => "0",
            "ysp-enhance-assets-version" => "0",
            "ysp-enhance-jquery-migrate" => "1",
            "ysp-enhance-block-editor-assets" => "0",
            "ysp-enhance-scrollmagic" => "1",
            "ysp-enhance-animations" => "1",
            // Typography
            "ysp-typography-body-font" => "default",
            "ysp-typography-heading-font" => "default",
            "ysp-typography-font-weights" => "400,700",
            // Navigation
            "ysp-sticky-nav" => "0",
            "ysp-nav-expand" => "lg",
            "ysp-mobile-navigation-toggle" => "0",
            "ysp-mobile-navigation-level" => "low",
            "mobile-navigation-width" => 100,
            "ysp-hang-navigation-position" => "lft",
            "ysp-back-to-top-button" => "1",
            // Spacing
            "ysp-spacing-size" => "7",
            // Scripts
            "ysp-script-head" => NULL,
            "ysp-script-body" => NULL,
            "ysp-script-footer" => NULL,
            // WooCommerce
            "ysp-woo-remove-header-utility" => "0",
            // 404 Page
            "ysp-404-page-custom-image-url" => null,
            "ysp-custom-404-page" => false,
        );
        
        if (is_array($option) && is_array($options)) {
            return array_merge( $option, $options );
        }
	}
}

/**
 * Customizer Options
 */
if ( ! function_exists( 'ysp_theme_customizer_advanced' ) ) {

    function ysp_theme_customizer_advanced( $wp_customize ) {

        // New Get Theme Fonts
        $fonts = new YspGetThemeFonts;

        // Add Containers Section
        $wp_customize->add_section( "ysp-containers",
            array(
                "title"     => 'Containers',
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Container: MD (default)
        $wp_customize->add_setting( "container-max-width-md",
            array(
                "default"   => ysp_customizer_defaults('container-max-width-md'),
                "sanitize_callback" => 'absint',
                "transport" => "postMessage",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "container-max-width-md",
            array(
                "label"		    => 'Default (MD)',
                "section"	    => "ysp-containers",
                "settings"	    => "container-max-width-md",
                "type"		    => "number",
                "description"   => __( "Default: 1140px", YSP_TEXT_DOMAIN ),
                "input_attrs"   => array(
                    'min' => 0,
                ),
            )
        ));

        // Container: SM
        $wp_customize->add_setting( "container-max-width-sm",
            array(
                "default"   => ysp_customizer_defaults('container-max-width-sm'),
                "sanitize_callback" => 'absint',
                "transport" => "postMessage",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "container-max-width-sm",
            array(
                "label"		    => 'Small (SM)',
                "section"	    => "ysp-containers",
                "settings"	    => "container-max-width-sm",
                "type"		    => "number",
                "description"   => __( "Default: 960px", YSP_TEXT_DOMAIN ),
                "input_attrs"   => array(
                    'min' => 0,
                ),
            )
        ));

        // Container: LG
        $wp_customize->add_setting( "container-max-width-lg",
            array(
                "default"   => ysp_customizer_defaults('container-max-width-lg'),
                "sanitize_callback" => 'absint',
                "transport" => "postMessage",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "container-max-width-lg",
            array(
                "label"		    => 'Wide (LG)',
                "section"	    => "ysp-containers",
                "settings"	    => "container-max-width-lg",
                "type"		    => "number",
                "description"   => __( "Default: 1320px", YSP_TEXT_DOMAIN ),
                "input_attrs"   => array(
                    'min' => 0,
                ),
            )
        ));

        // Container: XL
        $wp_customize->add_setting( "container-max-width-xl",
            array(
                "default"   => ysp_customizer_defaults('container-max-width-xl'),
                "sanitize_callback" => 'absint',
                "transport" => "postMessage",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "container-max-width-xl",
            array(
                "label"		    => 'Wider (XL)',
                "section"	    => "ysp-containers",
                "settings"	    => "container-max-width-xl",
                "type"		    => "number",
                "description"   => __( "Default: 1500px", YSP_TEXT_DOMAIN ),
                "input_attrs"   => array(
                    'min' => 0,
                ),
            )
        ));

        // Container: XXL
        $wp_customize->add_setting( "container-max-width-xxl",
            array(
                "default"   => ysp_customizer_defaults('container-max-width-xxl'),
                "sanitize_callback" => 'absint',
                "transport" => "postMessage",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "container-max-width-xxl",
            array(
                "label"		    => 'Widest (XXL)',
                "section"	    => "ysp-containers",
                "settings"	    => "container-max-width-xxl",
                "type"		    => "number",
                "description"   => __( "Default: 1680px", YSP_TEXT_DOMAIN ),
                "input_attrs"   => array(
                    'min' => 0,
                ),
            )
        ));

        // Add Site Content Section
        $wp_customize->add_section( "ysp-site-content",
            array(
                "title"     => __('Site Content', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Place content before the header (globally)
        $wp_customize->add_setting( "ysp-before-header-content",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-before-header-content",
            array(
                "label"		    => __('Place content before the header (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-before-header-content",
                "type"		    => "textarea",
            )
        ));

        // Place content after the header (globally)
        $wp_customize->add_setting( "ysp-after-header-content",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-after-header-content",
            array(
                "label"		    => __('Place content after the header (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-after-header-content",
                "type"		    => "textarea",
            )
        ));

        // Place content at the start of the header (globally)
        $wp_customize->add_setting( "ysp-header-content-start",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-header-content-start",
            array(
                "label"		    => __('Place content at the start of the header (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-header-content-start",
                "type"		    => "textarea",
            )
        ));

        // Place content before the main content (globally)
        $wp_customize->add_setting( "ysp-before-main-content",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-before-main-content",
            array(
                "label"		    => __('Place content before the main content (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-before-main-content",
                "type"		    => "textarea",
            )
        ));

        // Place content after the main content (globally)
        $wp_customize->add_setting( "ysp-after-main-content",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-after-main-content",
            array(
                "label"		    => __('Place content after the main content (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-after-main-content",
                "type"		    => "textarea",
            )
        ));

        // Place content before the footer (globally)
        $wp_customize->add_setting( "ysp-before-footer-content",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-before-footer-content",
            array(
                "label"		    => __('Place content before the footer (globally).', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-site-content",
                "settings"	    => "ysp-before-footer-content",
                "type"		    => "textarea",
            )
        ));

        // Add Advanced Panel
        $wp_customize->add_panel( "ysp-advanced", array(
            'title'         => __('Advanced Settings', YSP_TEXT_DOMAIN),
            'priority'      => 999,
        ));

        // Add Debugging Section
        $wp_customize->add_section( "ysp-debug",
            array(
                "title"     =>  "Debugging",
                "priority"  =>  90,
                'panel'     =>  'ysp-advanced',
            )
        );

        // Make hooks visible
        $wp_customize->add_setting( "ysp-visible-hooks",
            array(
                "default"   => ysp_customizer_defaults('ysp-visible-hooks'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-visible-hooks",
            array(
                "label"		=> "",
                "section"	=> "ysp-debug",
                "settings"	=> "ysp-visible-hooks",
                "type"		=> "select",
                "choices"   => array(
                    '0' => __('No', YSP_TEXT_DOMAIN),
                    '1' => __('Yes', YSP_TEXT_DOMAIN),
                ),
                'description' => ysp_get_site_info() .'<br/>'. __('Make Hooks Visible', YSP_TEXT_DOMAIN),
            )
        ));

        // Add Footer Section
        $wp_customize->add_section( "ysp-footer",
            array(
                "title"     =>  __("Footer", YSP_TEXT_DOMAIN),
                "priority"  =>  90,
                'panel'     =>  'ysp-advanced',
            )
        );

        // Footer Layout
        $wp_customize->add_setting( "ysp-footer-layout",
            array(
                "default"   => ysp_customizer_defaults('ysp-footer-layout'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-footer-layout",
            array(
                "label"		=> __('Footer Layout', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-footer",
                "settings"	=> "ysp-footer-layout",
                "type"		=> "select",
                "choices"   => array(
                    'static'    => __('Static Layout', YSP_TEXT_DOMAIN),
                    'disable'   => __('Disable Footer', YSP_TEXT_DOMAIN),
                ),
            )
        ));

        // Powered By Link
        $wp_customize->add_setting( "ysp-poweredby-link",
            array(
                "default"   => ysp_customizer_defaults('ysp-poweredby-link'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-poweredby-link",
            array(
                "label"		=> __( 'Display Powered by Yourstyle Link', YSP_TEXT_DOMAIN ),
                "section"	=> "ysp-footer",
                "settings"	=> "ysp-poweredby-link",
                "type"		=> "select",
                "choices"   => array(
                    '0' => __( 'No', YSP_TEXT_DOMAIN ),
                    '1' => __( 'Yes', YSP_TEXT_DOMAIN ),
                ),
            )
        ));

        // Add Enhancements Section
        $wp_customize->add_section( "ysp-enhancements",
            array(
                "title"     => __("Enhancements", YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Enhancements - 01. Emoji Scripts
        $wp_customize->add_setting( "ysp-enhance-emoji-scripts",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-emoji-scripts'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-emoji-scripts",
            array(
                "label"		=> __('Emoji Scripts', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-emoji-scripts",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("WordPress emoji scripts", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 02. Dashicons Scripts
        $wp_customize->add_setting( "ysp-enhance-dashicons-scripts",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-dashicons-scripts'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-dashicons-scripts",
            array(
                "label"		=> __('Dashicons Scripts', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-dashicons-scripts",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("WordPress dashicons script.", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 03. Assets Version
        $wp_customize->add_setting( "ysp-enhance-assets-version",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-assets-version'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-assets-version",
            array(
                "label"		=> __('Assets Version', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-assets-version",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("Remove assets version number of scripts and styles (reload/clear cache).", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 04. jQuery Migrate
        $wp_customize->add_setting( "ysp-enhance-jquery-migrate",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-jquery-migrate'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-jquery-migrate",
            array(
                "label"		=> __('jQuery Migrate', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-jquery-migrate",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("jQuery Migrate.", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 05. Block Editor Assets
        $wp_customize->add_setting( "ysp-enhance-block-editor-assets",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-block-editor-assets'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-block-editor-assets",
            array(
                "label"		=> __('Block Editor Assets', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-block-editor-assets",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("Gutenberg Block Editor Assets.", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 06. ScrollMagic
        $wp_customize->add_setting( "ysp-enhance-scrollmagic",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-scrollmagic'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-scrollmagic",
            array(
                "label"		=> __('ScrollMagic Support', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-scrollmagic",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("ScrollMagic JS Support.", YSP_TEXT_DOMAIN),
            )
        ));

        // Enhancements - 07. Animations
        $wp_customize->add_setting( "ysp-enhance-animations",
            array(
                "default"   => ysp_customizer_defaults('ysp-enhance-animations'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-enhance-animations",
            array(
                "label"		=> __('Animation Support', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-enhancements",
                "settings"	=> "ysp-enhance-animations",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('Disable', YSP_TEXT_DOMAIN),
                    '1' =>  __('Enable', YSP_TEXT_DOMAIN),
                ),
                "description"   =>  __("Animation CSS Support.", YSP_TEXT_DOMAIN),
            )
        ));

        // Add Typography Section
        $wp_customize->add_section( "ysp-typography",
            array(
                "title"     => __("Typography", YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Typography - Body
        $wp_customize->add_setting( "ysp-typography-body-font",
            array(
                "default"    => ysp_customizer_defaults('ysp-typography-body-font'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-typography-body-font",
            array(
                "label"		=> __('Body Font', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-typography",
                "settings"	=> "ysp-typography-body-font",
                "type"		=> "select",
                'choices' => array_merge(
                    array(
                        'default' => __('Default', YSP_TEXT_DOMAIN),
                    ),
                    (
                        $fonts->get_fonts_name()
                    )
                ),
            )
        ));

        // Typography - Headings
        $wp_customize->add_setting( "ysp-typography-heading-font",
            array(
                "default"    => ysp_customizer_defaults('ysp-typography-heading-font'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-typography-heading-font",
            array(
                "label"		=> __('Heading Font', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-typography",
                "settings"	=> "ysp-typography-heading-font",
                "type"		=> "select",
                'choices' => array_merge(
                    array(
                        'default' => __('Default', YSP_TEXT_DOMAIN),
                    ),
                    (
                        $fonts->get_fonts_name()
                    )
                ),
                'description' => __('Choose what Font Family to use as Heading Font.', YSP_TEXT_DOMAIN),
            )
        ));

        // Typography - Font Weights
        $wp_customize->add_setting( "ysp-typography-font-weights",
            array(
                "default"    => ysp_customizer_defaults('ysp-typography-font-weights'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-typography-font-weights",
            array(
                "label"		=> __('Font Weights', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-typography",
                "settings"	=> "ysp-typography-font-weights",
                "type"		=> "text",
                'description' => __('Choose which Font Weights you want to load into your website.', YSP_TEXT_DOMAIN),
            )
        ));

        // Add Navigation Section
        $wp_customize->add_section( "ysp-navigation",
            array(
                "title"     => __('Navigation', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Sticky Nav
        $wp_customize->add_setting( "ysp-sticky-nav",
            array(
                "default"   => ysp_customizer_defaults('ysp-sticky-nav'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-sticky-nav",
            array(
                "label"		=> __( 'Sticky Nav', YSP_TEXT_DOMAIN ),
                "section"	=> "ysp-navigation",
                "settings"	=> "ysp-sticky-nav",
                "type"		=> "select",
                "choices"   => array(
                    '0' => __('Disable', YSP_TEXT_DOMAIN),
                    '1' => __('Enable', YSP_TEXT_DOMAIN),
                ),
            )
        ));

        // Nav Expand
        $wp_customize->add_setting( "ysp-nav-expand",
            array(
                "default"   => ysp_customizer_defaults('ysp-nav-expand'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-nav-expand",
            array(
                "label"		=> __( 'Nav Expand', YSP_TEXT_DOMAIN ),
                "section"	=> "ysp-navigation",
                "settings"	=> "ysp-nav-expand",
                "type"		=> "select",
                "choices"   => array(
                    'aw' => __( 'Always Expanded', YSP_TEXT_DOMAIN ),
                    'sm' => __( '576px and up (SM)', YSP_TEXT_DOMAIN ),
                    'md' => __( '768px and up (MD)', YSP_TEXT_DOMAIN ),
                    'lg' => __( '992px and up (LG)', YSP_TEXT_DOMAIN ),
                    'xl' => __( '1200px and up (XL)', YSP_TEXT_DOMAIN ),
                    'xxl' => __( '1400px and up (XXL)', YSP_TEXT_DOMAIN ),
                ),
            )
        ));

        // Mobile Navigation Toggle Position
        $wp_customize->add_setting( "ysp-mobile-navigation-toggle",
            array(
                "default"   => ysp_customizer_defaults('ysp-mobile-navigation-toggle'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-mobile-navigation-toggle",
            array(
                "label"		=> __('Mobile Navigation Toggle Position', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-navigation",
                "settings"	=> "ysp-mobile-navigation-toggle",
                "type"		=> "select",
                "choices"   => array(
                    '0' => __('Right', YSP_TEXT_DOMAIN),
                    '1' => __('Left', YSP_TEXT_DOMAIN),
                ),
            )
        ));

        // Mobile Navigation Level
        $wp_customize->add_setting( "ysp-mobile-navigation-level",
            array(
                "default"   => ysp_customizer_defaults('ysp-mobile-navigation-level'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-mobile-navigation-level",
            array(
                "label"		=> __('Mobile Navigation Level', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-navigation",
                "settings"	=> "ysp-mobile-navigation-level",
                "type"		=> "select",
                "choices"   => array(
                    'low'  => __('Low', YSP_TEXT_DOMAIN),
                    'high' => __('High', YSP_TEXT_DOMAIN),
                ),
            )
        ));

        // Mobile Navigation Width
        $wp_customize->add_setting( "mobile-navigation-width",
            array(
                "default"   => ysp_customizer_defaults('mobile-navigation-width'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "mobile-navigation-width",
            array(
                "label"		=> __('Mobile Navigation Width', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-navigation",
                "settings"	=> "mobile-navigation-width",
                "type"		=> "number",
                "input_attrs"   => array(
                    'min' => 60,
                    'max' => 100,
                ),
            )
        ));

        if (get_option('ysp-addon-hang-nav') == "1") {
            // Hang Navigation Position
            $wp_customize->add_setting( "ysp-hang-navigation-position",
                array(
                    "default"   =>  ysp_customizer_defaults('ysp-hang-navigation-position'),
                )
            );
                
            $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
                "ysp-hang-navigation-position",
                array(
                    "label"		=> __('Hang Navigation Position', YSP_TEXT_DOMAIN),
                    "section"	=> "ysp-navigation",
                    "settings"	=> "ysp-hang-navigation-position",
                    "type"		=> "select",
                    "choices"   => array(
                        'lft' =>  __( 'Default', YSP_TEXT_DOMAIN ),
                        'cnt' =>  __( 'Center', YSP_TEXT_DOMAIN ),
                        'rgt' =>  __( 'Right', YSP_TEXT_DOMAIN ),
                    ),
                )
            ));
        }

        // Back to Top Button
        $wp_customize->add_setting( "ysp-back-to-top-button",
            array(
                "default"   =>  ysp_customizer_defaults('ysp-back-to-top-button'),
            )
        );
            
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-back-to-top-button",
            array(
                "label"		=> __('Display Back to Top Button', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-navigation",
                "settings"	=> "ysp-back-to-top-button",
                "type"		=> "select",
                "choices"   => array(
                    '1' =>  __( 'Yes', YSP_TEXT_DOMAIN ),
                    '0' =>  __( 'No', YSP_TEXT_DOMAIN ),
                ),
            )
        ));

        // Add Spacing Section
        $wp_customize->add_section( "ysp-spacing",
            array(
                "title"     => __('Spacing', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Size of the added spacing on top and bottom of pages
        $wp_customize->add_setting( "ysp-spacing-size",
            array(
                "default"   => ysp_customizer_defaults('ysp-spacing-size'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-spacing-size",
            array(
                "label"		    => __('Added content spacing height', YSP_TEXT_DOMAIN),
                "description"   => __('This is the spacing that will be added before and after the content of pages, posts and all other pages in your website.', YSP_TEXT_DOMAIN),
                "section"	    => "ysp-spacing",
                "settings"	    => "ysp-spacing-size",
                "type"		    => "select",
                "choices"       => ysp_default_spacing(),
            )
        ));

        // Add Scripts Section
        $wp_customize->add_section( "ysp-scripts",
            array(
                "title"     => __('Scripts', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // Load script(s) in the Head
        $wp_customize->add_setting( "ysp-script-head",
            array(
                "default"   => "",
            )
        );
        
        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-script-head",
            array(
                "label"		    => __('Load script(s) in the Head', YSP_TEXT_DOMAIN),
                "description"   => __("Will be loaded inside the head html-tag.", YSP_TEXT_DOMAIN),
                "section"	    => "ysp-scripts",
                "settings"	    => "ysp-script-head",
                "type"		    => "textarea",
            )
        ));

        // Load script(s) in the Body
        $wp_customize->add_setting( "ysp-script-body",
            array(
                "default"   => "",
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-script-body",
            array(
                "label"		    => __('Load script(s) in the Body', YSP_TEXT_DOMAIN),
                "description"   => __("Will be loaded inside the body html-tag.", YSP_TEXT_DOMAIN),
                "section"	    => "ysp-scripts",
                "settings"	    => "ysp-script-body",
                "type"		    => "textarea",
            )
        ));

        // Load script(s) in the Footer
        $wp_customize->add_setting( "ysp-script-footer",
            array(
                "default"   => "",
            )
        );	

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-script-footer",
            array(
                "label"		    => __('Load script(s) in the Footer', YSP_TEXT_DOMAIN),
                "description"   => __("Will be loaded in the footer html-tag.", YSP_TEXT_DOMAIN),
                "section"	    => "ysp-scripts",
                "settings"	    => "ysp-script-footer",
                "type"		    => "textarea",
            )
        ));

        // Add WooCommerce Section
        $wp_customize->add_section( "ysp-advanced-woocommerce",
            array(
                "title"     => __('WooCommerce', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // WooCommerce - Remove Header Utility
        $wp_customize->add_setting( "ysp-woo-remove-header-utility",
            array(
                "default"    => ysp_customizer_defaults('ysp-woo-remove-header-utility'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-woo-remove-header-utility",
            array(
                "label"		=> __('Remove Header Utility', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-advanced-woocommerce",
                "settings"	=> "ysp-woo-remove-header-utility",
                "type"		=> "select",
                "choices"   => array(
                    '0' =>  __('No', YSP_TEXT_DOMAIN),
                    '1' =>  __('Yes', YSP_TEXT_DOMAIN),
                ),
            )
        ));

        // Add 404 Page Section
        $wp_customize->add_section( "ysp-advanced-404",
            array(
                "title"     => __('404 Page', YSP_TEXT_DOMAIN),
                "priority"  => 90,
                'panel'     => 'ysp-advanced',
            )
        );

        // 404 Page - Custom Image URL
        $wp_customize->add_setting( "ysp-404-page-custom-image-url",
            array(
                "default"    => ysp_customizer_defaults('ysp-404-page-custom-image-url'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-404-page-custom-image-url",
            array(
                "label"		=> __('Image URL', YSP_TEXT_DOMAIN),
                "section"	=> "ysp-advanced-404",
                "settings"	=> "ysp-404-page-custom-image-url",
                "type"		=> "text",
                'description' => __('Set a custom image URL for the default 404 page.', YSP_TEXT_DOMAIN),
            )
        ));

        // 404 Page - Select a custom 404 page
        $wp_customize->add_setting( "ysp-custom-404-page",
            array(
                "default"   => ysp_customizer_defaults('ysp-custom-404-page'),
            )
        );

        $wp_customize->add_control( new WP_Customize_Control( $wp_customize,
            "ysp-custom-404-page",
            array(
                "label"		    => __( 'Custom 404 Page', YSP_TEXT_DOMAIN ),
                "description"   => __( 'Choose a page to use as a custom 404 page.', YSP_TEXT_DOMAIN ),
                "section"	    => "ysp-advanced-404",
                "settings"	    => "ysp-custom-404-page",
                "type"		    => "select",
                "choices"       => ysp_get_pages(),
            )
        ));
    }
}
add_action("customize_register", "ysp_theme_customizer_advanced");