<?php
/**
 * yourstyle+ Theme Customizer: Utility Functions
 *
 * Functions for rendering various Customizer settings
 *
 * @package yourstyle+
 */

/**
 * Create options array to be used as option defaults for the customizer
 *
 * @param array  $option value for the option.
 * @param string $filter_name Filter function name.
 * @return array
 */
if (!function_exists('ysp_get_customizer_options')) {
    function ysp_get_customizer_options( $option = '', $filter_name = '' ) {

        $options = array();

        if ( !empty( $option ) && !empty( $filter_function ) ) {
            if ( !is_array( $option ) ) {
                $option = preg_split( '#\s+#', $option );
            }
            $options = array_merge( $options, $option );
        } else {
            // Ensure that we always coerce option to being an array!
            $option = array();
        }

        /**
         * Filter the list of options for the current option.
        *
        * @since 2.8.0
        *
        * @param array  $options    An array of default options.
        * @param string $option     A comma-separated list of additional options.
        */
        $options = apply_filters( $filter_name, $options, $option );

        return $options;
    }
}

/**
 * Merge all customizer defaults into one function.
 *
 * @param array $option     Get specific default option
 * @param array $options    Get all merged default options
 */
if (!function_exists('ysp_customizer_defaults')) {
    function ysp_customizer_defaults( $option = '' ) {

        $options = ysp_get_customizer_options( $option, 'ysp_customizer_defaults' );

        $exists = array_key_exists($option, $options);
        if ($exists) {
            return $options[$option];
        // } else if (is_user_logged_in() && defined('WP_DEBUG') && WP_DEBUG === true) {
        //     return _e('Option Not Found!', YSP_TEXT_DOMAIN);
        } else {
            // Nothing
        }
    }
}

/**
 * Return the option with the default option as backup.
 *
 * @param string Option / Default
 */
if (!function_exists('ysp_get_option')) {
    function ysp_get_option( $option ) {
        $default = ysp_customizer_defaults( $option );
        if (!empty($default)) {
            $option_value = get_theme_mod( $option, $default );
        } else {
            $option_value = get_theme_mod( $option );
        }
        if ( $option_value ) {
            return $option_value;
        }
    }
}

/**
 * Render the css variable based on the theme_mod (used in ysp_include_css_variables())
 *
 * @param string The CSS variable / Theme Mod
 */
if (!function_exists('ysp_render_css_variable')) {
    function ysp_render_css_variable( $variable, $suffix = '' ) {
        $theme_mod_value = get_theme_mod( $variable, ysp_customizer_defaults( $variable ) );
        if ( $theme_mod_value ) {
            echo '--' . $variable . ': ' . $theme_mod_value . $suffix . ';';
        }
    }
}