<?php
/**
 * Layout Template Classes setup.
 * Control Layout classes from one place
 * Setup theme layouts from here
 *
 * @package yourstyle_plus
 */

/**
 * Site Header Classes
 */
add_filter( 'ysp_site_header_class', 'ysp_site_main_header' );
if ( !function_exists( 'ysp_site_main_header' ) ) {

	function ysp_site_main_header( $classes ) {

        $header_transparency = get_post_meta( get_the_id(), 'site_header_transparency', true );
        $header_transparency = !empty($header_transparency) ? $header_transparency : '';

		$classes[] = 'site-header';
        if ( 'transparent' == $header_transparency ) {
            $classes[] = 'site-header--transparent';
        }

		return $classes;
	}
}

/**
 * Site Header Navigation Classes
 */
add_filter( 'ysp_site_header_navigation_class', 'ysp_site_main_header_navigation' );
if ( !function_exists( 'ysp_site_main_header_navigation' ) ) {

	function ysp_site_main_header_navigation( $classes ) {

        $nav_expand = ysp_get_option('ysp-nav-expand');
        $nav_expand = !empty($nav_expand) ? $nav_expand : 'lg';

		$classes[] = 'site-header-navigation';

        if ( 'aw' !== $nav_expand ) {
            $classes[] = 'site-header-navigation--expand-'. $nav_expand;
        }

		return $classes;
	}
}

/**
 * Site Header Container Classes
 */
add_filter( 'ysp_site_header_container_class', 'ysp_site_main_header_container' );
if ( !function_exists( 'ysp_site_main_header_container' ) ) {

	function ysp_site_main_header_container( $classes ) {

		$classes[] = 'c-container-fluid';
		return $classes;
	}
}

/**
 * Header layout left Classes
 */
add_filter( 'ysp_header_layout_left_class', 'ysp_header_layout_left' );
if ( !function_exists( 'ysp_header_layout_left' ) ) {

	/**
	 * Setting for theme header layout left area
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_header_layout_left( $classes ) {

		$classes[] = 'site-branding';
		$classes[] = 'c-col-5';
		$classes[] = 'c-col-sm-6';
		$classes[] = 'c-col-md-4';
		$classes[] = 'c-col-lg-3';
		return $classes;
	}
}

/**
 * Header layout right Classes
 */
add_filter( 'ysp_header_layout_right_class', 'ysp_header_layout_right' );
if ( !function_exists( 'ysp_header_layout_right' ) ) {

	/**
	 * Setting for theme header layout right area
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_header_layout_right( $classes ) {

		$classes[] = 'site-navigation';
		$classes[] = 'c-col-7';
		$classes[] = 'c-col-sm-6';
		$classes[] = 'c-col-md-8';
		$classes[] = 'c-col-lg-9';
		return $classes;
	}
}

/**
 *	Site Content Classes
 */
add_filter( 'ysp_site_content_class', 'ysp_site_content_layout' );
if ( !function_exists( 'ysp_site_content_layout' ) ) {

	/**
	 * Setting for id="content"
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_site_content_layout( $classes ) {

		// Add 'class-name' to the $classes array!
        $classes[] = 'site-content';

        // Single Post
        if ( is_single() && ! is_singular('product') || woo_switch() && (is_cart()) ) {
            $classes[] = 'u-background-color-gray-1';
        }

		// Return the $classes array.
		return $classes;
	}
}

/**
 * Content Area Classes
 */
add_filter( 'ysp_content_area_class', 'ysp_content_layout' );
if ( !function_exists( 'ysp_content_layout' ) ) {

	/**
	 * Setting for id="primary"
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_content_layout( $classes ) {

		global $wp_query, $wpdb, $ysp_template_layout;

		// Element to be Removed.
		$whitelist = array();

		// Default Classes
		$classes[] = 'content-area';
		$classes[] = 'c-col-12';

		// Add Classes to the Sidebar Template
		if ( $ysp_template_layout == 'sidebar' ) {
			$classes[] = 'c-col-md-9';
		}

		// Add Classes to the Small Template
		if ( $ysp_template_layout == 'small' ) {
			$classes[] = 'c-col-md-8';
        }

        // Remove Classes
		if ( $ysp_template_layout == 'fullwidth' ) {
            $whitelist[] = 'c-col-12';
        }
		
		// Remove Classes
		if ( $ysp_template_layout == 'landingpage' ) {
            $whitelist[] = 'c-col-12';
        }
        
		// Classes With Whitelist
		$classes = array_diff( $classes, $whitelist );

		// Return the Classes
		return $classes;
	}
}

/**
 * HTML Page Content Wrappers.
 */
add_action( 'ysp_before_content', 'ysp_page_top', 15 );

if ( ! function_exists( 'ysp_page_top' ) ) {

	/**
	 * Add page wrapper html element
	 */
	function ysp_page_top() {

		// Whitelist Elements to be removed upon condition!
		if ( woo_switch() && (is_shop() || is_product_category() || is_product_tag()) ) {
			echo'<div class="c-container"><div class="c-row u-flex-row-reverse">';
		}
	}
}

/**
 * HTML Page Content Wrappers.
 */
add_action( 'ysp_after_content', 'ysp_page_end', 5 );

if ( ! function_exists( 'ysp_page_end' ) ) {

	/**
	 * Add page wrapper html element
	 */
	function ysp_page_end() {

		// Whitelist Elements to be removed upon condition!
		if ( woo_switch() && (is_shop() || is_product_category() || is_product_tag()) ) {
			echo '</div></div>';
		}
	}
}

/**
 * Sidebar Area Classes
 */
add_filter( 'ysp_sidebar_area_class', 'ysp_sidebar_layout' );
if ( !function_exists( 'ysp_sidebar_layout' ) ) {

	/**
	 * Setting for id="secondary"
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_sidebar_layout( $classes ) {

		global $ysp_template_layout;

		// Element to be Removed.
		$whitelist = array();

		// Default Classes
		$classes[] = 'sidebar-area';
        if ( class_exists( 'WooCommerce' ) && (is_shop() || is_product_category() || is_product_tag()) ) {
            $classes[] = 'sidebar-area--woocommerce';
        }
		$classes[] = 'c-col-12';
		$classes[] = 'c-col-md-3';

		// Add Classes to the Sidebar Template
		if ( $ysp_template_layout == 'sidebar' ) {
			$classes[] = 'c-col-md-3';
		}

		// Add Classes to the Small Template
		if ( $ysp_template_layout == 'small' ) {
			$classes[] = 'c-col-md-4';
        }

        // Remove Classes (Exmaple)
        // $whitelist[] = 'c-col-12';
        
		// Classes With Whitelist
		$classes = array_diff( $classes, $whitelist );

		// Return the $classes array.
		return $classes;
	}
}

/**
 * Theme Footer Default Class
 */
add_filter( 'ysp_site_footer_class', 'ysp_site_footer_layout' );
if ( !function_exists( 'ysp_site_footer_layout' ) ) {

	/**
	 * Setting for id="colophon"
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_site_footer_layout( $classes ) {

        $footer_alternative = get_post_meta( get_the_id(), 'site_footer_alternative', true );
        $footer_alternative = !empty($footer_alternative) ? $footer_alternative : '';

		// Add 'class-name' to the $classes array!
        $classes[] = 'site-footer';

        if ( 'alternative' == $footer_alternative ) {
            $classes[] = 'site-footer--alternative';
        }

		// Return the $classes array.
		return $classes;
	}
}

/**
 * Theme Footer Widget Default Class
 */
add_filter( 'ysp_site_footer_widget_class', 'ysp_site_footer_widget_layout' );
if ( !function_exists( 'ysp_site_footer_widget_layout' ) ) {

	/**
	 * Setting for Footer Widgets
	 *
	 * @param array $classes Storred css classes.
	 * @return array
	 */
	function ysp_site_footer_widget_layout( $classes ) {

		// Add 'class-name' to the $classes array!
        $classes[] = 'c-col-12';
        $classes[] = 'c-col-sm-6';
        $classes[] = 'c-col-md-3';

		// Return the $classes array.
		return $classes;
	}
}

/**
 * Theme Main nav default class
 */
add_filter( 'ysp_site_nav_class', 'ysp_theme_main_nav_class' );
if ( !function_exists( 'ysp_theme_main_nav_class' ) ) {

	/**
	 * Theme Main nav default class
	 *
	 * @param array $classes Holds the classes of the main navigation.
	 * @return array
	 */
	function ysp_theme_main_nav_class( $classes ) {
		$classes[] = 'site-nav';
		return $classes;
	}
}

/**
 * Theme Main mobile nav default class
 */
add_filter( 'ysp_site_mobile_nav_class', 'ysp_theme_main_mobile_nav_class' );
if ( !function_exists( 'ysp_theme_main_mobile_nav_class' ) ) {

	/**
	 * Theme Main nav default class
	 *
	 * @param array $classes Holds the classes of the main navigation.
	 * @return array
	 */
	function ysp_theme_main_mobile_nav_class( $classes ) {
		$classes[] = 'site-nav-mobile';
		return $classes;
	}
}