<?php
/**
 * File Handler Class
 * 
 * Functions related to handling files and file sizes just to make life a bit
 * easier.
 * 
 * @package     Yourstyle+
 * @subpackage  Yourstyle+/Includes/Classes
 * @author      Bjorn Manintveld
 * @since       1.0.0
 * @version     1.0.0
 */

if (!class_exists('ysp_file_handler')) {

    class ysp_file_handler
    {

        /**
         * Get the size of a folder
         * 
         * @param   string $dir
         * @return  string
         * @since   1.0.0
         */
        function folder_size($dir)
        {
            $size = 0;
            foreach (glob(rtrim($dir, '/').'/*', GLOB_NOSORT) as $each) {
                $size += is_file($each) ? filesize($each) : folderSize($each);
            }
            return $size;
        }

        /**
         * Count the files in a directory
         * 
         * @param   string $dir
         * @return  string
         * @since   1.0.0
         */
        function count_files_in_dir($dir)
        {
            $filecount = 0;
            $files = glob($dir . "*");
            if ($files) {
                $filecount = count($files);
            }
            return $filecount;
        }

        /**
         * Format Bytes
         * Takes file size in bytes and format it to KB, MB or GB
         * 
         * @param   int $bytes
         * @return  string
         * @since   1.0.0
         */
        public function format_bytes($bytes)
        {
            if ($bytes >= 1073741824) {
                $bytes = number_format($bytes / 1073741824, 2) . ' GB';
            } elseif ($bytes >= 1048576) {
                $bytes = number_format($bytes / 1048576, 2) . ' MB';
            } elseif ($bytes >= 1024) {
                $bytes = number_format($bytes / 1024, 2) . ' KB';
            } elseif ($bytes > 1) {
                $bytes = $bytes . ' bytes';
            } elseif ($bytes == 1) {
                $bytes = $bytes . ' byte';
            } else {
                $bytes = '0 bytes';
            }
            return $bytes;
        }

        /**
         * Clean up unnecessary files like .DS_Store
         * 
         * @since 1.0.0
         */
        function unnecessary_files_cleaner($dir, $dryrun = true){
            $ffs = scandir($dir);

            unset($ffs[array_search('.', $ffs, true)]);
            unset($ffs[array_search('..', $ffs, true)]);

            // prevent empty ordered elements
            if (count($ffs) < 1)
                return;

            foreach($ffs as $ff){
                if ($ff == '.DS_Store' || $ff == '._.DS_Store') {
                    if ($dryrun == false) {
                        if (is_file($dir.$ff)) {
                            unlink($dir.'/'.$ff);
                        }
                    } else {
                        echo '<li>'.$dir.'/'.$ff.'</li>';
                    }
                } else if (is_dir($dir.'/'.$ff)) {
                    ysdb_unnecessary_files_cleaner($dir.'/'.$ff, $dryrun);
                }
            }
        }

    }

}