<?php
/**
 * Theme Helper functions.
 */

/**
 * Pagination
 */
if ( ! function_exists('ysp_pagination') ) {
	function ysp_pagination() {
        
		global $wp_query;
        $big = 999999999;
        $output = '';
        
		$links = paginate_links(array(
			'base' => str_replace($big, '%#%', get_pagenum_link($big)),
			'format' => '?page=%#%',
			'current' => max(1, get_query_var('paged')),
			'total' => $wp_query->max_num_pages,
			'type' => 'array',
        ));
        
		if (is_array($links)) {
            $output .= '<nav aria-label="'. __('Page navigation', YSP_TEXT_DOMAIN) .'">';
                $output .= '<ul class="c-pagination">';
                foreach ($links as $link) {
                    $link = str_replace("page-numbers", "c-pagination__link", $link);
                    $output .= '<li class="c-pagination__item">'. $link .'</li>';
                }
			    $output .= '</ul>';
			$output .= '</nav><!-- Pagination -->';
        }
        echo $output;
	}
}

/**
 * Navigation
 */
if ( ! function_exists('ysp_single_navigation') ) {
	function ysp_single_navigation() {

        $next_post = get_next_post();
        $prev_post = get_previous_post();

        if ( $next_post || $prev_post ) {

            $pagination_classes = '';

            if ( ! $next_post ) {
                $pagination_classes = ' only-one only-prev';
            } elseif ( ! $prev_post ) {
                $pagination_classes = ' only-one only-next';
            }
            ?>

            <nav class="pagination-single section-inner<?php echo esc_attr( $pagination_classes ); ?>" aria-label="<?php esc_attr_e( 'Post', YSP_TEXT_DOMAIN ); ?>" role="navigation">
                <hr class="styled-separator is-style-wide" aria-hidden="true" />
                <div class="pagination-single-inner">
                    <?php
                    if ( $prev_post ) {
                        ?>
                        <a class="previous-post" href="<?php echo esc_url( get_permalink( $prev_post->ID ) ); ?>">
                            <span class="arrow" aria-hidden="true">&larr;</span>
                            <span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $prev_post->ID ) ); ?></span></span>
                        </a>
                        <?php
                    }

                    if ( $next_post ) {
                        ?>
                        <a class="next-post" href="<?php echo esc_url( get_permalink( $next_post->ID ) ); ?>">
                            <span class="arrow" aria-hidden="true">&rarr;</span>
                                <span class="title"><span class="title-inner"><?php echo wp_kses_post( get_the_title( $next_post->ID ) ); ?></span></span>
                        </a>
                        <?php
                    }
                    ?>
                </div><!-- .pagination-single-inner -->
                <hr class="styled-separator is-style-wide" aria-hidden="true" />
            </nav><!-- .pagination-single -->
            <?php
        }
	}
}

/**
 * Get Current Page ID
 */
if (!function_exists('ysp_get_current_page_id')) {
    function ysp_get_current_page_id() {
        if ( class_exists('woocommerce') && ( is_shop() || is_product_category() || is_product_tag() ) ) {
            $ID = get_option( 'woocommerce_shop_page_id' );
        } else if ( class_exists('woocommerce') && is_cart() ) {
            $ID = get_option( 'woocommerce_cart_page_id' );
        } else if ( class_exists('woocommerce') && is_checkout() ) {
            $ID = get_option( 'woocommerce_checkout_page_id' );
        } else if ( class_exists('woocommerce') && is_account_page() ) {
            $ID = get_option( 'woocommerce_myaccount_page_id' );
        } else {
            $ID = get_queried_object_id();
        }
        return $ID;
    }
}

/**
 * Theme Available Default Spacings.
 */
if ( ! function_exists('ysp_default_spacing') ) {
	function ysp_default_spacing() {
		$default_spacings_list = array(
            'none' => __( 'None', YSP_TEXT_DOMAIN ),
            '3' => __( 'Spacing (XS)', YSP_TEXT_DOMAIN ),
            '4' => __( 'Spacing (SM)', YSP_TEXT_DOMAIN ),
            '5' => __( 'Spacing (MD)', YSP_TEXT_DOMAIN ),
            '6' => __( 'Spacing (LG)', YSP_TEXT_DOMAIN ),
            '7' => __( 'Spacing (XL)', YSP_TEXT_DOMAIN ),
            '8' => __( 'Spacing (XXL)', YSP_TEXT_DOMAIN ),
            '9' => __( 'Spacing (3XL)', YSP_TEXT_DOMAIN ),
        );
		return $default_spacings_list;
	}
}

/**
 * Theme Available Spacings.
 */
if ( ! function_exists('ysp_spacings') ) {
	function ysp_spacings() {
		$spacings_list = array(
            'default' => __( 'Default', YSP_TEXT_DOMAIN ),
            '0' => __( 'None', YSP_TEXT_DOMAIN ), // Becomes 'none' in ysp_spacing_content_class()
            '3' => __( 'Spacing (XS)', YSP_TEXT_DOMAIN ),
            '4' => __( 'Spacing (SM)', YSP_TEXT_DOMAIN ),
            '5' => __( 'Spacing (MD)', YSP_TEXT_DOMAIN ),
            '6' => __( 'Spacing (LG)', YSP_TEXT_DOMAIN ),
            '7' => __( 'Spacing (XL)', YSP_TEXT_DOMAIN ),
            '8' => __( 'Spacing (XXL)', YSP_TEXT_DOMAIN ),
            '9' => __( 'Spacing (3XL)', YSP_TEXT_DOMAIN ),
        );
		return $spacings_list;
	}
}

/**
 * Theme Get All Pages.
 */
if ( ! function_exists('ysp_get_pages') ) {
    function ysp_get_pages() {
        
        // Pull all the pages into an array
        $options_pages     = array();
        $options_pages_obj = get_pages( 'sort_column=post_parent,menu_order' );
        $options_pages[''] = __( 'Select a page:', YSP_TEXT_DOMAIN );
        foreach ( $options_pages_obj as $page ) {
            $options_pages[ $page->ID ] = $page->post_title;
        }
        return $options_pages;
    }
}

/**
 * Theme Available Template Layouts.
 */
if ( ! function_exists('ysp_template_layouts') ) {
	function ysp_template_layouts() {
        $dir = new DirectoryIterator(YSP_THEME_DIR.'/template-layouts');
        foreach ($dir as $fileinfo) {
            if (!$fileinfo->isDot()) {
                $path_parts = pathinfo($fileinfo->getFilename());
                $remove_parts = ['-start', '-end'];
                $path_parts = str_replace($remove_parts, '', $path_parts);
                $layouts[] = $path_parts['filename'];
            }
        }
        $layouts = array_unique($layouts);
		$template_layouts = array();
        foreach ( $layouts as $layout ) {
            $title = str_replace('-', ' ', $layout);
            $title = ucwords($title);
            $template_layouts[$layout] = __( $title, YSP_TEXT_DOMAIN );
        }
        return $template_layouts;
	}
}

/**
 * Helper function to check if we are in the child theme.
 */
if (!function_exists('ysp_is_child')) {
    function ysp_is_child() {
        // Gets a WP_Theme object for the current theme.
        $current_theme = wp_get_theme();

        // For limitation of empty() write in var.
        $parent = $current_theme->parent();
        if (!empty($parent)) {
            return true;
        }

        return false;
    }
}

/**
 * Get site info.
 */
if (!function_exists('ysp_get_site_info')) {
    function ysp_get_site_info() {
        global $wpdb;
        $wp_data = '';
        $sys_data = '';
        $parent_theme = '';
        $current_theme = '';
        $theme = wp_get_theme();
        $ysp_is_child = ysp_is_child( $theme );

        $short_data = '<span style="font-size:22px;font-weight:300;">'. __('General', YSP_TEXT_DOMAIN) .'</span><br/><br/>';

        // Site Data.
        $short_data .= '<strong>'. __('WordPress', YSP_TEXT_DOMAIN) .': </strong>'. get_bloginfo('version') .'<br/>';
        $short_data .= '<strong>'. __('Language', YSP_TEXT_DOMAIN) .': </strong>'. get_bloginfo('language') .'<br/>';
        $short_data .= '<strong>'. 'Prefix: </strong>'. $wpdb->prefix .'<br/>';
        $short_data .= '<strong>'. __('Active Theme', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Name') .'<br/>';
        $short_data .= '<strong>'. __('Active Theme Version', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Version') .'<br/>';
        $short_data .= '<hr/>';
        $short_data .= '<strong>'. __('Site Title', YSP_TEXT_DOMAIN) .': </strong>'. get_bloginfo('name') .'<br/>';
        $short_data .= '<strong>'. __('Tagline', YSP_TEXT_DOMAIN) .': </strong>'. get_bloginfo('description') .'<br/>';
        $short_data .= '<strong>'. __('Admin Email', YSP_TEXT_DOMAIN) .': </strong>'. get_bloginfo('admin_email') .'<br/>';
        $short_data .= '<strong>'. __('Home URL', YSP_TEXT_DOMAIN) .': </strong>'. home_url() .'<br/>';
        $short_data .= '<strong>'. __('Site URL', YSP_TEXT_DOMAIN) .': </strong>'. site_url() .'<br/>';
        $short_data .= '<strong>'. __('Stylesheet Directory', YSP_TEXT_DOMAIN) .': </strong>'. get_stylesheet_directory_uri() .'<br/>';
        $short_data .= '<strong>'. __('Template Directory', YSP_TEXT_DOMAIN) .': </strong>'. get_template_directory_uri() .'<br/>';

        // Current Theme Data.
        $current_theme .= '<span style="font-size:18px;font-weight:300;">'. __('Current Theme Data', YSP_TEXT_DOMAIN) .'</span><br/><br/>';
        $current_theme .= '<strong>'. __('Theme Name', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Name') .'<br/>';
        $current_theme .= '<strong>'. __('Theme URI', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('ThemeURI') .'<br/>';
        $current_theme .= '<strong>'. __('Theme Version', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Version') .'<br/>';
        $current_theme .= '<strong>'. __('Text Domain', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('TextDomain') .'<br/>';
        $current_theme .= '<strong>'. __('Description', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Description') .'<br/>';
        $current_theme .= '<strong>'. __('Author', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('Author') .'<br/>';
        $current_theme .= '<strong>'. __('Author URI', YSP_TEXT_DOMAIN) .': </strong>'. $theme->get('AuthorURI') .'<br/>';
        $current_theme .= '<hr/>';

        // Parent Theme Data.
        if ( $ysp_is_child ) {
            $parent_t = $theme->parent();
            $parent_theme .= '<span style="font-size:18px;font-weight:300;">'. __('Parent Theme Data', YSP_TEXT_DOMAIN) .'</span><br/><br/>';
            $parent_theme .= '<strong>'. __('Theme Name', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('Name') .'<br/>';
            $parent_theme .= '<strong>'. __('Theme URI', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('ThemeURI') .'<br/>';
            $parent_theme .= '<strong>'. __('Theme Version', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('Version') .'<br/>';
            $parent_theme .= '<strong>'. __('Text Domain', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('TextDomain') .'<br/>';
            $parent_theme .= '<strong>'. __('Description', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('Description') .'<br/>';
            $parent_theme .= '<strong>'. __('Author', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('Author') .'<br/>';
            $parent_theme .= '<strong>'. __('Author URI', YSP_TEXT_DOMAIN) .': </strong>'. $parent_t->get('AuthorURI') .'<br/>';
            $parent_theme .= '<hr/>';
        }
        
        // Get Wordpress Data.
        $wp_data .= '<span style="font-size:22px;font-weight:300;">'. __('WordPress Data', YSP_TEXT_DOMAIN) .'</span><br/>';
        $wp_data .= '<strong>'. __('Site Title', YSP_TEXT_DOMAIN) .'</strong>'. get_bloginfo('name') .'<br/>';
        
        // System Data.
        $sys_data .= '<span style="font-size:22px;font-weight:300;">'. __('System', YSP_TEXT_DOMAIN) .'</span><br/><br/>';
        $sys_data .= '<strong>'. __('PHP Version', YSP_TEXT_DOMAIN) .': </strong>'. phpversion() .'<br/>';
        $sys_data .= '<strong>'. __('MySQL Version', YSP_TEXT_DOMAIN) .': </strong>'. $wpdb->db_version() .'<br/>';
        $sys_data .= '<strong>'. __('Max. Execution Time', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('max_execution_time') .'<br/>';
        $sys_data .= '<strong>'. __('Max. Input Time', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('max_input_time') .'<br/>';
        $sys_data .= '<strong>'. __('Memory Limit', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('memory_limit') .'<br/>';
        $sys_data .= '<strong>'. __('Max. Post Size', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('post_max_size') .'<br/>';
        $sys_data .= '<strong>'. __('Max. Upload Size', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('upload_max_filesize') .'<br/>';
        $sys_data .= '<strong>'. __('Max. Upload Size (WP)', YSP_TEXT_DOMAIN) .': </strong>'. size_format(wp_max_upload_size()) .'<br/>';
        $sys_data .= '<strong>'. __('Max. File Uploads', YSP_TEXT_DOMAIN) .': </strong>'. ini_get('max_file_uploads') .'<br/>';

        return $short_data . '<br/><hr/>' . $current_theme . $parent_theme . $sys_data . '<hr/>';
    }
}

/**
 * Get size information for all currently-registered image sizes.
 *
 * @global $_wp_additional_image_sizes
 *
 * @uses   get_intermediate_image_sizes()
 *
 * @return array $sizes data for all currently-registered image sizes
 */
if (!function_exists('get_image_sizes')) {
    function get_image_sizes() {
        global $_wp_additional_image_sizes;

        $sizes = array();
        $output = '';

        foreach ( get_intermediate_image_sizes() as $_size ) {
            if ( in_array( $_size, array( 'thumbnail', 'medium', 'medium_large', 'large' ) ) ) {
                $sizes[$_size]['width'] = get_option("{$_size}_size_w");
                $sizes[$_size]['height'] = get_option("{$_size}_size_h");
                $sizes[$_size]['crop'] = (bool) get_option("{$_size}_crop");
            } elseif ( isset( $_wp_additional_image_sizes[$_size] ) ) {
                $sizes[$_size] = array(
                    'width' => $_wp_additional_image_sizes[$_size]['width'],
                    'height' => $_wp_additional_image_sizes[$_size]['height'],
                    'crop' => $_wp_additional_image_sizes[$_size]['crop'],
                );
            }
        }

        foreach ( $sizes as $image_size => $image_size_data ) {
            $crop = '';

            if ( is_array( $image_size_data['crop'] ) ) {
                $crop = 'true '.$image_size_data['crop'][0].'-'.$image_size_data['crop'][0];
            } else {
                $crop = $image_size_data['crop'] ? 'true auto' : 'false';
            }

            $output .= '<strong>'.$image_size.'</strong><br/>'.$image_size_data['width'].'x'.$image_size_data['height'].'<br/>Croop: '.$crop.'<hr/>';
        }
        return  $output;
    }
}

/**
 * @param $width
 *
 * @since 1.4.4
 *
 * @return bool|string
 */
if (!function_exists('ysp_wpb_translateColumnWidthToSpan')) {
    function ysp_wpb_translateColumnWidthToSpan( $width ) {
        preg_match( '/(\d+)\/(\d+)/', $width, $matches );
        
        if ( !empty( $matches ) ) {
            $part_x = (int) $matches[1];
            $part_y = (int) $matches[2];

            // 5 Columns Fix
            if ( $part_y == '5' ) {
                switch ( $width ) {
                    case '1/5':
                        $width = '-flex-20';
                        break;
                    case '2/5':
                        $width = '-flex-40';
                        break;
                    case '3/5':
                        $width = '-flex-60';
                        break;
                    case '4/5':
                        $width = '-flex-80';
                        break;
                }
            } else {
                if ( $part_x > 0 && $part_y > 0 ) {
                    $value = ceil( $part_x / $part_y * 12 );
                    if ( $value > 0 && $value <= 12 ) {
                        $width = $value; // 'c-col-lg-' . $value .'/12';
                    }
                }
            }
        }
        return $width;
    }
}

/**
 * Pharse string that is passed via wp built in url modal
 * @return array
 */
if (!function_exists('ysp_parse_link_string')) {
    function ysp_parse_link_string( $value = false ) {
        // Bail out early
        if ( function_exists( 'vc_build_link' ) && $value ) {
            return vc_build_link( $value );
        }
        
        $result = array(
            'url' => '', 
            'title' => '', 
            'target' => '', 
            'rel' => ''
        );
        
        if ( $value ) {
            $params_pairs = explode('|', $value);        
            if (!empty($params_pairs)) {
                foreach ($params_pairs as $pair) {                
                    $param = preg_split('/\:/', $pair);
                    if (!empty($param[0]) && isset($param[1])) {
                        $result[$param[0]] = rawurldecode($param[1]);
                    }
                }
            }
        }
        return $result;
    }
}

if (!function_exists('ysp_generate_link')) {
    function ysp_generate_link( $value ) {
        $link_array = ysp_parse_link_string( $value );

        /**
         * WPML helper / url converter
         * get the post id and generate url from a post id
         * if you duplicate a page in wpml in another language the get_permalink()
         * will give us the link to the correspondent page in the selected language
         */
        // TODO implement the wpml lang switch based on theme option to avoid extra check
        if ( function_exists( 'icl_object_id' ) ) {
            $post_id = url_to_postid( $link_array['url'] );

            //Check if is custom link
            if ( $post_id !== 0 ) {
                $link_array['url'] = get_permalink( $post_id );
            }
        }  
        return $link_array;
    }
}

if (!function_exists('ysp_generate_url_param_list')) {
    function ysp_generate_url_param_list( $url ) {
        $param_list = '';  

        $link = ysp_generate_link( $url );
        if ( !$link['url'] ) {
            return false;
        }
        
        $param_list .= $link['url'] ? ' href="'. $link['url'] .'"' : '';
        $param_list .= $link['target'] ? ' target="'. $link['target'] .'"' : '';
        $param_list .= $link['title'] ? ' title="'. $link['title'] .'"' : '';
        $param_list .= $link['rel'] ? ' rel="'. $link['rel'] .'"' : '';

        return $param_list;
    }
}

if ( ! function_exists( 'ysp_back_to_top_btn' ) ) {
    function ysp_back_to_top_btn()
    {
        if ( ! ysp_get_option( 'ysp-back-to-top-button' ) ) {
            return;
        }

        $output = '';

        $title = __('Back to Top', YSP_TEXT_DOMAIN);
        $icon = '<svg aria-hidden="true" focusable="false" data-prefix="fal" data-icon="chevron-up" class="svg-inline--fa fa-chevron-up fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="currentColor" d="M4.465 366.475l7.07 7.071c4.686 4.686 12.284 4.686 16.971 0L224 178.053l195.494 195.493c4.686 4.686 12.284 4.686 16.971 0l7.07-7.071c4.686-4.686 4.686-12.284 0-16.97l-211.05-211.051c-4.686-4.686-12.284-4.686-16.971 0L4.465 349.505c-4.687 4.686-4.687 12.284 0 16.97z"></path></svg>';

        $output .= '<a id="yspBack2Top" href="#page" title="'. $title .'">'. $icon .'</a>';

        echo $output;
    }
}
add_action('wp_footer', 'ysp_back_to_top_btn', 10);