<?php
/**
 * yourstyle+ Spacing Related Hooks & Filters.
 *
 * @package yourstyle+
 */

/* Before Content Spacing */
if (!function_exists('ysp_spacing_before_content')) {
    function ysp_spacing_before_content() {

        $spacing_class = ysp_spacing_content_class( $spacing = '' ); // Default (customizer)
        $spacing_before = ysp_spacing_content_class( get_post_meta( ysp_get_current_page_id(), 'spacing_before_content', true ) ); // Setting (post)
        
        if ( ( $spacing_before != NULL || $spacing_before != NULL ) && $spacing_before != 'default' ) {
            $spacing = !empty($spacing_before) ? $spacing_before : ''; // Default (post)
        } else if ( $spacing_class != NULL || $spacing_class != NULL ) {
            $spacing = !empty($spacing_class) ? $spacing_class : ''; // Default (customizer)
        } else {
            $spacing = 'u-padding-bottom-xl'; // Fallback
        }

        if ($spacing) {
            echo '<div class="'. $spacing .'"></div>';
        }
    }
}
add_action('ysp_before_content', 'ysp_spacing_before_content');

/* After Content Spacing */
if (!function_exists('ysp_spacing_after_content')) {
    function ysp_spacing_after_content() {

        $spacing_class = ysp_spacing_content_class( $spacing = '' ); // Default (customizer)
        $spacing_after = ysp_spacing_content_class( get_post_meta( ysp_get_current_page_id(), 'spacing_after_content', true ) ); // Setting (post)

        if ( ( $spacing_after != NULL || $spacing_after != NULL ) && $spacing_after != 'default' ) {
            $spacing = !empty($spacing_after) ? $spacing_after : ''; // Default (post)
        } else if ( $spacing_class != NULL || $spacing_class != NULL ) {
            $spacing = !empty($spacing_class) ? $spacing_class : ''; // Default (customizer)
        } else {
            $spacing = 'u-padding-bottom-xl'; // Fallback
        }

        if ($spacing) {
            echo '<div class="'. $spacing .'"></div>';
        }
    }
}
add_action('ysp_after_content', 'ysp_spacing_after_content');

/* Default Content Spacing */
if (!function_exists('ysp_spacing_content_class')) {
    function ysp_spacing_content_class( $spacing ) {

        $spacing = $spacing === '0' ? 'none' : $spacing; // Set value '0' as 'none' for $spacing

        if ( ! empty( $spacing ) ) {
            $spacing = $spacing;
        } else {
            $spacing = ysp_get_option('ysp-spacing-size');
        }

        if ( $spacing ) {
            switch ($spacing) {

                case 'none':
                    $spacing_class = 'u-padding-bottom-none';
                    break;

                case 3:
                    $spacing_class = 'u-padding-bottom-xs';
                    break;

                case 4:
                    $spacing_class = 'u-padding-bottom-sm';
                    break;

                case 5:
                    $spacing_class = 'u-padding-bottom-md';
                    break;

                case 6:
                    $spacing_class = 'u-padding-bottom-lg';
                    break;

                case 7:
                    $spacing_class = 'u-padding-bottom-xl';
                    break;

                case 8:
                    $spacing_class = 'u-padding-bottom-xxl';
                    break;

                case 9:
                    $spacing_class = 'u-padding-bottom-3xl';
                    break;

                default:
                    $spacing_class = 'u-padding-bottom-xl';
                    break;
            }

            return $spacing_class;
        }
    }
}