<?php

/**
 * Custom theme navigation Walker.
 */
if ( !class_exists('Ysp_Mobile_Nav_walker') ) {
    class Ysp_Mobile_Nav_walker extends Walker_Nav_Menu {

        /**
         * Ends the list of after the elements are added.
         *
         * @see Walker::end_lvl()
         * @since 3.0.0
         *
         * @param string $output Passed by reference. Used to append additional content.
         * @param int    $depth  Depth of menu item. Used for padding.
         * @param array  $args   An array of arguments. @see wp_nav_menu().
         */
        public function start_lvl( &$output, $depth = 0, $args = array() ) {
            $icon    = '<svg aria-hidden="true" focusable="false" data-prefix="far" data-icon="chevron-down" class="c-mobile-nav__icon svg-inline--fa fa-chevron-down fa-w-14" role="img" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 448 512"><path fill="currentColor" d="M441.9 167.3l-19.8-19.8c-4.7-4.7-12.3-4.7-17 0L224 328.2 42.9 147.5c-4.7-4.7-12.3-4.7-17 0L6.1 167.3c-4.7 4.7-4.7 12.3 0 17l209.4 209.4c4.7 4.7 12.3 4.7 17 0l209.4-209.4c4.7-4.7 4.7-12.3 0-17z"></path></svg>';
            $indent  = str_repeat( "\t", $depth );
            $output .= "\n$indent<span class=\"show-submenu\">{$icon}</span><ul class=\"site-nav__list sub-menu level-" . $depth . "\">\n";
        }

        /**
         * Start the element output.
         *
         * @see Walker::start_el()
         * @since 3.0.0
         *
         * @param string $output Passed by reference. Used to append additional content.
         * @param object $item   menu item data object
         * @param int    $depth  Depth of menu item. Used for padding.
         * @param array  $args   An array of arguments. @see wp_nav_menu().
         * @param int    $id     current item ID
         */
        public function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
            global $wp_query;

            $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';

            $class_names = $value = '';
            
            $item_tag    = 'a';

            $classes = empty( $item->classes ) ? array() : (array) $item->classes;
            
            $link_class = 'site-nav__link';

            // Check if menu is set to behave like a submenu open trigger
            $disable_menu_link = get_post_meta( $item->ID, 'menu-item-ysp-disable-menu-link', true );
            if ( $disable_menu_link === 'true' ) {
                $classes[] = 'menu-item--show-submenu';
                $item_tag  = 'div';
            }
                
            // Check if the button option is enabled and add classes
            $menu_button_type = get_post_meta( $item->ID, 'menu-item-ysp-menu-button-type', true );
            if ( $menu_button_type !== '' ) {
                $classes[] = 'menu-item--has-button';
                $link_class = 'c-button '. $menu_button_type;
            }

            $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
            $class_names = ' class="' . esc_attr( $class_names ) . ' site-nav__item c-mobile-nav__item"';

            $output .= $indent . '<li id="main-mobile-menu-item-' . $item->ID . '"' . $value . $class_names . '>';

            $attributes  = ! empty( $item->attr_title ) ? ' title="' . esc_attr( $item->attr_title ) . '"' : '';
            $attributes .= ! empty( $item->target ) ? ' target="' . esc_attr( $item->target ) . '"' : '';
            $attributes .= ! empty( $item->xfn ) ? ' rel="' . esc_attr( $item->xfn ) . '"' : '';
            $attributes .= ! empty( $item->url ) ? ' href="' . esc_attr( $item->url ) . '"' : '';

            $item_output = ! empty( $args->before ) ? $args->before : '';
            $item_output .= '<' . $item_tag . ' class="'. $link_class .'" ' . $attributes . '>';
            $item_output .= ! empty( $args->link_before ) ? $args->link_before : '';
            $item_output .= apply_filters( 'the_title', $item->title, $item->ID );
            $item_output .= ! empty( $args->link_after ) ? $args->link_after : '';
            $item_output .= '</' . $item_tag . '>';
            $item_output .= ! empty( $args->after ) ? $args->after : '';

            $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
        }

        /**
         * Ends the element output, if needed.
         *
         * @see Walker::end_el()
         * @since 3.0.0
         *
         * @param string $output Passed by reference. Used to append additional content.
         * @param object $item   Page data object. Not used.
         * @param int    $depth  Depth of page. Not Used.
         * @param array  $args   An array of arguments. @see wp_nav_menu().
         */
        public function end_el( &$output, $item, $depth = 0, $args = array() ) {
            $output .= '</li>';
        }
    }
}