<?php
/**
 * yourstyle+ Scripts
 *
 * @package yourstyle+
 */

/**
 * Enqueue Scripts and Styles
 */
if (!function_exists('ysp_scripts') ) {
    function ysp_scripts()
    {
        /**
         * Scripts
         */
        
         /* Theme Script - Enqueue */
		if ( is_child_theme() ) {
            $ysp_theme_script = ( file_exists( get_stylesheet_directory() . '/assets/dist/js/min/ysp-child-theme.min.js' ) ) ? '/assets/dist/js/min/ysp-child-theme.min.js' : '/assets/dist/js/min/main.min.js'; // Legacy Support
            wp_register_script('ysp_theme_script', get_stylesheet_directory_uri() . $ysp_theme_script, array('jquery'), get_child_theme_version(), true );
            wp_enqueue_script('ysp_theme_script');
        } else {
            wp_register_script('ysp_theme_script', get_template_directory_uri() . '/assets/dist/js/min/ysp-theme.min.js', array('jquery'), get_ysp_version(), true );
            wp_enqueue_script('ysp_theme_script');
        }

		/* Fancybox */
		wp_register_script( 'ysp_fancybox_script', 'https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.7/jquery.fancybox.min.js', array('jquery'), '3.5.7', true );

        /* Swiper */
        wp_register_script('swiper_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/js/swiper.min.js', array('jquery'), '5.4.1', true);

        /* Sticky Nav - Enqueue */
        wp_register_script( 'ysp_sticky_nav', get_template_directory_uri() . '/assets/libs/sticky.min.js', array( 'jquery' ), '', true );
        if ( ysp_get_option('ysp-sticky-nav') ) {
            wp_enqueue_script('ysp_sticky_nav');
        }

        /* Tabby Tabs Script */
		if ( is_child_theme() ) {
            wp_register_script('ysp_tabby', get_stylesheet_directory_uri() . '/assets/src/js/parent/components/tabby.js', array('jquery'), '', true);
        } else {
            wp_register_script('ysp_tabby', get_template_directory_uri() . '/assets/src/js/parent/components/tabby.js', array('jquery'), '', true);
        }
        
        /* Animations - Enqueue */
        wp_register_script('ysp_animations_script', get_template_directory_uri() . '/assets/dist/js/min/ysp-animate.min.js', array('jquery'), '', false);
        
        /* Swiper Slider */
        wp_register_script('ysp_swiper_slider', get_template_directory_uri() . '/assets/src/js/parent/components/swiper-slider.js', array( 'jquery', 'swiper_core' ), '', true );

        /* Parallax Script */
        wp_register_script('ysp_parallax', get_template_directory_uri( ) . '/assets/libs/parallax.min.js', array('jquery'), '', true);

        /* Video Background Script */
        wp_register_script('ysp_vc_yt_bg', get_template_directory_uri() . '/assets/libs/youtube-bg.min.js', array('jquery'), '', true);

        /* Vimeo Player API */
        wp_register_script('ysp_vc_vimeo_bg', 'https://player.vimeo.com/api/player.js', array('jquery'), '', true);

        /* ScrollMagic */
        wp_register_script('scroll_magic', 'https://cdnjs.cloudflare.com/ajax/libs/ScrollMagic/2.0.7/ScrollMagic.min.js', array( 'jquery' ), '', true);
        
        /* Comment Script - Enqueue */
        if ( is_singular() && comments_open() && get_option('thread_comments') ) {
            wp_enqueue_script('comment-reply');
        }

        /**
         * Styles
         */

        /* Theme Style - Enqueue */
		if ( is_child_theme() ) {
            $ysp_theme_style =  ( file_exists( get_stylesheet_directory() . '/ysp-child-theme.css' ) ) ? '/ysp-child-theme.css' : '/style.css'; // Legacy Support
            wp_register_style('ysp_theme_style', get_stylesheet_directory_uri() . $ysp_theme_style, array(), get_child_theme_version() );
            wp_enqueue_style('ysp_theme_style');
        } else {
            wp_register_style('ysp_theme_style', get_template_directory_uri() . '/ysp-theme.css', array(), get_ysp_version() );
            wp_enqueue_style('ysp_theme_style');
        }

        /* Animation Support */
        wp_register_style('ysp_animations_style', get_template_directory_uri() . '/assets/dist/css/ysp-animate.min.css');

        /* Fancybox */
		wp_register_style( 'ysp_fancybox_style', 'https://cdnjs.cloudflare.com/ajax/libs/fancybox/3.5.7/jquery.fancybox.min.css', array(), '3.5.7' );

        /* Swiper */
        wp_register_style('swiper_style_core', 'https://cdnjs.cloudflare.com/ajax/libs/Swiper/5.4.1/css/swiper.min.css', array(), '5.4.1' );
    }
}
add_action('wp_enqueue_scripts', 'ysp_scripts');

/**
 * Enqueue scripts and styles in the Head Tag.
 */
if (!function_exists('ysp_scripts_head') ) {
    function ysp_scripts_head()
    {
        /* Load Custom Scripts for the Body */
        $custom_head_script = ysp_get_option('ysp-script-head');
        if (!empty( $custom_head_script ) ) {
            echo $custom_head_script;
        }
    }
}
add_action( 'wp_head', 'ysp_scripts_head');

/**
 * Enqueue scripts and styles after the Body Tag.
 */
if (!function_exists('ysp_scripts_body') ) {
    function ysp_scripts_body()
    {
        /* Load Custom Scripts for the Body */
        $custom_body_script = ysp_get_option('ysp-script-body');
        if (!empty( $custom_body_script ) ) {
            echo $custom_body_script;
        }
    }
}
add_action('ysp-after-body-tag', 'ysp_scripts_body');

/**
 * Enqueue scripts and styles in the Footer.
 */
if (!function_exists('ysp_scripts_footer') ) {
    function ysp_scripts_footer()
    {
        /* Load Custom Scripts for the Footer */
        $custom_footer_script = ysp_get_option('ysp-script-footer');
        if (!empty( $custom_footer_script ) ) {
            echo $custom_footer_script;
        }
    }
}
add_action('wp_footer', 'ysp_scripts_footer');