<?php
/**
 * Functions which enhance the theme by hooking into WordPress
 *
 * @package yourstyle+
 */

if (!function_exists('ysp_body_classes')) {
    /**
     * Adds custom classes to the array of body classes.
     *
     * @param array $classes Classes for the body element.
     * @return array
     */
    function ysp_body_classes($classes)
    {
        // Adds a class of single-default-style to single posts.
        if (is_singular('post')) {
            $classes[] = 'single-default-style';
        }

        // Adds classes based on Page Settings.
        $post_types = array('page', 'post', 'product');
        $post_types = apply_filters('ysp_page_settings', $post_types);        
        if (is_singular($post_types)) {
            $title_visibility = get_post_meta(get_the_ID(), 'page_title_visibility', true);
            if ($title_visibility == 'hide') {
                $classes[] = 'page-title-hidden';
            }
            $site_header_transparency = get_post_meta(get_the_ID(), 'site_header_transparency', true);
            if ($site_header_transparency == 'transparent') {
                $classes[] = 'site-header-transparent';
            }
            $site_footer_alternative = get_post_meta(get_the_ID(), 'site_footer_alternative', true);
            if ($site_footer_alternative == 'alternative') {
                $classes[] = 'site-footer-alternative';
            }
        }        

        // Adds a class of hfeed to non-singular pages.
        if (!is_singular()) {
            $classes[] = 'hfeed';
        }
    
        // Adds a class of group-blog to blogs with more than 1 published author.
        if (is_multi_author()) {
            $classes[] = 'group-blog';
        }

        // Adds a class of no-sidebar when there is no sidebar present.
        if (!is_active_sidebar('sidebar-1')) {
            $classes[] = 'no-sidebar';
        }

        return $classes;
    }
}
add_filter('body_class', 'ysp_body_classes');

if (!function_exists('ysp_pingback_header')) {
    /**
     * Add a pingback url auto-discovery header for single posts, pages, or attachments.
     */
    function ysp_pingback_header()
    {
        if (is_singular() && pings_open()) {
            printf('<link rel="pingback" href="%s">', esc_url(get_bloginfo('pingback_url')));
        }
    }
}
add_action('wp_head', 'ysp_pingback_header');

if (!function_exists('get_post_thumbnail_url')) {
    /**
     * Get the post thumbnail 
     * 
     * @return string
     */
    function get_post_thumbnail_url($post_id = '', $size = 'thumbnail') {
        if (empty($post_id)) {
            $post_id = get_the_ID();
        }
        $output = wp_get_attachment_image_src(get_post_thumbnail_id($post_id), $size);
        if (!empty($output)) {
            return $output[0];
        } else {
            return FALSE;
        }
    }
}

if (!function_exists('ysp_site_branding_logo')) {
    /**
     * Add Branding Logo to the Site Header Branding
     */
    function ysp_site_branding_logo() {

        $logo_mobile_url = ysp_get_option( 'ysp-site-identity-logo-mobile' );
        $logo_desktop_class = ! empty( $logo_mobile_url ) ? ' site-logo__desktop' : '';
        ?>
            <a class="site-logo-wrap" href="<?php bloginfo('url'); ?>">
                <img class="site-logo<?php echo $logo_desktop_class; ?> img-responsive" title="<?php bloginfo('name'); ?>" alt="<?php bloginfo('name'); ?>" src="<?php echo get_site_logo_url(); ?>" width="100%" height="100%" />
                <?php if ( ! empty( $logo_mobile_url ) ) { ?>
                    <img class="site-logo site-logo__mobile img-responsive" title="<?php bloginfo('name'); ?>" alt="<?php bloginfo('name'); ?>" src="<?php echo $logo_mobile_url; ?>" />
                <?php } ?>
            </a>
        <?php
    }
}
add_action('ysp_site_branding', 'ysp_site_branding_logo');