<?php
/**
 * Utility functions
 *
 * @package     yourstyle+
 * @subpackage  yourstyle+/includes
 * @since       0.3.0
 * @version     0.3.0
 */

/**
 * Template Utilities
 * 
 * @since 0.3.0
 */
if (!function_exists('get_part')) {
    function get_part($slug, $name = '')
    {
        get_template_part('template-parts/' . $slug, $name);
    }
}

/**
 * Layout Start
 * 
 * @since 0.3.0
 */
$ysp_template_layout = 'normal';
$ysp_layout_builder_active = FALSE;
if (!function_exists('layout_start')) {
    function layout_start($layout = 'normal')
    {
        global $ysp_template_layout;
        global $ysp_layout_builder_active;
        $ysp_layout_builder_active = TRUE;
        if (!empty($ysp_template_layout)) {
            $layout = $ysp_template_layout;
        } else {
            function_exists('ysp_fallback_layout_start') ? ysp_fallback_layout_start() : '';
        }
        $ysp_template_layout = $layout;
        get_template_part('template-layouts/' . $layout, 'start');
    }
}
add_action('ysp_content_layout_start', 'layout_start', 1);

/**
 * Layout End
 * 
 * @since 0.3.0
 */
if (!function_exists('layout_end')) {
    function layout_end($layout = 'normal')
    {
        global $ysp_template_layout;
        global $ysp_layout_builder_active;
        if (!empty($ysp_template_layout)) {
            $layout = $ysp_template_layout;
        } else {
            function_exists('ysp_fallback_layout_end') ? ysp_fallback_layout_end() : '';
        }
        $layout = $ysp_template_layout;
        get_template_part('template-layouts/' . $layout, 'end');
        $ysp_template_layout = 'normal';
        $ysp_layout_builder_active = FALSE;
    }
}
add_action('ysp_content_layout_end', 'layout_end', 1);

/**
 * Non YSP Layout Start
 * 
 * @since 0.3.0
 */
if (!function_exists('layout_start_non_ysp')) {
    function layout_start_non_ysp()
    {
        global $ysp_layout_builder_active;
        if ($ysp_layout_builder_active == FALSE) {
            do_action('ysp_content_layout_start');
            $ysp_layout_builder_active = FALSE;
        }
    }
}
add_action('ysp_before_content', 'layout_start_non_ysp', 10);

/**
 * Non YSP Layout End
 * 
 * @since 0.3.0
 */
if (!function_exists('layout_end_non_ysp')) {
    function layout_end_non_ysp()
    {
        global $ysp_layout_builder_active;
        if ($ysp_layout_builder_active == FALSE) {
            do_action('ysp_content_layout_end');
        }
    }
}
add_action('ysp_after_content', 'layout_end_non_ysp', 10);

/**
 * Fallback Layout Start
 * 
 * @since 0.9.9.2
 */
if (!function_exists('ysp_fallback_layout_start')) {
    function ysp_fallback_layout_start()
    {
        if (class_exists('WooCommerce') && !woo_switch() ) {
            echo '<div class="c-container">';
                echo '<div class="c-row">';
        }
    }
}

/**
 * Fallback Layout End
 * 
 * @since 0.9.9.2
 */
if (!function_exists('ysp_fallback_layout_end')) {
    function ysp_fallback_layout_end()
    {
        if (class_exists('WooCommerce') && !woo_switch() ) {
                echo '</div>';
            echo '</div>';
        }
    }
}

/**
 * Find the URL of the Child Theme
 * 
 * @since 0.3.0
 */
if (!function_exists('get_child_url')) {
    function get_child_url($add_after_url = "")
    {
		return dirname(get_bloginfo('stylesheet_url')).$add_after_url;
	}
}

/**
 * Get the version number of the Parent Theme
 * 
 * @since 0.3.0
 */
if (!function_exists('get_ysp_version')) {
    function get_ysp_version()
    {
		$theme = wp_get_theme('yourstyle-plus');
		$theme_version = $theme->get('Version');
		return $theme_version;
	}
}

/**
 * Get the version number of the Child Theme
 * 
 * @since 0.3.0
 */
if (!function_exists('get_child_theme_version')) {
    function get_child_theme_version()
    {
        $child = wp_get_theme();
        $child_version = $child->get('Version');
		return $child_version;
	}
}

/**
 * Dump & Die
 * 
 * Dumps the variable and stops the code after
 * 
 * @since 0.3.0
 */
if (!function_exists('dd')) {
    function dd($var)
    {
		echo '<pre>';
		var_dump($var);
		echo '</pre>';
		die();
	}
}