<?php
/**
 * Template part for displaying a message that posts cannot be found
 *
 * @link https://developer.wordpress.org/themes/basics/template-hierarchy/
 *
 * @package yourstyle+
 */

?>

<section class="no-results not-found">
	<header class="page-header">
        <?php do_action('ysp_before_entry_title'); ?>
        <h1 class="page-title"><?php esc_html_e( 'Nothing Found', YSP_TEXT_DOMAIN ); ?></h1>
        <?php do_action('ysp_after_entry_title'); ?>
	</header><!-- .page-header -->

	<div class="page-content">
		<?php
        do_action('ysp_prepend_entry_content');
		if ( is_home() && current_user_can( 'publish_posts' ) ) :

			printf(
				'<p>' . wp_kses(
					/* translators: 1: link to WP admin new post page. */
					__( 'Ready to publish your first post? <a href="%1$s">Get started here</a>.', YSP_TEXT_DOMAIN ),
					array(
						'a' => array(
							'href' => array(),
						),
					)
				) . '</p>',
				esc_url( admin_url( 'post-new.php' ) )
			);

		elseif ( is_search() ) :
            $search_title = sprintf(
                '%1$s %2$s',
                __( 'Search:', YSP_TEXT_DOMAIN ),
                '&ldquo;' . get_search_query() . '&rdquo;'
            );
			?>

            <?php if ( $search_title ) { ?>
                <h4 class="search-title"><?php echo wp_kses_post( $search_title ); ?></h4>
            <?php } ?>

			<p><?php esc_html_e( 'Sorry, but nothing matched your search terms. Please try again with some different keywords.', YSP_TEXT_DOMAIN ); ?></p>
			<?php
			get_search_form();

		else :
			?>

			<p><?php esc_html_e( 'It seems we can&rsquo;t find what you&rsquo;re looking for. Perhaps searching can help.', YSP_TEXT_DOMAIN ); ?></p>
			<?php
			get_search_form();

        endif;
        do_action('ysp_append_entry_content');
		?>
	</div><!-- .page-content -->
</section><!-- .no-results -->
